#
# spec file for package virtualbox
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


# Do not provide libGL.so symbols - they are owned by Mesa already and this could potentially confuse rpm/zypp
%global __provides_exclude ^libE?GL.so.1.*$

%define _vbox_instdir  %{_libexecdir}/virtualbox
%define _udevrulesdir %{_sysconfdir}/udev/rules.d
Name:           virtualbox
Version:        5.1.26
Release:        28.2
Summary:        VirtualBox is an Emulator
License:        GPL-2.0+
Group:          System/Emulators/PC
Url:            http://www.virtualbox.org/
#
# so you don't need to repack virtualbox by hand, just add new release of VirtualBox-x.x.x.tar.bz2 and line below with
# script virtualbox-patch-source.sh will do the job :)
# WARNING: This is not a comment, but the real command to repack souce
#%(bash %{_sourcedir}/virtualbox-patch-source.sh VirtualBox-%{version}.tar.bz2)
Source0:        VirtualBox-%{version}-patched.tar.bz2
Source1:        UserManual.pdf
Source3:        %{name}-60-vboxguest.rules
Source4:        %{name}-default.virtualbox
Source5:        %{name}-host-kmp-files
Source6:        %{name}-guest-kmp-files
Source7:        %{name}-host-preamble
Source8:        %{name}-guest-preamble
Source9:        %{name}-wrapper.sh
Source10:       %{name}-LocalConfig.kmk
Source11:       %{name}-60-vboxdrv.rules
Source13:       %{name}-sysconfig.vbox
Source14:       vboxdrv.service
Source15:       vboxadd-service.service
Source16:       vboxconfig.sh
Source17:       vboxguestconfig.sh
Source18:       fix_usb_rules.sh
Source19:       vboxdrv.sh
# init script to start virtual boxes during boot, to be configured via /etc/sysconfig/vbox bnc#582398
Source20:       vboxes.sh
Source21:       vboxes.service
Source98:       %{name}-rpmlintrc
Source99:       %{name}-patch-source.sh
#rework init scripts to fit suse needs
Patch1:         vbox-vboxdrv-init-script.diff
Patch2:         vbox-vboxadd-init-script.diff
Patch3:         vbox-vboxweb-init-script.diff
#PATCH-FIX-OPENSUSE: Use system X libraries and do not build local things
Patch4:         virtualbox-system-x.patch
#fix build : "Error 4001 - String must be entirely alphanumeric"
#with renaming we probably break some macosx functionality however ths is just quick fix
#file :http://www.virtualbox.org/browser/trunk/src/VBox/Devices/PC/vbox.ds
#see thread : http://lists.freebsd.org/pipermail/freebsd-acpi/2010-October/006795.html
Patch6:         vbox-smc-napa.diff
#fix build of Python and dev package on openSUSE 11.3
Patch8:         vbox-python-detection.diff
#deprecated old-style C++ service proxies and objects,we have to use soapcpp2 -z1 flag
Patch9:         vbox-deprec-gsoap-service-proxies.diff
#fix failed linking process during build - this patch is just quick workaround
Patch10:        vbox-gsoapssl-deps.diff
#PATCH-FIX-OPENSUSE implement messagebox (VBoxPermissionMessage app), which is displayed, when user
#try to start VirtualBox and is not memeber of vboxusers group
Patch99:        vbox-permissions_warning.diff
#PATCH-FIX-OPENSUSE Do not include build dates on binaries, makes build-compare happier
Patch100:       vbox-no-build-dates.diff
Patch101:       vbox-default-os-type.diff
#disable update in vbox gui
Patch103:       vbox-disable-updates.diff
#use pie/fPIE for setuid binaries (bnc#743143)
Patch104:       vbox-fpie.diff
#smap issues on Haswell or Broadwell (boo#931461)
Patch105:       smap.diff
# Patch to build with Factory gcc5
Patch106:       gcc5-real-support.patch
# Patch to build with gnu sed correctly
Patch107:       virtualbox-sed-params.patch
# Patch to use snprintf correcty and not overflow dst buffer
Patch108:       virtualbox-snpritnf-buffer-overflow.patch
# Patch to add code to explain USB Passthru
Patch109:       vbox-usb-warning.diff
# Fix change in kernel API for ttm_bo_move_memcpy()
Patch112:       modify_for_4_8_bo_move.patch
# Remove all mention of _smp_mflags
Patch113:       vbox_remove_smp_mflags.patch
# Fix change in API for get_user_pages()
Patch114:       vbox_fix_42.3_api.patch
# Allow use of gcc7
Patch115:       vbox_fix_for_gcc7.patch
# Fix for missing include needed for server 1.19
Patch116:       Fix_for_server_1.19.patch
# Fix for missing cleanup in KMS support
Patch117:       fix_KMS_support.patch
# Fix invalid use of internal headers
Patch118:       internal-headers.patch
#
BuildRequires:  LibVNCServer-devel
BuildRequires:  SDL-devel
BuildRequires:  acpica
BuildRequires:  alsa-devel
BuildRequires:  bin86
BuildRequires:  infinipath-psm
BuildRequires:  systemd-rpm-macros
%if 0%{?suse_version} > 1325
BuildRequires:  libboost_headers-devel
%else
BuildRequires:  boost-devel
%endif
BuildRequires:  dev86
BuildRequires:  device-mapper-devel
BuildRequires:  dmidecode
BuildRequires:  e2fsprogs-devel
BuildRequires:  fdupes
BuildRequires:  gcc
BuildRequires:  gcc-c++
BuildRequires:  glibc-devel-static
BuildRequires:  gsoap-devel
BuildRequires:  java-devel >= 1.6.0
BuildRequires:  kbuild >= 0.1.9998svn2808
BuildRequires:  kernel-syms
BuildRequires:  libcap-devel
BuildRequires:  libcurl-devel
BuildRequires:  libelf-devel
BuildRequires:  libidl-devel
BuildRequires:  libopenssl-devel
BuildRequires:  libqt5-linguist
BuildRequires:  libqt5-qtbase-devel
BuildRequires:  libqt5-qtx11extras-devel
BuildRequires:  libvpx-devel
BuildRequires:  libxslt-devel
BuildRequires:  module-init-tools
BuildRequires:  pam-devel
BuildRequires:  pulseaudio-devel
BuildRequires:  python-devel
BuildRequires:  quilt
BuildRequires:  sed
BuildRequires:  update-desktop-files
BuildRequires:  which
BuildRequires:  xorg-x11
BuildRequires:  xorg-x11-server
BuildRequires:  xorg-x11-server-sdk
BuildRequires:  yasm
BuildRequires:  zlib-devel-static
BuildRequires:  pkgconfig(fontsproto)
BuildRequires:  pkgconfig(libpng)
BuildRequires:  pkgconfig(randrproto)
BuildRequires:  pkgconfig(renderproto)
BuildRequires:  pkgconfig(resourceproto)
BuildRequires:  pkgconfig(scrnsaverproto)
BuildRequires:  pkgconfig(udev)
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xau)
BuildRequires:  pkgconfig(xcomposite)
BuildRequires:  pkgconfig(xcursor)
BuildRequires:  pkgconfig(xdmcp)
BuildRequires:  pkgconfig(xext)
BuildRequires:  pkgconfig(xextproto)
BuildRequires:  pkgconfig(xf86driproto)
BuildRequires:  pkgconfig(xfixes)
BuildRequires:  pkgconfig(xinerama)
BuildRequires:  pkgconfig(xineramaproto)
BuildRequires:  pkgconfig(xmu)
BuildRequires:  pkgconfig(xproto)
BuildRequires:  pkgconfig(xrandr)
Requires:       %{name}-host-kmp = %{version}
Requires(post): sysvinit(syslog)
Requires(pre):  permissions
%if ! 0%{?suse_version} > 1325
Requires(pre):  net-tools-deprecated
%endif
Requires(pre):  pwdutils
Requires(pre):  %insserv_prereq
Requires(pre):  %fillup_prereq
Recommends:     %{name}-gui = %{version}
#rename from ose version:
Provides:       %{name}-ose = %{version}
Obsoletes:      %{name}-ose < %{version}
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%(sed -e '/^Provides: multiversion(kernel)/d' %{_libexecdir}/rpm/kernel-module-subpackage > %{_builddir}/virtualbox-kmp-template)
ExclusiveArch:  %ix86 x86_64
%ifarch amd64 x86_64 ia32e em64t
BuildRequires:  gcc-32bit
BuildRequires:  gcc-c++-32bit
BuildRequires:  xorg-x11-libX11-devel-32bit
BuildRequires:  xorg-x11-libXext-devel-32bit
BuildRequires:  xorg-x11-libXmu-devel-32bit
BuildRequires:  xorg-x11-libXt-devel-32bit
%endif
%{?systemd_requires}

%description
VirtualBox is an extremely feature rich, high performance product
for enterprise customers, it is also the only professional solution
that is freely available as Open Source Software under the terms of the
GNU Public License (GPL).
##########################################

%package qt
Summary:        Qt GUI part for %{name}
Group:          System/Emulators/PC
Requires:       %{name} = %{version}
Requires(pre):  permissions
Provides:       %{name}-gui = %{version}
#this is needed during update to trigger installing qt subpackage
#http://en.opensuse.org/openSUSE:Upgrade_dependencies_explanation#Splitting_and_Merging
Provides:       %{name}-ose:%{_libexecdir}/virtualbox/VirtualBox.so
#rename from "ose" version:
Provides:       %{name}-ose-qt = %{version}
Obsoletes:      %{name}-ose-qt < %{version}

%description qt
Qt GUI part for %{name}.
#########################################

%package websrv
Summary:        WebService GUI part for %{name}
Group:          System/Emulators/PC
Requires:       %{name} = %{version}
Provides:       %{name}-gui = %{version}
Requires(pre):  %insserv_prereq

%description websrv
websrv GUI part for %{name}.
#########################################

%package host-KMP
Summary:        Host kernel module for VirtualBox
Group:          System/Emulators/PC
%kernel_module_package -t %{_builddir}/virtualbox-kmp-template -p %{SOURCE7} -n %{name}-host -f %{SOURCE5} -x kdump um xen pae xenpae pv

%description host-KMP
This package contains the kernel-module for VirtualBox.
##########################################

%package guest-KMP
Summary:        Guest kernel modules for VirtualBox
Group:          System/Emulators/PC
%kernel_module_package -t %{_builddir}/virtualbox-kmp-template -p %{SOURCE8} -n %{name}-guest -f %{SOURCE6} -x kdump um xen pae xenpae pv

%description guest-KMP
This package contains the kernel-module for VirtualBox.
##########################################

%package guest-x11
Summary:        VirtualBox X11 drivers for mouse and video
Group:          System/X11/Servers/XF86_4
Requires:       %{name}-guest-kmp = %{version}
Supplements:    modalias(xorg-x11-server:pci:v000080EEd0000BEEFsv*sd*bc*sc*i*)
#rename from xorg-x11-driver-virtualbox-ose:
Provides:       xorg-x11-driver-virtualbox-ose = %{version}
Obsoletes:      xorg-x11-driver-virtualbox-ose < %{version}

%description guest-x11
VirtualBox
This package contains X11 guest utilities and X11 guest mouse and video drivers
###########################################

%package guest-tools
Summary:        VirtualBox guest tools
Group:          System/Emulators/PC
Requires:       %{name}-guest-kmp = %{version}
Supplements:    modalias(pci:v000080EEd0000BEEFsv*sd*bc*sc*i*)
#rename from "ose" version:
Provides:       %{name}-ose-guest-tools = %{version}
Obsoletes:      %{name}-ose-guest-tools < %{version}
Requires(pre):  %insserv_prereq
%if ! 0%{?suse_version} > 1325
Requires(pre):  net-tools-deprecated
%endif

%description guest-tools
VirtualBox guest addition tools.
###########################################

%package -n python-%{name}
Summary:        Python bindings for %{name}
Group:          Development/Libraries/Python
Requires:       %{name} = %{version}
#rename from "ose" version:
Provides:       python-%{name}-ose = %{version}
Obsoletes:      python-%{name}-ose < %{version}

%description -n python-%{name}
Python XPCOM bindings to %{name}. Used e.g. by vboxgtk package.
###########################################

%package devel
Summary:        Devel files for %{name}
Group:          Development/Libraries/Other
Requires:       %{name} = %{version}
Requires:       python-%{name} = %{version}
#rename from "ose" version:
Provides:       %{name}-ose-devel = %{version}
Obsoletes:      %{name}-ose-devel < %{version}

%description devel
Development file for %{name}
###########################################

%package host-source
Summary:        Source files for %{name} host kernel modules
Group:          Development/Sources
Requires:       %{name} = %{version}
Requires:       gcc
Requires:       make
BuildArch:      noarch

%description host-source
Source files for %{name} host kernel modules
These can be built for custom kernels using
cd %{_prefix}/src/kernel-modules/virtualbox ; make ; make install

%package guest-source
Summary:        Source files for %{name} guest kernel modules
Group:          Development/Sources
Requires:       %{name} = %{version}
Requires:       gcc
Requires:       make
BuildArch:      noarch

%description guest-source
Source files for %{name} guest kernel modules
These can be built for custom kernels using
cd %{_prefix}/src/kernel-modules/virtualbox/guest ; make ; make install
###########################################

%package guest-desktop-icons
Summary:        Icons for guest desktop files
Group:          System/Emulators/PC
Requires:       %{name} = %{version}
Recommends:     %{name}-gui = %{version}
BuildArch:      noarch

%description guest-desktop-icons
This package contains icons for guest desktop files that were created on the desktop.
###########################################

%package vnc
Summary:        VNC desktop sharing
Group:          System/Emulators/PC
Requires:       %{name} = %{version}

%description vnc
Virtual Network Computing (VNC) is a graphical desktop sharing system that uses the Remote Frame Buffer
protocol (RFB) to remotely control another computer. When this optional feature is desired, it is installed
as an "extpack" for VirtualBox. The implementation is licensed under GPL.
###########################################

%prep
%setup -q -n VirtualBox-%{version}
%patch1 -p1
%patch2 -p1
%patch3 -p1
%patch4 -p1
%patch6 -p1
%patch8 -p1
%patch9 -p1
%patch10 -p1
%patch99 -p1
%patch100
%patch101 -p1
%patch103 -p1
%patch104 -p1
%patch105 -p1
%patch106 -p1
%patch107 -p1
%patch108 -p1
%patch109 -p1
%patch112 -p1
%patch113 -p1
%if 0%{?sle_version} == 120300
%patch114 -p1
%endif
%patch115 -p1
%patch116 -p1
%patch117 -p1
%patch118 -p1

#copy user manual
cp %{SOURCE1} UserManual.pdf
#copy kbuild config
cp %{SOURCE10} LocalConfig.kmk
#
##########################
####workaround kmk_sed --v
#instead of kmk_sed use /usr/bin/sed because of bug http://svn.netlabs.org/kbuild/ticket/112,
#but we have to create wrapper which will handle --append and --output options which are not provided by /usr/bin/sed
cat >> kmk_sed <<EOF
#!/bin/bash
while [ "\$#" != "0" ]; do
	pass=\${pass}" \$1"
	[ "\$1" == "-e" ] && shift && pass=\${pass}" '\$1'"
	shift
done
eval "sed \$(echo "\$pass" | sed -e "s/--output=/>/g;s/--append=/>/g;s/--output/>/g;s/--append/>>/g");"
EOF
chmod +x ./kmk_sed
echo "SED = $RPM_BUILD_DIR/VirtualBox-%{version}/kmk_sed"  >> LocalConfig.kmk
####workaround kmk_sed --^
##########################
#

%build
#ensure we don't ever use them
rm -rf src/libs/{libpng-*,libxml2-*,libxslt-*,zlib-*,boost-*}

#	--disable-kmods		don't build Linux kernel modules -  but use SUSE specific way see few lines under
# NOT an autoconf configure macro
./configure \
    --ose \
    --enable-vnc \
    --enable-vde \
    --disable-kmods \
    --with-linux="/usr" \
    --disable-java \
    --disable-docs \
    --enable-webservice \
    --with-mkisofs=/bin/true \
    --with-makeself=/bin/true

# configure actually warns we should source env.sh (which seems like it could influence the build...)
source ./env.sh

#
#  	VBOX_PATH_PACKAGE_DOCS set propper path for link to pdf in .desktop file
# 	VBOX_WITH_REGISTRATION_REQUEST= VBOX_WITH_UPDATE_REQUEST= just disable some functionality in gui
echo "build basic parts"
# To keep memory requirements within bounds, limit make to 2 jobs
	%{_bindir}/kmk -j2 \
    VBOX_GCC_WERR= \
    KBUILD_VERBOSE=2 \
    VBOX_USE_SYSTEM_XORG_HEADERS=1 \
    VBOX_WITH_REGISTRATION_REQUEST= VBOX_WITH_UPDATE_REQUEST= \
    TOOL_YASM_AS=yasm \
    VBOX_BUILD_PUBLISHER=_SUSE \
    TOOL_GCC3_CFLAGS="%{optflags}" TOOL_GCC3_CXXFLAGS="%{optflags}" \
    VBOX_GCC_OPT="%{optflags}"

echo "build VNC extension pack"
# tar must use GNU, not POSIX, format here
sed -i 's/tar /tar --format=gnu /' src/VBox/ExtPacks/VNC/Makefile.kmk
kmk -C src/VBox/ExtPacks/VNC packing
pushd out/linux.*/release/packages/
mkdir -p "%{buildroot}%{_datadir}/virtualbox/extensions/"
install -D -m 644 VNC-*.vbox-extpack "%{buildroot}%{_datadir}/virtualbox/extensions/VNC-%{version}.vbox-extpack"
popd
install -D -m 644 "COPYING" "%{buildroot}%{_datadir}/licenses/LICENSE.vnc"

#
# build kernel modules for guest and host (check novel-kmp package as example)
# host  modules : vboxdrv,vboxnetflt,vboxnetadp,vboxpci
# guest modules : vboxguest,vboxsf,vboxvideo
echo "build kernel modules"
for vbox_module in out/linux.*/release/bin/src/vbox{drv,netflt,netadp,pci} \
           out/linux.*/release/bin/additions/src/vbox{guest,sf,video}; do
    #get the module name from path
    module_name=$(basename "$vbox_module")

    # go through the all flavors (desktop,default ...)
    for flavor in %{flavors_to_build}; do
	# delete old build dir for sure
	rm -rf modules_build_dir/${module_name}_${flavor}

	# create build directory for specific flavor
        mkdir -p modules_build_dir/$flavor

	# copy sources which will be used to build vbox module in last step
	cp -r $vbox_module/ modules_build_dir/$flavor/

	# copy vboxdrv (for host) module symbols which are used by vboxnetflt and vboxnetadp km's:
	if [ "$module_name" = "vboxnetflt" -o \
	     "$module_name" = "vboxnetadp" -o \
	     "$module_name" = "vboxpci" ] ; then
	    cp $PWD/modules_build_dir/$flavor/vboxdrv/Module.symvers	\
		  $PWD/modules_build_dir/$flavor/$module_name
	fi
	# copy vboxguest (for guest) module symbols which are used by vboxsf km:
	if [ "$module_name" = "vboxsf" ]; then
	    cp $PWD/modules_build_dir/$flavor/vboxguest/Module.symvers \
	          $PWD/modules_build_dir/$flavor/$module_name
	fi
	# copy vboxguest (for guest) module symbols which are used by vboxvideo km:
	if [ "$module_name" = "vboxvideo" ]; then
	    cp $PWD/modules_build_dir/$flavor/vboxguest/Module.symvers \
	          $PWD/modules_build_dir/$flavor/$module_name
	fi
	# build the module for the specific flavor
	make -j2 -C %{_prefix}/src/linux-obj/%{_target_cpu}/$flavor modules \
		M=$PWD/modules_build_dir/$flavor/$module_name
    done
done

%install
#################################
echo "create directory structure"
#################################
install -d -m 755 %{buildroot}/sbin
install -d -m 755 %{buildroot}%{_bindir}
install -d -m 755 %{buildroot}%{_sbindir}
install -d -m 755 %{buildroot}%{_datadir}/virtualbox/nls
install -d -m 755 %{buildroot}%{_datadir}/pixmaps
install -d -m 755 %{buildroot}%{_datadir}/applications
install -d -m 755 %{buildroot}%{_vbox_instdir}/sdk/bindings/xpcom
install -d -m 755 %{buildroot}%{_vbox_instdir}/components
install -d -m 755 %{buildroot}%{_libdir}/dri
install -d -m 755 %{buildroot}%{_libdir}/xorg/modules/drivers
install -d -m 755 %{buildroot}%{_libdir}/xorg/modules/input
install -d -m 755 %{buildroot}%{_sysconfdir}/default
install -d -m 755 %{buildroot}%{_sysconfdir}/init.d
install -d %{buildroot}%{_unitdir}
install -d %{buildroot}%{_unitdir}/multi-user.target.wants
install -d -m 755 %{buildroot}%{_sysconfdir}/vbox
install -d -m 755 %{buildroot}%{_udevrulesdir}
install -d -m 755 %{buildroot}%{_sysconfdir}/X11/xinit/xinitrc.d

####################################################################################
echo "entering virtualbox-kmp-guest and virtualbox-kmp-host install section"
####################################################################################
export INSTALL_MOD_PATH=%{buildroot}
export INSTALL_MOD_DIR=misc
#Keep the install process from calling mkinitrd. The VB kernel modules are not in initrd. bsc#1052428
export INITRD_IN_POSTTRANS=1
export KMP_NEEDS_MKINITRD=0
#to install modules we use here similar steps like in build phase, go through all the modules :
for module_name in vbox{drv,netflt,pci,netadp,guest,sf,video}
do
	#and through the all flavors
	for flavor in %{flavors_to_build}; do
	#to install modules use Makefile from %{_prefix}/src/linux-obj/%_target_cpu/$flavor and builds from $PWD/modules_build_dir/$flavor/$module_name
    	make -C %{_prefix}/src/linux-obj/%{_target_cpu}/$flavor modules_install M=$PWD/modules_build_dir/$flavor/$module_name
    done
done

###########################################
echo "entering guest-tools install section"
###########################################
install -m 755 out/linux.*/release/bin/additions/VBoxControl %{buildroot}%{_bindir}/VBoxControl
install -m 755 out/linux.*/release/bin/additions/VBoxService %{buildroot}%{_sbindir}/VBoxService
install -m 755 out/linux.*/release/bin/additions/mount.vboxsf %{buildroot}/sbin/mount.vboxsf
install -m 744 src/VBox/Additions/linux/installer/vboxadd-service.sh %{buildroot}%{_vbox_instdir}/vboxadd-service
# udev rule for guest (virtualbox-guest-tools)
install -m 644 %{SOURCE3}			%{buildroot}%{_udevrulesdir}/60-vboxguest.rules
# /media is used for auto-mounting of shared folders
%if 0%{?suse_version} > 1320 || 0%{?sle_version} == 120300
install -d -m 755 %{buildroot}/media
%endif
#
##############################################################
echo "entering guest-x11 install section"
##############################################################
pushd out/linux.*/release/bin/additions/
#VBoxClient daemon (support for clipboard,autoresize,seamless windows)
install -m 755 VBoxClient	%{buildroot}%{_bindir}
# xorg drivers for video
install -m 755 vboxvideo_drv_system.so %{buildroot}%{_libdir}/xorg/modules/drivers/vboxvideo_drv.so
popd
# VBoxOGL* libs for guest-x11 subpackage
install -m 755 out/linux.*/release/bin/additions/VBoxOGL*.so \
						%{buildroot}%{_libdir}
# VBoxEGL* libs for guest-x11 subpackage
install -m 755 out/linux.*/release/bin/additions/VBoxEGL*.so \
						%{buildroot}%{_libdir}
# make link for dri lib
ln -s %{_libdir}/VBoxOGL.so			%{buildroot}%{_libdir}/dri/vboxvideo_dri.so
# install init script which start VBoxClient daemon (support for clipboard,autoresize,seamless windows)
install -m 755 src/VBox/Additions/x11/Installer/98vboxadd-xclient %{buildroot}%{_sysconfdir}/X11/xinit/xinitrc.d/vboxadd-xclient.sh

##############################################
echo "entering virtualbox(-qt) install section"
##############################################
# copy the main files to %{_vbox_instdir}
pushd out/linux.*/release/bin
install -m 755 VBoxManage 			%{buildroot}%{_vbox_instdir}
install -m 755 VBoxHeadless 			%{buildroot}%{_vbox_instdir}
install -m 755 VBoxSDL 				%{buildroot}%{_vbox_instdir}
install -m 755 VBoxTunctl 			%{buildroot}%{_vbox_instdir}
install -m 755 VBoxNetNAT			%{buildroot}%{_vbox_instdir}
install -m 755 VBoxAutostart			%{buildroot}%{_vbox_instdir}
install -m 755 VBoxVolInfo			%{buildroot}%{_vbox_instdir}
install -m 755 vboxshell.py			%{buildroot}%{_vbox_instdir}
install -m 755 VBoxBalloonCtrl			%{buildroot}%{_vbox_instdir}
install -m 755 webtest				%{buildroot}%{_vbox_instdir}
install -m 755 VBoxDTrace			%{buildroot}%{_vbox_instdir}
# create links to vbox tools in PATH - they could be usefull for controlling vbox from command line
ln -s %{_vbox_instdir}/VBoxManage		%{buildroot}%{_bindir}/VBoxManage
ln -s %{_vbox_instdir}/VBoxHeadless 		%{buildroot}%{_bindir}/VBoxHeadless
ln -s %{_vbox_instdir}/VBoxSDL			%{buildroot}%{_bindir}/VBoxSDL
ln -s %{_vbox_instdir}/VBoxTunctl		%{buildroot}%{_bindir}/VBoxTunctl
install -m 755 VBoxSVC 				%{buildroot}%{_vbox_instdir}
install -m 755 VBoxXPCOMIPCD 			%{buildroot}%{_vbox_instdir}
install -m 755 VBoxExtPackHelperApp		%{buildroot}%{_vbox_instdir}
install -m 755 VBoxTestOGL			%{buildroot}%{_vbox_instdir}
install -m 755 VBoxPermissionMessage		%{buildroot}%{_vbox_instdir}
install -m 755 VBoxUSB_DevRules			%{buildroot}%{_vbox_instdir}
install -m 755 VBoxNetDHCP			%{buildroot}%{_vbox_instdir}
install -m 755 VBoxNetAdpCtl			%{buildroot}%{_vbox_instdir}
install -m 755 VirtualBox			%{buildroot}%{_vbox_instdir}
install -m 755 VBoxEFI*.fd			%{buildroot}%{_vbox_instdir}
install -m 755 VBoxSysInfo.sh			%{buildroot}%{_vbox_instdir}
install -m 644 *.so		 		%{buildroot}%{_vbox_instdir}
install -m 644 *.rc 				%{buildroot}%{_vbox_instdir}
install -m 644 *.r0 				%{buildroot}%{_vbox_instdir}
install -m 644 components/*			%{buildroot}%{_vbox_instdir}/components/
# install languages
install -m 644 nls/*				%{buildroot}%{_datadir}/virtualbox/nls/
# install kmp src
mkdir -p %{buildroot}%{_usrsrc}/kernel-modules/virtualbox
mkdir -p %{buildroot}%{_usrsrc}/kernel-modules/additions
# Host and guest kmp sources have duplicate files. Hide this with tar.
tar jcf %{buildroot}%{_usrsrc}/kernel-modules/additions/guest_src.tar.bz2 additions/src
cp -a src %{buildroot}%{_usrsrc}/kernel-modules/virtualbox
install -m 644 %{SOURCE11}			%{buildroot}%{_udevrulesdir}/60-vboxdrv.rules
popd

# install desktop file
install -m 644 out/linux.*/release/bin/virtualbox.desktop %{buildroot}%{_datadir}/applications/%{name}.desktop
%suse_update_desktop_file			%{buildroot}%{_datadir}/applications/%{name}.desktop 'System Emulator'

# create a menu entry
install -m 644 out/linux.*/release/bin/VBox.png %{buildroot}%{_datadir}/pixmaps/virtualbox.png
# install config with session shutdown defs
install -m 644 %{SOURCE4}			%{buildroot}%{_sysconfdir}/default/virtualbox
#install wrapper script
install -m 644 %{SOURCE9}			%{buildroot}%{_bindir}/VirtualBox

# modify and install the vboxdrv init script
#sed -i "s|%{NOLSB}%|yes|g;s|%{DEBIAN}%||g;s|%{PACKAGE}%|virtualbox|g" \
#						src/VBox/Installer/linux/vboxdrv.sh
# Service files to load kernel modules on boot
install -m 0644 %{SOURCE14}			%{buildroot}%{_unitdir}/vboxdrv.service
install -m 0644 %{SOURCE15}			%{buildroot}%{_unitdir}/vboxadd-service.service
install -m 0755 %{SOURCE16}			%{buildroot}/sbin/vboxconfig
install -m 0755 %{SOURCE17}			%{buildroot}/sbin/vboxguestconfig
install -m 0755 %{SOURCE18}			%{buildroot}/sbin/vbox-fix-usb-rules.sh
install -m 0755 %{SOURCE19}			%{buildroot}%{_vbox_instdir}/vboxdrv.sh
install -m 0755 %{SOURCE20}			%{buildroot}%{_vbox_instdir}/vboxes.sh
install -m 0644 %{SOURCE21}			%{buildroot}%{_unitdir}/vboxes.service
ln -s %{_vbox_instdir}/vboxes.sh		%{buildroot}%{_sbindir}/rcvboxes
ln -s %{_vbox_instdir}/vboxdrv.sh		%{buildroot}%{_sbindir}/rcvboxdrv
# Init script to start virtual boxes during boot
ln -sf %{_unitdir}/vboxdrv.service		%{buildroot}%{_unitdir}/multi-user.target.wants/vboxdrv.service
ln -sf %{_unitdir}/vboxadd-service.service	%{buildroot}%{_unitdir}/multi-user.target.wants/vboxadd-service.service
ln -sf %{_unitdir}/vboxes.service		%{buildroot}%{_unitdir}/multi-user.target.wants/vboxes.service
# sysconfig file intended for vboxes script
install -d -m 755 %{buildroot}%{_var}/adm/fillup-templates
install -m 640 %{SOURCE13} %{buildroot}%{_var}/adm/fillup-templates/sysconfig.vbox

# config file for vboxdrv script and vboxweb
install -d -m 755 %{buildroot}%{_sysconfdir}/vbox
echo -e "#settings for vboxwebsrn\nVBOXWEB_USER=root" > %{buildroot}%{_sysconfdir}/vbox/vbox.cfg
# install udev helper script for creating usb devices
install -m 0755 -D src/VBox/Installer/linux/VBoxCreateUSBNode.sh %{buildroot}%{_vbox_instdir}/VBoxCreateUSBNode.sh
######################################################
echo "entering python-virtualbox install section"
######################################################
pushd out/linux.*/release/bin/sdk/installer
VBOX_INSTALL_PATH=%{_vbox_instdir} python vboxapisetup.py install --prefix=%{_prefix} --root=%{buildroot} --record-rpm=%{_tmppath}/SITE_FILES
popd
install -d -m 755 %{buildroot}%{_vbox_instdir}/sdk/bindings/xpcom
cp -r out/linux.*/release/bin/sdk/bindings/xpcom/python %{buildroot}%{_vbox_instdir}/sdk/bindings/xpcom
%py_compile %{buildroot}%{_vbox_instdir}/sdk/bindings/xpcom/python

######################################################
echo "entering virtualbox-devel install section"
######################################################
cp -r out/linux.*/release/bin/sdk/bindings/auth %{buildroot}%{_vbox_instdir}/sdk/bindings

pushd out/linux.*/release/bin/sdk/bindings/xpcom
cp -r include %{buildroot}%{_vbox_instdir}/sdk/bindings/xpcom
cp -r idl %{buildroot}%{_vbox_instdir}/sdk/bindings/xpcom
cp -r samples %{buildroot}%{_vbox_instdir}/sdk/bindings/xpcom
popd

cp out/linux.*/release/bin/sdk/bindings/VirtualBox.xidl %{buildroot}%{_vbox_instdir}/sdk/bindings

######################################################
echo "entering virtualbox-websrv install section"
######################################################
pushd out/linux.*/release/bin
install -m 755 vboxwebsrv %{buildroot}%{_vbox_instdir}
install -m 755 webtest %{buildroot}%{_vbox_instdir}
popd

sed -i "s|%{NOLSB}%|yes|g;s|%{DEBIAN}%||g;s|%{PACKAGE}%|virtualbox|g" src/VBox/Installer/linux/vboxweb-service.sh
install -m 744 src/VBox/Installer/linux/vboxweb-service.sh %{buildroot}%{_sysconfdir}/init.d/vboxweb-service
ln -s %{_sysconfdir}/init.d/vboxweb-service %{buildroot}%{_sbindir}/rcvboxweb-service
#
######################################################
echo "entering virtualbox-guest-desktop-icons install section"
######################################################
install -d -m 755	%{buildroot}%{_datadir}/pixmaps/virtalbox

pushd src/VBox/Frontends/VirtualBox/images
for icon in os_*.png; do
  install -m 644 "$icon" %{buildroot}%{_datadir}/pixmaps/virtalbox/"$icon";
done
popd
#
######################################################
# run fdupes
######################################################
#run fdupes because we lost link for virtualbox/components directory
%fdupes %{buildroot}/%{_vbox_instdir}
#also some translation files are duplicated
%fdupes %{buildroot}/%{_datadir}/virtualbox/nls
#also some icon files are duplicated
%fdupes %{buildroot}/%{_datadir}/pixmaps/virtalbox

#
#
######################################################
# scriptlets - pre
######################################################

%pre
getent group vboxusers >/dev/null || groupadd -r vboxusers
%service_add_pre vboxdrv.service

%pre guest-tools
# Add groups for seamless mode and shared folders:
getent group vboxguest >/dev/null || groupadd -r vboxguest
getent group vboxsf >/dev/null || groupadd -r vboxsf
%service_add_pre vboxadd.service

#######################################################
# scriptlets - post
#######################################################

%post
/sbin/ldconfig
#setup our sysconfig file /etc/sysconfig/vbox
%set_permissions %{_vbox_instdir}/VBoxNetDHCP
%set_permissions %{_vbox_instdir}/VBoxNetAdpCtl
%set_permissions %{_vbox_instdir}/VBoxHeadless
%set_permissions %{_vbox_instdir}/VBoxSDL
%service_add_post vboxdrv.service

%post qt
%set_permissions %{_vbox_instdir}/VirtualBox

%verifyscript
%verify_permissions -e %{_vbox_instdir}/VBoxNetDHCP
%verify_permissions -e %{_vbox_instdir}/VBoxNetAdpCtl
%verify_permissions -e %{_vbox_instdir}/VBoxHeadless
%verify_permissions -e %{_vbox_instdir}/VBoxSDL

%verifyscript qt
%verify_permissions -e %{_vbox_instdir}/VirtualBox

%post guest-tools
%service_add_post vboxadd-service.service

%post websrv

%post vnc
EXTPACK="/usr/share/virtualbox/extensions/VNC-%{version}.vbox-extpack"
ACCEPT="$(tar --to-stdout -xf "${EXTPACK}" ./ExtPack-license.txt | sha256sum | head --bytes=64)"
VBoxManage extpack install --replace "${EXTPACK}" --accept-license="${ACCEPT}" > /dev/null

#######################################################
# scriptlets preun
#######################################################

%preun
%stop_on_removal vboxdrv
%service_del_preun vboxdrv.service
exit 0

%preun guest-tools
%stop_on_removal vboxadd-service
%stop_on_removal vboxadd
%service_del_preun vboxadd-service.service
exit 0

%preun websrv
%stop_on_removal vboxweb-service
exit 0

#######################################################
# scriptlets postun
#######################################################

%postun
/sbin/ldconfig
%restart_on_update vboxdrv
%insserv_cleanup
# immediately restarting virtualbox may not work. As such wait for the next reboot to restart
export DISABLE_RESTART_ON_UPDATE=yes
%service_del_postun vboxdrv.service

%postun guest-tools
%restart_on_update vboxadd
%restart_on_update vboxadd-service
%insserv_cleanup
%service_del_postun vboxadd-service.service

%postun websrv
%restart_on_update vboxweb-service
%insserv_cleanup
#
#######################################################

%files
%defattr(-, root, root)
%doc UserManual.pdf
%{_bindir}/VBoxManage
%{_bindir}/VBoxHeadless
%{_bindir}/VBoxSDL
%{_bindir}/VBoxTunctl
%dir %{_vbox_instdir}
%{_vbox_instdir}/VBoxAutostart
%{_vbox_instdir}/VBoxBalloonCtrl
%{_vbox_instdir}/VBoxDTrace
%{_vbox_instdir}/VBoxNetNAT
%{_vbox_instdir}/VBoxVolInfo
%{_vbox_instdir}/vboxshell.py
%{_vbox_instdir}/VBoxSysInfo.sh
%{_vbox_instdir}/VBoxDD2.so
%{_vbox_instdir}/VBoxDD.so
%{_vbox_instdir}/VBoxDDU.so
%{_vbox_instdir}/VBoxGuestControlSvc.so
%{_vbox_instdir}/VBoxGuestPropSvc.so
%{_vbox_instdir}/VBoxHeadless.so
%{_vbox_instdir}/VBoxKeyboard.so
%{_vbox_instdir}/VBoxNetDHCP.so
%{_vbox_instdir}/VBoxNetNAT.so
%{_vbox_instdir}/VBoxOGLhostcrutil.so
%{_vbox_instdir}/VBoxOGLhosterrorspu.so
%{_vbox_instdir}/VBoxOGLrenderspu.so
%{_vbox_instdir}/VBoxREM*.so
%{_vbox_instdir}/VBoxRT.so
%{_vbox_instdir}/VBoxSDL.so
%{_vbox_instdir}/VBoxSharedClipboard.so
%{_vbox_instdir}/VBoxSharedCrOpenGL.so
%{_vbox_instdir}/VBoxSharedFolders.so
%{_vbox_instdir}/VBoxVMM.so
%{_vbox_instdir}/VBoxXPCOMC.so
%{_vbox_instdir}/VBoxXPCOM.so
%{_vbox_instdir}/VBoxDD2RC.rc
%{_vbox_instdir}/VBoxDDRC.rc
%{_vbox_instdir}/VMMRC.rc
%{_vbox_instdir}/VBox*.r0
%{_vbox_instdir}/VMMR0.r0
%{_vbox_instdir}/VBoxEFI*.fd
%{_vbox_instdir}/VBoxManage
%{_vbox_instdir}/VBoxSVC
%{_vbox_instdir}/VBoxTunctl
%{_vbox_instdir}/VBoxXPCOMIPCD
%{_vbox_instdir}/VBoxExtPackHelperApp
%{_vbox_instdir}/DbgPlugInDiggers.so
%{_vbox_instdir}/VBoxAuth.so
%{_vbox_instdir}/VBoxAuthSimple.so
%{_vbox_instdir}/VBoxDbg.so
%{_vbox_instdir}/VBoxDragAndDropSvc.so
%{_vbox_instdir}/VBoxVMMPreload.so
#todo:double check - if this file should be assigned to the host side
%{_vbox_instdir}/VBoxHostChannel.so
%dir %{_vbox_instdir}/components
%{_vbox_instdir}/components/*.so
%{_vbox_instdir}/components/*.xpt
%dir %{_datadir}/virtualbox
%config %{_sysconfdir}/default/virtualbox
%dir /usr/lib/virtualbox
%dir %{_unitdir}
%dir %{_unitdir}/multi-user.target.wants
/usr/lib/virtualbox/vboxdrv.sh
/usr/lib/virtualbox/vboxes.sh
%{_unitdir}/vboxdrv.service
%{_unitdir}/vboxes.service
%{_unitdir}/multi-user.target.wants/vboxdrv.service
%{_unitdir}/multi-user.target.wants/vboxes.service
%dir %{_sysconfdir}/vbox
%config %{_sysconfdir}/vbox/vbox.cfg
%{_var}/adm/fillup-templates/sysconfig.vbox
%{_sbindir}/rcvboxes
%{_sbindir}/rcvboxdrv
/sbin/vboxconfig
%{_vbox_instdir}/VBoxCreateUSBNode.sh
#%verify(not mode) %attr(4750,root,vboxusers) %{_vbox_instdir}/VBoxNetNAT
%verify(not mode) %attr(4750,root,vboxusers) %{_vbox_instdir}/VBoxNetDHCP
%verify(not mode) %attr(4750,root,vboxusers) %{_vbox_instdir}/VBoxNetAdpCtl
%verify(not mode) %attr(4750,root,vboxusers) %{_vbox_instdir}/VBoxHeadless
%verify(not mode) %attr(4750,root,vboxusers) %{_vbox_instdir}/VBoxSDL

%files qt
%defattr(-, root, root)
%attr(0755,root,vboxusers) %{_vbox_instdir}/VBoxPermissionMessage
%attr(0755,root,vboxusers) %{_vbox_instdir}/VBoxUSB_DevRules
%verify(not mode) %attr(4750,root,vboxusers) %{_vbox_instdir}/VirtualBox
#wrapper script is in bindir
%attr(0755,root,root) %{_bindir}/VirtualBox
#script to rules is in /sbin
%attr(0755,root,root) /sbin/vbox-fix-usb-rules.sh
#ldd shows libQt* dependency
%{_vbox_instdir}/VBoxTestOGL
#qm's translations
%{_datadir}/virtualbox/nls
%{_vbox_instdir}/VirtualBox.so
%{_datadir}/pixmaps/virtualbox.png
%{_datadir}/applications/%{name}.desktop
%{_udevrulesdir}/60-vboxdrv.rules

%files guest-x11
%defattr(-, root, root)
%dir %{_libdir}/xorg/modules/drivers
%dir %{_libdir}/xorg/modules/input
%dir %{_libdir}/dri/
%{_bindir}/VBoxClient
%{_libdir}/VBoxOGL*.so
%{_libdir}/VBoxEGL*.so
%{_libdir}/xorg/modules/drivers/vboxvideo_drv.so
%{_libdir}/dri/vboxvideo_dri.so
%{_sysconfdir}/X11/xinit/xinitrc.d/vboxadd-xclient.sh

%files guest-tools
%defattr(-, root, root)
%{_bindir}/VBoxControl
%{_sbindir}/VBoxService
/sbin/vboxguestconfig
/sbin/mount.vboxsf
%{_udevrulesdir}/60-vboxguest.rules
%{_vbox_instdir}/vboxadd-service
%{_unitdir}/vboxadd-service.service
%{_unitdir}/multi-user.target.wants/vboxadd-service.service
%if 0%{?suse_version} > 1320 || 0%{?sle_version} == 120300
%dir /media
%endif

%files -n python-%{name} -f %{_tmppath}/SITE_FILES
%defattr(-, root, root)
%dir %{_vbox_instdir}/sdk
%dir %{_vbox_instdir}/sdk/bindings
%dir %{_vbox_instdir}/sdk/bindings/xpcom
%{_vbox_instdir}/sdk/bindings/xpcom/python
%attr(0755, root, root) %{_vbox_instdir}/VBoxPython2_7.so

%files devel
%defattr(-,root, root)
%dir %{_vbox_instdir}/sdk
%dir %{_vbox_instdir}/sdk/bindings
%dir %{_vbox_instdir}/sdk/bindings/xpcom
%{_vbox_instdir}/sdk/bindings/VirtualBox.xidl
%{_vbox_instdir}/sdk/bindings/xpcom/idl
%{_vbox_instdir}/sdk/bindings/xpcom/include
%{_vbox_instdir}/sdk/bindings/xpcom/samples
%{_vbox_instdir}/sdk/bindings/auth

%files host-source
%defattr(-,root, root)
%dir %{_usrsrc}/kernel-modules
%{_usrsrc}/kernel-modules/virtualbox

%files guest-source
%defattr(-,root, root)
%dir %{_usrsrc}/kernel-modules
%dir %{_usrsrc}/kernel-modules/additions
%{_usrsrc}/kernel-modules/additions/guest_src.tar.bz2

%files websrv
%defattr(-,root, root)
%{_vbox_instdir}/vboxwebsrv
%{_vbox_instdir}/webtest
%{_sysconfdir}/init.d/vboxweb-service
%{_sbindir}/rcvboxweb-service

%files guest-desktop-icons
%defattr(-,root, root)
%dir %{_datadir}/pixmaps/virtalbox
%{_datadir}/pixmaps/virtalbox/*.png

%files vnc
%defattr(-,root, root)
%dir %{_datadir}/virtualbox/extensions
%{_datadir}/virtualbox/extensions/VNC-%{version}.vbox-extpack
%dir %{_datadir}/licenses
%{_datadir}/licenses/LICENSE.vnc

%changelog
* Tue Aug 15 2017 Larry.Finger@lwfinger.net
- Corrected typo in bug report number.
* Mon Aug 14 2017 Larry.Finger@lwfinger.net
- Bring the Leap 42.3 version up to the level of the Factory build. Changes include
  Update vboxconfig.sh to fix problems noted in bsc#1042726
  Disable pae build for 32-bit kernels.
  Added missing commands to keep mkinitrd from being called twice during installation of host kernel modules. bsc#1052428.
* Mon Aug  7 2017 schwab@suse.de
- internal-headers.patch: fix invalid use of internal headers, enable
  POSIX extensions
* Thu Aug  3 2017 hpj@urpla.net
- reorganize vbox autostart, coping with systemd:
  - add /usr/lib/virtualbox/vboxes.sh (based on /etc/init.d/vboxes)
  - add /usr/lib/systemd/system/vboxes.service
  - remove /etc/init.d/vboxes
* Sun Jul 30 2017 Larry.Finger@lwfinger.net
- Version bump to 5.1.26 (released 2017-07-27 by Oracle)
  This is a maintenance release. The following items were fixed and/or added:
    VMM: reset the TSC on VM reset to work around a Windows bug (bug #16643)
    Audio: fixed memory leak when enabled with VRDP connections (5.1.24 regression; bug #16928)
    Audio: fixed creation of too many sound sinks on Linux hosts when using the PulseAudio backend (bug #16938)
    Audio: implemented record gain registers for AC'97 emulation; those are needed for newer Ubuntu guests which rely on those when controlling gain and muting the recording (capturing) levels
    Storage: fixed hang when using the emulated NVMe controller with the SPDK (bug #16945)
    Mouse: double click was not working with a precision touchpad (bug #14632)
    Linux hosts: properly bring up host-only network interfaces with iproute (5.1.24 regression; bug #16911)
    Linux hosts: provide Python 3 libraries for deb/rpm packages
    Windows guests: fixed automatic logons for Vista and newer Windows guests (5.1.24 regression; bug #16921)
* Thu Jul 20 2017 Larry.Finger@lwfinger.net
- Initial submission to openSUSE:Leap:42.3:Update.
* Wed Jul 19 2017 Larry.Finger@lwfinger.net
- File "vbox_fix_for_kernel_4.12.patch" removed as these changes are fixed upstream.
- File "vbox_fix_for_kernel_4.13.patch" removed as these changes are fixed upstream.
- Version bump to 5.1.24 (released 2017-07-18 by Oracle)
  This is a maintenance release. The following items were fixed and/or added:
    VMM: mask the VME CPUID capability on AMD Ryzen processors for now to make certain guests works, for example Windows XP
    VMM: emulate more SSE2 instructions
    VMM: properly clear the TF and AC flags when dispatching real-mode interrupts
    GUI: fixes to make the mini-toolbar work with recent versions of KDE / Plasma (bug #16325)
    GUI: fixed a potential crash when a VM with multiple screens is running in full screen / seamless mode and a host screen is removed, for example when connecting to the host via RDP
    GUI: fixed initial size hints for guests which set intermediate sizes before responding (bug #16593)
    GUI: prevent stopped screen updates or black screen on reboot in a multi-screen setup under certain conditions
    Audio: many improvements for Windows 10 guests (bugs #15189, #15925, #16170, #16682, #16794 and others)
    Storage: fixed possible crash when using Intels SPDK
    API: use the correct file name of the VM machine state if the VM settings directory is renamed, for example during grouping / ungrouping a VM (bugs #16075 and #16745)
    API: return the correct error code if powering up a VM fails
    API: video recording did not automatically start at VM start when enabled in the VM settings (bug #16803)
    API: when relocating a medium, check that the target path is fully qualified
    EFI: fix for VMs with more than 3504MB RAM (bug #11103)
    Host-only adapter: correctly determine IPv4 netmasks on Windows hosts (bug #16826)
    NAT network: properly do the refcounting for starting / stopping the NAT / DHCP services if the NAT network is changed while the adapter network connection type is anything else but NAT network
    VBoxManage: fixed controlvm videocapfile (bug #16779)
    Linux / Mac OS X hosts: more fixes for loading shared libraries (5.1.20 regression; bugs #16778, #16693)
    Linux hosts / guests: Linux 4.12 fixes (bugs #16725, #16800)
    Linux hosts / guests: reduce the kernel stack consumption for Linux kernels with CONFIG_CPUMASK_OFFSTACK defined
    Linux hosts / guests: fixes for kernel modules built with gcc-7 (bug #16772)
    Linux hosts / guests: Linux 4.13 fix (bug #16887)
    Linux hosts: don't depend on net-tools on newer distributions as this package is deprecated in favour of iproute (bug #16764)
    Linux hosts: make 2D video acceleration available for older Linux distributions (5.1 regression; bug #16858)
    Linux Additions: fix for dynamic resizing with Oracle Linux 6 with UEK4
    Linux Additions: make Fedora 25 and 26 Alpha work when 3D pass-through is enabled
    Linux Additions: no longer recommend removing distribution- installed Additions if they are updated to our guidelines
* Tue Jul 18 2017 Larry.Finger@lwfinger.net
- In kernel 4.13, wait_queue_t => wait_queue_entry_t. File "vbox_fix_for_kernel_4.13.patch" patches the source to account for this change.
* Mon Jul 10 2017 Larry.Finger@lwfinger.net
- Fix several problems with the startup scripts. The SysV form is no longer used for most packages as proper systemd
  service files have been created. These fixes address bsc#1037291, #1043532, and #1045871.
- Increase reserved disk space from 4 to 5 GB. This change was suddested as a fix for the 32-bit failures.
* Fri Jun 30 2017 Larry.Finger@lwfinger.net
- Fix missing global for 32-bit version with gcc7. (bsc#1046571).
  Fix missing frame buffer cleanup - private communication from Oracle - adds file "fix_KMS_support.patch".
* Sun Jun 25 2017 Larry.Finger@lwfinger.net
- Fix logic error in scripts to build kernel modules locally - see bnc#1042726.
  Fix "requires" for net-tools-deprecated so that Leap 42.3 will build.
  Fix missing /media for Leap 42.3.
  Fix typo in above changes.
* Sun Jun 25 2017 Larry.Finger@lwfinger.net
- Fix some typos in the various service files as noted in boo#1044931.
  With these fixes, TW guests start correctly. In addition, the /sbin/vboxconfig (for hosts) and the
  /sbin/vboxguestconfig (for guests) work correctly.
* Wed Jun 21 2017 Larry.Finger@lwfinger.net
- Now that kernel:HEAD:standard has changed to version 4.12.0-rcX, the VB drivers need some changes for new API's.
  File "vbox_fix_for_kernel_4.12.patch" is added.
  The added installation of "net-tools-deprecated" broke builds for Leap 42.3. That change is now conditional on building for Factory.
* Sat Jun 10 2017 Larry.Finger@lwfinger.net
- Add installation of package "net-tools-deprecated" as requested in boo#1027742.
* Thu Jun  8 2017 Larry.Finger@lwfinger.net
- Revise warning screen concerning USB passthru - fixes bnc#1041137.
  USB passthru opens a security hole, yet it is so valuable that many users want the feature, thus it is our default.
  Previously, a user needed to edit a udev rule to disable passthru. The bad part was that an update of VB changed the
  rule back to allow passthru without any notification. These changes modify the popup to allow the user to accept or decline
  passthru. If the user declines, then the root password is requested and the udev rule is modified. As these modifications will be
  lost with the next VB update, the inode of the udev rule is kept. If the user has previously declined and the inode has changed,
  the popup will show the next time VB is started. File "fix_usb_rules.sh" is added.
* Sun May 21 2017 hpj@urpla.net
- add %%dir /usr/share/licenses to new vnc package
* Wed May 17 2017 Larry.Finger@lwfinger.net
- Made changes to build with gcc 7.x. This adds new file "vbox_fix_for_gcc7.patch".
  Changed the building of VBoxVNC to remove the hack used earlier.
* Wed May 10 2017 Larry.Finger@lwfinger.net
- Make a number of changes:
  * Add VBoxVNC as a proper external pack rather than just make the so available (bnc #1037033). Thanks to Michal Nowak for most of this effort.
    One hack was required to work around a bug in "VBoxManage extpack install" whereby the --accept-license option failed to work.
  * Improve startup of VirtualBox through use of systemd service files:
    a. Beginning with Oracle version 5.0.8, the command used to build the kernel modules outside of the RPM packaging
    code changed; however, the openSUSE version did not implement the new method. That new code is now implemented.
    b. In Tumbleweed, the SysV init scripts to systemd service files stopped working. Part of the new code also checks
    to see if the kernel modules are loaded. If not, new script files are called to include the necessary packages
    and build the necessary modules.
    c. The hooks are in place to remove the sysv init files and do the complete conversion to systemd. This step will
    be done at a later time.
  * New files are "vboxconfig.sh", "vboxguestconfig.sh", "vboxdrv.service", and "vboxadd-service.service".
  * New sub-packages virtualbox-guest-source and virtualbox-vnc are produced.
  * Some typos in virtualbox.spec are fixed.
* Thu May  4 2017 Larry.Finger@lwfinger.net
- Add libelf-devel to build. Fixes bnc #1037511.
  Modified the startup files to build the kernel modules if they are missing. Files "vboxconfig.sh" and "vboxguestconfig" added.
* Sat Apr 29 2017 Larry.Finger@lwfinger.net
- Version bump to 5.1.22 (released 2017-04-28 by Oracle)
  This is a maintenance release. The following items were fixed and/or added:
  VMM: fixed VERR_IEM_INSTR_NOT_IMPLEMENTED Guru Meditation under certain conditions (5.1 regression; mostly Mac OS X hosts; bugs #15693, #15801, #16274, #16569, #16663)
  VMM: fixed software virtualization on Solaris hosts (5.1.20 regression)
  Storage: fixed a potential hang under rare circumstances (bug #16677)
  Storage: fixed a potential crash under rare circumstances (asynchronous I/O disabled or during maintenance file operations like merging snapshots)
  Linux hosts: make the ALSA backend work again as well as loading the GL libraries on certain hosts (5.1.20 regression; bugs #16667, #16693)
  Linux Additions: fixed mount.vboxsf symlink problem (5.1.20 regression; bug #16670)
* Sat Apr 29 2017 Larry.Finger@lwfinger.net
- VirtualBox has always been started by systemd utilizing the old-style scripts in /etc/init.d.
  These should be converted to the service files native to systemd. This issue has been forced
  as a recent update to Tumbleweed broke the startup of VB for both TW hosts and guests. This
  change starts the conversion to native systemd files. The original scripts are still used; however,
  service files are used to start and stop the VB components. In a later change, all action will
  be accomplished using systemd service files.
  Two new files named "vboxdrv.service" and "vboxadd-service.service" are added.
* Thu Apr 20 2017 Larry.Finger@lwfinger.net
-  Fixes for CVE-2017-3561, CVE-2017-3563, CVE-2017-3576, CVE-2017-3558, CVE-2017-3587
    CVE-2017-3559, CVE-2017-3575, CVE-2017-3538, CVE-2017-3513
  Version bump to 5.1.20 (released 2017-04-18 by Oracle)
  This is a maintenance release. The following items were fixed and/or added:
    GUI: don't check if the Extension Pack is up-to-date if the user is about to install a new Extension Pack (bug #16317)
    GUI: fixed a possible crash when switching a multi-monitor VM into full-screen or seamless mode
    GUI: several mini-toolbar fixes in full-screen / seamless mode (X11 hosts only)
    GUI: don't crash on restoring defaults in the appliance import dialog
    Windows Additions: another fix for automatic logins for Windows Vista and newer (bug #15904)
    ICH9: fix for Windows guests with a huge amount (>64G) of guest memory
    BIOS: fixed El Torito hard disk emulation geometry calculation (thanks Dwight Engen)
* Sat Apr  8 2017 Larry.Finger@lwfinger.net
- Add File "vbox_fix_42.3_api.patch" to handle the get_user_pages() API change in Leap 42.3.
* Tue Mar 28 2017 Larry.Finger@lwfinger.net
- Package VBoxVNC.so. This extension is already being built, just not packaged.
  This feature is requested in bsc #1024671.
* Thu Mar 16 2017 Larry.Finger@lwfinger.net
- Version bump to 5.1.18 (released 2017-08-15 by Oracle)
  This is a maintenance release. The following items were fixed and/or added:
    Shared Folders: fixed case insensitive filename access (5.1.16 regression; Windows guests only; bug #16549)
    Shared Folders: fixed access to long pathes (5.1.16 regression; Windows guests only; bugs #14651, #16564)
    API: fixed snapshot handling of medium attachments and PCI device attachments (bug #16545)
    API: make 32-bit Windows guests in raw mode boot again if the ICH9 chipset is used (5.1.16 regression)
    VBoxBugReport: fixed VM log collection issue
    Linux hosts: fixed autostart service script (bug #14955)
    Windows Additions: fixed automatic logins for Windows Vista and newer (5.1.4 regression; bug #15904)
* Thu Mar  9 2017 Larry.Finger@lwfinger.net
- Removed "vbox_fix_4.10_api_changes.patch" - fixed upstream
  Removed "vbox_fix_4.11_api_changes.patch" - fixed upstream
- Version bump to 5.1.16 (released 2017-03-08 by Oracle)
  This is a maintenance release. The following items were fixed and/or added:
    VMM: don't access the MSR_IA32_SMM_MONITOR_CTL MSR if dual-monitor treatment is not available (KVM workaround, bug #14965)
    VMM: another fix for handling certain MSRs on ancient CPUs without VT-x support for MSR bitmaps
    VMM: fixed VERR_SSM_LOAD_CPUID_MISMATCH errors when restoring a saved state with SMP guests on hosts without the CPUID/HTT bit set (bug #16428)
    VMM: fixed a bug in call gate emulation
    VMM: FWAIT instruction fix
    VMM: fixed a sporadic guest hang under certain conditions
    GUI: hide the mini-toolbar from the taskbar and the pager on certain X11 hosts
    GUI: better error handling on the global settings / network / host-only / DHCP server settings
    GUI: fixes for full-screen with multiple screens
    Host-only Network: fixed host-only adapter creation issue preventing VirtualBox installation on Windows 10 hosts (bug #16379)
    NAT network: fixed two potential crashes in the DHCP server
    ICH9: fixed incorrect initialization of the primary bus for PCI bridges (5.1.14 regression)
    Storage: LsiLogic fix for Windows 10
    USB: fixed not being able to attach certain USB devices having invalid characters in the device strings (5.0.18 regression; bug #15956)
    USB: several fixes for the USB/IP support (bug #16462)
    VBoxSVC: fixed another crash during shutdown under rare circumstances
    VBoxSVC: fixed a stack overflow on (Windows debug builds only; bug #16409)
    OVF: when importing an appliance handle more than 10 network adapters if the OVA was created by VirtualBox (bug #16401)
    OVF: fixes for exporting and importing appliances with many disks (bug #16402)
    VBoxManage: fixed regression with modifyhd --resize (bug #16311)
    rdesktop-vrdp: source code tarball fixes
    Linux Installers: do not rebuild kernel modules unnecessarily (bug #16408)
    Linux hosts: added an action for opening the VM manager window to the .desktop file
    Linux hosts / guests: Linux 4.11 compile fixes (bug #16506)
    Linux Additions: added vboxsf FS modules alias (bug #16404)
    Linux Additions: fix for the shared folders kernel module to compile on Linux 4.10
    Linux Additions: properly install the Linux kernel module override rule on distributions without /etc/depmod.d
    Windows Additions: fixed a crash with recent Windows 10 builds if 3D is disabled (bug #15973)
* Wed Mar  8 2017 Larry.Finger@lwfinger.net
- Fix API changes for kernel 4.11. This change adds file "vbox_fix_4.11_api_changes.patch".
  Make some changes to various script files to remove reference to run level 4, which is not used.
* Sat Mar  4 2017 Larry.Finger@lwfinger.net
- Fix for missing global in vboxsf that prevented mounting shared folders
  for kernel 4.10.  This change is the fix for bsc #1027967.
* Tue Feb 28 2017 dimstar@opensuse.org
- Do not proivde libGL.so.1 and libEGL.so.1 symbols into the rpm
  database.
* Sun Feb 26 2017 Larry.Finger@lwfinger.net
- The fix for 3D acceleration only works for Gmome desktops. KDE desktops fail. Accordingly,
  3D acceleration must still be disabled "out-of-the-box". File /etc/init.d/vboxadd contains
  comments on the modifications needed to turn 3D acceleration on, thus Gnome users may turn
  it on selectively.
* Fri Feb 24 2017 Larry.Finger@lwfinger.net
- Fix 3D acceleration as reported in bsc #1024934. The steps needed are as follows:
  - Remove file "vbox_prevent_wrong_SONAME.patch" - the original SONAME values are needed for
    libGL.so.1 and libEGL.so.1 to be replaced by VBoxOGL.so and VBoxEGL.so, respectively.
  - Package VBoxEGL.so
* Thu Feb 23 2017 kukuk@suse.de
- Require insserv and fillup by the packages who call it in the
  pre/post install sections
* Thu Feb  2 2017 adam.majer@suse.de
- use individual libboost-*-devel packages instead of boost-devel
* Sat Jan 28 2017 Larry.Finger@lwfinger.net
- Removed "vbox_fix_4.9_api_changes.patch" as changes are upstream.
  Fixed API changes for kernel 4.10 in "vbox_fix_4.10_api_changes.patch".
* Wed Jan 25 2017 Larry.Finger@lwfinger.net
- The version bump to 5.1.14 also addresses boo#1020856 CVE-2017-3316 CVE-2017-3332 CVE-2017-3290 CVE-2016-5545
- Version bump to 5.1.14 (released 2017-01-17 by Oracle)
  This is a maintenance release. The following items were fixed and/or added:
    VMM: fixed emulation of certain instructions for 64-bit guests on 32-bit hosts
    VMM: properly handle certain MSRs for 64-bit guests on ancient CPUs without VT-x support for MSR bitmaps (bug #13886)
    GUI: fixed a crash with multimonitor setups under certain conditions
    GUI: allow cloning of snapshots when the VM is running
    NVMe: fixed compatibility with the Storage Performance Development Kit (SPDK, bug #16368)
    VBoxSVC: fixed a crash under rare circumstances
    VBoxManage: added a sanity check to modifymedium --resize to prevent users from resizing their hard disk from 1GB to 1PB (bug #16311)
    Windows hosts: another fix for recent Windows 10 hosts
    Linux hosts: Linux 4.10 fixes
    Linux Additions: fixed protocol error during certain operations on shared folders (bug #8463)
* Sat Jan 14 2017 Larry.Finger@lwfinger.net
- The printing of the warning about the insecurity in USB passthru had been lost. As most people are likely to want that feature,
  the logic has been inverted. Now, the required udev commands to allow passthru are included. The first time that VB is started,
  the user will get a screen that points to the bug entry discussing the problem and states what they should do to block the
  insecure usage. In any case, that screen will only be printed once. File "virtualbox-60-vboxdrv.rules" has been added
  These changes address the issues in bnc #1018340.
* Wed Dec 21 2016 Larry.Finger@lwfinger.net
- Version bump to 5.1.12 (released 2016-12-20 by Oracle)
  This is a maintenance release. The following items were fixed and/or added:
    VMM: fixed VERR_IEM_ASPECT_NOT_IMPLEMENTED Guru Meditations with certain Linux guests if KVM paravirtualization is enabled (5.1 regression; bugs #15613 and #16251)
    VMM: fixed VERR_VMX_UNABLE_TO_START_VM Guru Meditations under rare conditions
    GUI: prevent a crash under certain conditions if the VM is terminated very early
    GUI: fixed certain keyboard capture issues (5.1.10 regression; Mac OS X hosts only; bug #16150)
    GUI: fixed dragging guest windows in seamless mode with the keyboard captured (X11 hosts only; bug #15837)
    GUI: fixed a problem where the new version detected dialog was covered by the appliance import dialog (Mac OS X hosts only; bug #16238)
    Storage: fixed NVMe reset processing when doing rmmod nvme; modprobe nvme in a Linux guest (bug #16080)
    Storage: fixed creating a snapshot when the VM is running and an NVMe controller is present
    Storage: fixed a problem with the LsiLogic SCSI controller where requests could be lost with SMP guests
    E1000: fixed "cable disconnected" issue (Mac OS X guests only; 5.1.10 regression; bug #16260)
    E1000: fixed "TX unit hang" issue (Linux guests only; 5.1.10 regression; bug #16221)
    API: don't crash when sanitizing certain VM names (bug #16299)
    Linux hosts: automatically disable asynchronous I/O on Linux 2.6.18 kernels as high I/O load may trigger kernel oopses on these kernels if this feature is enabled
    Linux hosts / guests: Linux 2.6.28 compile fix (bug #16267)
    Linux hosts: compile Linux 4.9 compile fix (bug #16286)
    Linux Additions: warn the user about a known bug with older Linux guests (e.g. Debian 7) requiring manual work to get 3D working (bug #15319)
    Linux Additions: fix the graphics driver build with Linux 4.10 and later (bug #16298)
    Windows Additions: fixed a crash in the WDDM driver under certain conditions
* Mon Dec 12 2016 Larry.Finger@lwfinger.net
- Revert "vbox_hdpi_support.patch. This patch may improve things for asn@cryptomilk.org, but it breaks other systems.
  See https://forums.opensuse.org/showthread.php/521520-VirtualBox-interface-scaling and bsc #1014694.
* Mon Dec  5 2016 Larry.Finger@lwfinger.net
- I now have the necessary preprocessor symbol to modify the source depending on whether the server is 1.19.0 or greater.
  It is no longer necessary to detect the server version in the spec file, thus the solution is cleaner.
* Mon Dec  5 2016 Larry.Finger@lwfinger.net
- Leap 42.2 still has server v. 1.18.3, thus the test failed. The test has been changed to look at only the 1.xx part of the version.
* Sun Dec  4 2016 Larry.Finger@lwfinger.net
- Add patch file "Fix_for_server_1.19.patch" to support xorg-x11-server v. 1.19.0.
  The spec file now interrogates the rpm for the server and conditionally applies the patch, thus both versions build OK.
* Wed Nov 30 2016 asn@cryptomilk.org
- Add patch file "vbox_hidpi_support.patch" to add support for HiDPI in the
  management frontend.
  (This does not fix rendering in guest windows)
* Mon Nov 21 2016 Larry.Finger@lwfinger.net
- Version bump to 5.1.10 (released 2016-11-21 by Oracle)
  This is a maintenance release. The following items were fixed and/or added:
    GUI: the USB filter settings dialog should allow to specify the USB revision in hexadecimal format (bug #15400)
    GUI: fixed crash on certain hosts when pressing certain key combinations (Windows hosts only; bug #15719)
    GUI: fixed issue with updating the available-geometry on host-screen work-area resize
    GUI: don't crash / hang on certain environments if accessibility support is enabled
    GUI: fixed various issues in Unscaled HiDPI Output mode (bug #15707)
    GUI: extend the VM Input menu with Print Screen-related actions
    GUI: improved handling of inserting the Guest Additions ISO image by trying all available optical drives rather than only the first one and by not asking the user if he wants to force unmounting (which doesn't work in most cases anyway)
    API: default to RTC using UTC for Solaris 11 guests
    Settings: be less restrictive when reading a VM configuration containing a host-only adapter without an interface name
    Storage: fixed resizing VDI images resulting in an unbootable image under certain circumstances (bug #15983)
    NAT: fixed several 5.1.8 regressions on Mac OS X and Windows hosts (bug #16084)
    Audio: fixed a few 5.1.x regressions by using the audio code from 5.0.x until the audio overhaul is completed
    VBoxManage: fixed documentation of the storagectl command (bug #15971)
    Build system: another fix for building VirtualBox on systems which default to Python 3
    Windows hosts: hardening fix for Windows 10 build 14971 (bug #16202)
    Windows Additions: properly start the VirtualBox guest services even if the guest user name contains special characters (bug #15982)
    Solaris Additions: fixed preemptible mouse notification callback being executed under a spinlock for Solaris guests
    Linux hosts / guests: Linux 4.9 fixes (bugs #16155 and #16064)
    Linux Additions: fixed Linux kernel module override rule (thanks Mark Furneaux)
* Tue Nov  1 2016 Larry.Finger@lwfinger.net
- Remove all references to libreadline. I misinterpreted a previous error message.
- Fixes for VUL-0: CVE-2016-5501,CVE-2016-5538,CVE-2016-5605,CVE-2016-5608,CVE-2016-5610,CVE-2016-5611,CVE-2016-561313
  boo #1005621.
* Sun Oct 30 2016 Larry.Finger@lwfinger.net
- Replaced libreadline6 with libreadline7.
* Wed Oct 26 2016 Larry.Finger@lwfinger.net
- Found and fixed another API change for kernel 4.9. In addition, the libreadline6 package is now needed.
* Fri Oct 21 2016 Larry.Finger@lwfinger.net
- Fix typo in "vbox_fix_4.9_api_changes.patch".
* Thu Oct 20 2016 Larry.Finger@lwfinger.net
- Make another 4.9 API change.
* Thu Oct 20 2016 Larry.Finger@lwfinger.net
- Fix build on kernel 4.9 using patch "vbox_fix_4.9_api_changes.patch".
* Wed Oct 19 2016 Larry.Finger@lwfinger.net
- Fixes for VUL-0: CVE-2016-5501,CVE-2016-5538,CVE-2016-5605,CVE-2016-5608,CVE-2016-5610,CVE-2016-5611,CVE-2016-561313
  boo #1005621.
- Add patch file "vbox_remove_smp_mflags.patch" to limit number of simultaneous make jobs.
- Version bump to 5.1.8 (released 2016-10-18 by Oracle)
  This is a maintenance release. The following items were fixed and/or added:
    GUI: fixed keyboard shortcut handling regressions (Mac OS X hosts only; bugs #15937 and #15938)
    GUI: fixed keyboard handling regression for separate UI (Windows hosts only; bugs #15928)
    NAT: don't exceed the maximum number of "search" suffixes. Patch from bug #15948.
    NAT: fixed parsing of port-forwarding rules with a name which contains a slash (bug #16002)
    NAT Network: when the host has only loopback nameserver that cannot be mapped to the guests (e.g. dnsmasq running on 127.0.1.1), make DHCP supply NAT Network DNS proxy as nameserver.
    Bridged Network: prevent flooding syslog with packet allocation error messages (bug #15569)
    Audio: now using Audio Queues on Mac OS X hosts
    Audio: fixed recording with the PulseAudio backend (5.1 regression)
    Audio: various bugfixes
    Snapshots: fixed regression in 5.1.4 for deleting snapshots with several disks (bug #15831)
    Snapshots: crash fix and better error reporting when snapshot deletion failed
    Storage: some fixes for the NVMe emulation with Windows guests
    API: fixed initialization of SAS controllers (bug #15972)
    Build system: make it possible to build VBox on systems which default to Python 3
    Windows Additions / VGA: if the guest's power management turns a virtual screen off, blank the corresponding VM window rather than hide the window
    Windows Additions: fixed a generic bug which could lead to freezing shared folders (bug #15662)
    Linux hosts / guests: fix for kernels with CONFIG_CPUMASK_OFFSTACK set (bug #16020)
    Linux Additions: don't require all virtual consoles be in text mode. This should fix cases when the guest is booted with a graphical boot screen (bug #15683)
    Linux Additions: added depmod overrides for the vboxguest and vboxsf kernel modules to fix conflicts with modules shipped by certain Linux distributions
    X11 Additions: disable 3D on the guest if the host does not provide enough capabilities (bug #15860)
* Tue Oct 18 2016 Larry.Finger@lwfinger.net
- Requesting 14000 MB is too much. Reduce the request to 12000 MB.
* Thu Oct 13 2016 Larry.Finger@lwfinger.net
- Some builds still run out of memory and fail. Increase to 14000 MB.
* Thu Oct 13 2016 Larry.Finger@lwfinger.net
- Builds keep running out of memory when building the web server part of the package.
  To help the memory pressure, I have forced make to run with "-j2", rather than use
  the number of processors. Such a change will slow the build, but will result in a
  higher rate of success.
* Wed Oct 12 2016 Larry.Finger@lwfinger.net
-  Increase memory allowed in build to 10000 MB.
* Mon Sep 12 2016 Larry.Finger@lwfinger.net
- Remove file "fix_removal_of_DEFINE_PCI_DEVICE_TABLE" - fixed upstream.
- Version bump to 5.1.6 (released 2016-09-12 by Oracle)
  This is a maintenance release. The following items were fixed and/or added:
    GUI: fixed issue with opening '.vbox' files and it's aliases
    GUI: keyboard grabbing fixes (bugs #15771 and #15745)
    GUI: fix for passing through Ctrl + mouse-click (Mac OS X hosts only; bug #15714)
    GUI: fixed automatic deletion of extension pack files (bugs #11352 and #14742)
    USB: fixed showing unknown device instead of the manufacturer or product description under certain circumstances (5.1.0 regression; bug #15764)
    XHCI: another fix for a hanging guest under certain conditions as result of the fix for bug #15747, this time for Windows 7 guests
    Serial: fixed high CPU usage with certain USB to serial converters on Linux hosts (bug #7796)
    Storage: fixed attaching stream optimized VMDK images (bug #14764)
    Storage: reject image variants which are unsupported by the backend (bug #7227)
    Storage: fixed loading saved states created with VirtualBox 5.0.10 and older when using a SCSI controller (bug #15865)
    Storage: fixed broken NVMe emulation if the host I/O cache setting is enabled
    Storage: fixed using multiple NVMe controllers if ICH9 is used
    NVMe: fixed a crash during reset which could happen under certain circumstances
    Audio: fixed microphone input (5.1.2 regression; bugs #14386 and #15802)
    Audio: fixed crashes under certain conditions (5.1.0 regression; bug #15887 and others)
    Audio: fixed recording with the ALSA backend (5.1 regression)
    Audio: fixed stream access mode with OSS backend (5.1 regression, thanks to Jung-uk Kim)
    E1000: do also return masked bits when reading the ICR register, this fixes booting from iPXE (5.1.2 regression; bug #15846)
    BIOS: fixed 4bpp scanline calculation (bug #15787)
    API: relax the check for the version attribute in OVF/OVA appliances (bug #15856)
    Windows hosts: fixed crashes when terminating the VM selector or other VBox COM clients (bug #15726 and others)
    Linux Installer: fixed path to the documentation in .rpm packages (5.1.0 regression)
    Linux Installer: fixed the vboxdrv.sh script to prevent an SELinux complaint (bug #15816)
    Linux hosts: don't use 32-bit legacy capabilities
    Linux Additions: Linux 4.8 fix for the kernel display driver (bugs #15890 and #15896)
    Linux Additions: don't load the kernel modules provided by the Linux distribution but load the kernel modules from the official Guest Additions package instead (bug #15324)
    Linux Additions: fix dynamic resizing problems in recent Linux guests (bug #15875)
    User Manual: fixed error in the VBoxManage chapter for the getextradata enumerate example (bug #15862)
* Fri Sep  9 2016 Larry.Finger@lwfinger.net
- Add file "fix_removal_of_DEFINE_PCI_DEVICE_TABLE" to compile on kernel 4.8.
* Fri Sep  2 2016 wbauer@tmo.at
- Re-added missing copy of Module.symvers from vboxguest build so
  that loads of vboxvideo can resolve all symbols, this got lost
  somehow (boo#983927, boo#993091)
* Thu Sep  1 2016 mmarek@suse.cz
- Update the host <-> guest KMP conflict dependencies to no longer
  refer to the old name (boo#983927).
* Sun Aug 28 2016 Larry.Finger@lwfinger.net
- Add "ExclusiveArch:  %%ix86 x86_64" line back into the spec file.
  Handle a false positive indication from kmemleak. This patch is added to "modify_for_4_8_bo_move.patch".
* Thu Aug 18 2016 Larry.Finger@lwfinger.net
- The API for ttm_bo_move_memcpy() is changed in kernel 4.8.
  Add patch file "modify_for_4_8_bo_move.patch" to handle this case.
* Thu Aug 18 2016 Larry.Finger@lwfinger.net
-  Version bump to 5.1.4 (released 2016-08-16 by Oracle)
  This is a maintenance release. The following items were fixed and/or added:
    GUI: show actual VM uptime in the session information window
    Audio: re-enabled speakers for Mac OS X guests (5.1.0 regression; bug #15611)
    Audio: fixed crashes under certain conditions
    USB: fixed a hang under certain conditions
    USB: fixed a hanging guest under certain conditions (bug #15747)
    PIIX4: implemented dummy SMBus controller to prevent annoying Linux kernel warnings about uninitialized SMBus base address (bug #9517)
    NVMe: several fixes to improve stability, fixed a crash while saving a VM state
    VMDK: Fixed an issue creating fixed size images with certain sizes and the Split2G option enabled (bug #15748)
    VHDX: fixed cloning images with VBoxManage clonehd (bug #14288)
    Storage: Fixed broken bandwidth limitation when the limit is very low (bug #14982)
    EFI: fixed sending debug messages in the EFI firmware if a serial port is enabled (bug #12161)
    OVF: when importing appliances, make sure that the version of the embedded VirtualBox-specific settings is processed, to get the default settings handling right
    VBoxManage: Don't try to set the medium type if there is no change (bug #13850)
    Linux installer: fixed some scripting issues (bugs #15701 and #15702)
    Linux installer: fixed a path issue on certain Linux distributions (bug #15717)
    Windows hosts: fixed corrupted mouse pointers with some Linux and Solaris guests (bug #15665)
    Linux Additions: made the video driver work on 32-bit guests with large video memory sizes (bug #15621)
    Linux Additions: made the video driver work on kernel 4.7 and later (bug #15769)
    Linux Additions: converted a failure message to an informational one when drivers could not be stopped during upgrade (bug #15692)
    Linux Additions: made the video driver work around an X server bug which cause screen refresh to stop (bug #15511)
    Windows Additions: auto-resizing fixes for Windows 10 guests (bug #15257)
    Windows Additions: fixed VBoxTray problems with Windows 2000 (bug #15661)
- Other local changes:
  "changeset_60565.diff" is removed - fixed in upstream.
  "vbox-kernel47-cpu_has_pge.diff" -s removed - also fixed in upstream.
* Thu Aug 11 2016 hpj@urpla.net
- adjust file attributes on SUID helpers to avoid chkstat issues
* Thu Aug 11 2016 hpj@urpla.net
- remove obsolete libgsoap-devel (again)
- remove /usr/lib/udev/rules.d/60-vboxdrv.rules
  - it is overruled from vboxdrv init script anyway
  - vboxdrv generates a /etc/udev/rules.d/60-vboxdrv.rules file
    on _every_ start, note that fact in /etc/default/virtualbox
    and describe a strategy to control this behaviour
- relocate VBoxCreateUSBNode.sh to /usr/lib/virtualbox
  this is, where vboxdrv, resp. the generated 60-vboxdrv.rules
  file is expecting it
* Mon Aug  8 2016 Larry.Finger@lwfinger.net
-  Remove request for patch that is no longer used.
* Mon Aug  8 2016 Larry.Finger@lwfinger.net
- Patch11 is file "vbox-kernel47-cpu_has_pge.diff".
* Mon Aug  8 2016 bruno@ioda-net.ch
- Add upstream patch fix cpu_has_pge removed macro in kernel 4.7
  Patch11
- Add ifarch ix86 to limit concurrency on 32bits (-j2)
  Remove ExcludeArch instructions
* Fri Jul 22 2016 luizluca@tre-sc.jus.br
- Version bump to 5.1.2 (released 2016-07-21 by Oracle)
  New main capabilities in Oracle VM VirtualBox 5.1 are:
  Improved Performance: Significantly improved performance for multi-CPU virtual machines and networking.
  Bug Reporting Tool: New utility able to collect all the information and logs related to the host and guest operating system, for debug or analysis purposes.
  Improved Logging Window: New logging functionalities to highlight and filter information related to guest Virtual Machines.
  Improved multimedia availability: Improved support for different USB devices and multi-channel audio availability.
  Flash storage emulation: New NVMHCI storage controller emulation available, able to emulate NVME devices - Flash storage - on guest Virtual Machine.
  Improved Linux integration: Automatic modules deployment in case of a Linux Kernel upgrade and improved systemd integration for the latest releases of popular Linux distributions.
- Drop drm-vboxvideo-Add-delayed-update-to-support-fbdev.patch, fixed upstream.
- Drop drm-vboxvideo-Initialize-data-needed-to-map-fbdev-memory.patch, fixed upstream.
- Drop vbox-4.7.patch, fixed upstream.
- vbox-permissions_warning.diff and vbox-usb-warning.diff updated to Qt5
- User Manual updated.
* Thu Jul 21 2016 adam@mizerski.pl
- virtualbox-60-vboxdrv.rules: added missing udev rules for
  vboxdrvu and vboxnetctl (http://www.mgreene.org/?p=211)
* Wed Jul 20 2016 Larry.Finger@lwfinger.net
- Disable i586 builds as they fail with the OBS compiler.
  Increased VM to 20000 M.
- Version bump to 5.0.26 (released 2016-07-18 by Oracle)
  This is a maintenance release. The following items were fixed and/or added:
    VMM: fixed a bug in the task switching code (ticket #15571)
    GUI: allow to overwrite an existing file when saving a log file (bug #8034)
    GUI: fixed screenshot if the VM is started in separate mode
    Audio: improved recording from USB headsets and other sources which might need conversion of captured data
    Audio: fixed regression of not having any audio available on Solaris hosts
    VGA: fixed an occasional hang when running Windows guests with 3D enabled
    Storage: fixed a possible endless reconnect loop for the iSCSI backend if connecting to the target succeeds but further I/O requests cause a disconnect
    Storage: fixed a bug when resizing certain VDI images which resulted in using the whole disk on the host (bug #15582)
    EFI: fixed access to devices attached to SATA port 2 and higher (bug #15607)
    API: fixed video recording with VBoxHeadless (bug #15443)
    API: don't crash if there is no graphics controller configured (bug #15628)
    VBoxSVC: fixed several memory leaks when handling .dmg images
    Solaris hosts: fixed a crash on hosts with certain CPU configurations
    Windows hosts: properly fall back to NDIS5 on pre-Vista hosts on silent installations
* Mon Jul 18 2016 Larry.Finger@lwfinger.net
- Version bump to 5.0.24 (released 2016-06-28 by Oracle)
  This is a maintenance release. The following items were fixed and/or added:
    VMM: reverted to the old I/O-APIC code for now to fix certain regressions with 5.0.22 (bug #15529). This means that the networking performance with certain guests will drop to the 5.0.20 level (bug #15295). One workaround is to disable GRO for Linux guests.
    Main: when taking a screenshot, don't save garbage for blanked screens
    NAT: correctly parse resolv.conf file with multiple separators (5.0.22 regression)
    Storage: fixed a possible corruption of stream optimized VMDK images from VMware when opened in read/write mode for the first time
    Audio: imlemented dynamic re-attaching of input/output devices on Mac OS X hosts
    ACPI: notify the guest when the battery / AC state changes instead of relying on guest polling
    Linux hosts: fixed VERR_VMM_SET_JMP_ABORTED_RESUME Guru Meditations on hosts with Linux 4.6 or later (bug #15439)
* Mon Jun 20 2016 Larry.Finger@lwfinger.net
- Version bump to 5.0.22 (released 2016-06-16 by Oracle)
  This is a maintenance release. The following items were fixed and/or added:
    VMM: fixes for certain Intel Atom hosts (bug #14915)
    VMM: properly restore the complete FPU state for 32-bit guests on 64-bit hosts on Intel Sandy Bridge and Ivy Bridge CPUs
    VMM: new I/O-APIC implementation fixing several bugs and improving the performance under certain conditions (bug #15295 and others)
    VMM: fixed a potential Linux guest panic on AMD hosts
    VMM: fixed a potential hang with 32-bit EFI guests on Intel CPUs (VT-x without unrestricted guest execution)
    GUI: don't allow to start subsequent separate VM instances
    GUI: raised upper limit for video capture screen resolution (bug #15432)
    GUI: warn if the VM has less than 128MB VRAM configured and 3D enabled
    Main: when monitoring DNS configuration changes on Windows hosts avoid false positives from competing DHCP renewals. This should fix NAT link flaps when host has multiple DHCP configured interfaces, in particular when the host uses OpnVPN.
    Main: properly display an error message if the VRDE server cannot be enabled at runtime, for example because another service is using the same port
    NAT: Initialize guest address guess for wildcard port-forwarding rules with default guest address (bug #15412)
    VGA: fix for a problem which made certain legacy guests crash under certain conditions (bug #14811)
    ACPI: properly notify the guest if the ACPI battery state changed
    OVF: fixed import problems for some appliances using an AHCI controller created by 3rd party applications
    SDK: reduced memory usage in the webservice Java bindings
    Linux hosts: EL 6.8 fix (bug #15411)
    Linux hosts: Linux 4.7 fix (bug #15459)
    Linux Additions: Linux 4.7 fixes (bug #15444)
    Linux Additions: fix for certain 32-bit guests (5.0.18 regression; bug #15320)
    Linux Additions: fixed mouse pointer offset (5.0.18 regression; bug #15324)
    Linux Additions: made old X.Org releases work again with kernels 3.11 and later (5.0.18 regression; bug #15319)
    Linux Additions: fixed X.Org crash after hard guest reset (5.0.18 regression; bug #15354)
    Linux Additions: don't stop the X11 setup if loading the shared folders module fails (5.0.18 regression)
    Linux Additions: don't complain if the Drag and Drop service is not available on the host
    Solaris Additions: added support for X.org 1.18
  Local openSUSE specific changes:
    File "changeset_60565.diff" is no longer needced and has been removed.
  Version bump to 5.0.20 (released 2016-04-28 by Oracle)
  This is a maintenance release. The following items were fixed and/or added:
    Storage: fixed a regression causing write requests from the BIOS to cause a Guru Meditation with the LsiLogic SCSI controller (5.0.18 regression; bug #15317)
    Storage: several emulation fixes in the BusLogic SCSI controller emulation
    NAT Network: support TCP in DNS proxy (same problem as in bug #14736 for NAT)
    NAT: rework handling of port-forwarding rules (bug #13570)
    NAT: rewrite host resolver to handle more query types and make it asynchronous so that a stalled lookup doesn't block all NAT traffic
    Snapshots: don't crash when restoring a snapshot which has more network adapters than the current state (ie when the snapshot uses ICH9 and the current state uses PIIX3)
    Guest Control: various bugfixes for the copyfrom and copyto commands / API (bug #14336)
    VBoxManage: list processor features on list hostinfo (bug #15334)
    Linux hosts: fix for Linux 4.5 if CONFIG_NET_CLS_ACT is enabled (bug #15327)
    Windows Additions: fixed performance issues with PowerPoint 2010 and the WDDM graphics drivers if Aero is disabled
* Tue Jun  7 2016 Larry.Finger@lwfinger.net
- Add file "vbox-4.7.patch" to all builds on Kernel_HEAD_standard/x86_64 now that 4.7-rcX is released.
* Wed May 18 2016 hpj@urpla.net
- remove libgsoap-devel from build deps, it conflicts with gsoap-devel
* Fri May  6 2016 Larry.Finger@lwfinger.net
-  Fix start failure of vboxadd service routine
  This script fails because /var/lib/VBoxGuestAdditions/config does not exist; however, there is no need
  for this file. That service routine is modified.
  (boo #977328).
* Tue Apr 26 2016 eich@suse.com
- drm-vboxvideo-Initialize-data-needed-to-map-fbdev-memory.patch:
  * Add missing initialization of scanout buffer base and size for
    proper fbdev support.
- drm-vboxvideo-Add-delayed-update-to-support-fbdev.patch:
  * Add support for delayed_io in fbdev-layer.
  (boo#977200).
* Fri Apr 22 2016 Larry.Finger@lwfinger.net
-   This submission fixes the bug in VB 5.0.18 that prevents proper operation
    for guest VMs configured to use a LsiLogic adapter for disks. See ticket:
    https://www.virtualbox.org/ticket/15317 for a description of the problem,
    and changeset: https://www.virtualbox.org/changeset/60565/vbox for the fix,
    which is implemented in file "changeset_60565.diff".
    This update contains a fix for CVE-2016-0678. Bug report b.o.o #97366
    discusses this vulnerability.
* Wed Apr 20 2016 Larry.Finger@lwfinger.net
-   Version bump to 5.0.18 (released 2016-04-18 by Oracle)
  This is a maintenance release. The following items were fixed and/or added:
    GUI: position off-screen windows to be fully visible again on relaunch in consistence with default-behavior (bug #15226)
    GUI: fixed the View menu / Full-screen Mode behavior on Mac OS X El Capitan
    GUI: fixed a test which allowed to encrypt a hard disk with an empty password
    GUI: fixed a crash under certain conditions during VM shutdown
    GUI: fixed the size of the VM list scrollbar in the VM selector when entering a group
    PC speaker passthrough: fixes (Linux hosts only; bug #627)
    Drag and drop: several fixes
    SATA: fixed hotplug flag handling when EFI is used
    Storage: fixed handling of encrypted disk images with SCSI controllers (bug #14812)
    Storage: fixed possible crash with Solaris 7 if the BusLogic SCSI controller is used
    USB: properly purge non-ASCII characters from USB strings (bugs #8801, #15222)
    NAT Network: fixed 100%% CPU load in VBoxNetNAT on Mac OS X under certain circumstances (bug #15223)
    ACPI: fixed ACPI tables to make the display color management settings available again for older Windows versions (4.3.22 regression)
    Guest Control: fixed VBoxManage copyfrom command (bug #14336)
    Snapshots: fixed several problems when removing older snapshots (bug #15206)
    VBoxManage: fixed --verbose output of the guestcontrol command
    Windows hosts: hardening fixes required for recent Windows 10 insider builds (bugs #15245, #15296)
    Windows hosts: fixed support of jumbo frames in with bridged networking (5.0.16 regression; bug #15209)
    Windows hosts: don't prevent receiving multicast traffic if host-only adapters are installed (bug #8698)
    Linux hosts: added support for the new naming scheme of NVME disks when creating raw disks
    Solaris hosts / guests: properly sign the kernel modules (bug #12608)
    Linux hosts / guests: Linux 4.5 fixes (bug #15251)
    Linux hosts / guests: Linux 4.6 fixes (bug #15298)
    Linux Additions: added a kernel graphics driver to support graphics when X.Org does not have root rights (bug #14732)
    Linux/Solaris Additions: fixed several issues causing Linux/Solatis guests using software rendering when 3D acceleration is available
    Windows Additions: fixed a hang with PowerPoint 2010 and the WDDM drivers if Aero is disabled
- Drop VirtualBox-5.0.17-r106108-r106140.patch, fixed upstream.
* Fri Apr 15 2016 Larry.Finger@lwfinger.net
-  Fix build error caused by removal of macro page_cache_release() from kernel.
  File "vbox-replace-page-cache-release.diff" is used to modify code to use put_page() instead.
* Mon Apr  4 2016 Larry.Finger@lwfinger.net
-  Fix problem with SONAME for VBoxOGL.so. With the Oracle code, it is libGL.so.1 rather than VBoxOGL.so.1.
  Thanks to Max Lin <mlin@suse.com> for notifying me about the problem.
  This fix adds file "vbox_prevent_wrong_SONAME.patch"
* Thu Mar 31 2016 Larry.Finger@lwfinger.net
-  Fix problems with previous submission
  Removed copy of user manual from download site as there is no special manual for 5.0.17.
  File VirtualBox-5.0.17-r106108-r106140.patch is added to update the Oracle source to the latest commit.
* Wed Mar 30 2016 Larry.Finger@lwfinger.net
-  Modify Guest Additions so that openSUSE build works with new Oracle code. The following changes have been made:
  Added Oracle patch to bring code to r106140 commit.
  Moved VB guest modules to /lib/modules/.../misc/. This layout matches that of the Oracle Guest Additions ISO.
  Added missing copy of Module.symvers from vboxguest build so that loads of vboxvideo can resolve all symbols.
  Remove patch added in previous cycle to build under kernel 4.5.0. The Oracle code now has this fix.
  With these changes, both Gnome and KDE desktops as VB virtual machines work with gdm and the versions of X.Org that do not run as root.
  The only known defect is that the mouse pointer is missing when 3D acceleration is turned on in the VB control panel.
* Mon Mar  7 2016 Larry.Finger@lwfinger.net
-  Version bump to 5.0.17 (released 2016-03-07 by Oracle)
    Following the 5.0.16 release, the Guest Additions were updated to support Linux guests
    with X.Org Server running without root privileges and to fix certain 3D acceleration-related issues.
    There are no other changes to VirtualBox.
    A patch "vbox-guest-add.diff" is needed to enable the Oracle code to build with kernel 4.5.
* Sat Mar  5 2016 Larry.Finger@lwfinger.net
-  Version bump to 5.0.16 (released 2016-03-04 by Oracle)
  This is a maintenance release. The following items were fixed and/or added for Linux hosts:
    VMM: fixed a problem which could lead to a wrong guest behavior on AMD CPUs (tickets #14831 and #15186)
    GUI: prevent a crash during startup under rare conditions
    GUI: position off-screen windows to be fully visible again on relaunch
    GUI: hide the VT-x/AMD-V checkbox if raw-mode is not supported (usually Mac OS X hosts; bug #15178)
    PC speaker passthrough: new experimental feature, available on Linux host only
    Audio: properly handle default audio device changes (Windows hosts)
    USB: serveral fixes for the xHCI controller (e.g. for webcam passthrough)
    BIOS: fixed int15/AH=83/AL=00 function (4.2.0 regression)
    iPXE: enable the HTTP download protocol on non-Linux hosts (bug #13628)
    Shared folders: fixed a failure to load the saved state under certain circumstances (bug #6314)
    Guest Control: added support for (cached) Active Directory authentication in case the domain controller is not reachable (anymore)
    Serial ports: raised the number of serial ports per VM from 2 to 4 (bug #9109)
    SDK: make the Python webservice API binding work again (5.0 regression)
    Seamless mode: fixed a crash under certain circumstances (bug #15106)
    Linux hosts: fixed the /sbin/rcvboxdrv script as well as the missing shebang in two scripts (bugs #15055 and #15057)
    Linux hosts: properly uninstall Python files installed by the .run installer
    Windows Additions: fixed guest property enumeration of logged-in users
    Windows Additions: fixed sporadical failure of the graphics driver in Windows 10 guests (bug #14409)
    Windows Additions: under rare circumstances no mouse movement events were delivered to the guest
* Tue Jan 19 2016 Larry.Finger@lwfinger.net
-  Version bump to 5.0.14 (released 2016-01-19i by Oracle)
  This is a maintenance release. The following items were fixed and/or added:
    GUI: properly limit the number of VCPUs to the number of physical cores on Mac OS X (bug #15018)
    Audio: fixed a bug which prevented loading a saved state of a saved guests with HDA emulation (5.0.12 regression; bug #14981)
    Audio: don't crash if the backend is unable to initialize (bug #14960)
    Audio: fixed audio capture on Mac OS X (bug #14386)
    Storage: fixed a possible crash when attaching the same ISO image multiple times to the same VM (bug #14951)
    BIOS: properly report if two floppy drives are attached
    USB: fixed a problem with filters which would not capture the device under certain circumstances (5.0.10 regression; bug #15042)
    ExtPack: black-list Extension Packs older than 4.3.30 due to incompatible changes not being properly handled in the past
    Linux hosts: properly create the /sbin/rcvboxdrv symbolic link (5.0.12 regression; bug #14989)
    Linux Additions: fixes for Linux 4.5 (bug #15032)
* Thu Jan 14 2016 bwiedemann@suse.com
- vboxadd script no more fails on remote_fs failure (bnc#908383)
* Sat Dec 26 2015 Larry.Finger@lwfinger.net
- Version bump to 5.0.12 (released 2015-12-18i by Oracle)
  This is a maintenance release. The following items were fixed and/or added:
    GUI: fixed wrong scrolling behaviour in the VM selector window when a VM item is dragged out of the chooser-pane area
    GUI: fixed the validation of IPv6 port-forwarding rules
    GUI: suppress the first-run wizard if a CD/DVD medium is inserted using the selector UI
    GUI: fixed the Ctrl+Break key sequence scan codes (bug #14927)
    GUI: improved handling of text selection mouse pointer (bug #750)
    Host services: fixed a crash during VM shutdown under rare conditions (5.0.6 regression; bug #14841)
    Shared folders: fixed a sharing violation if a file is opened to check the attributes (Windows hosts only; bug #14450)
    Webcam: passthrough fix for certain devices (Mac OS X hosts only)
    XHCI: fixed broken emulation if software virtualization is used
    XHCI: several fixes
    3D: fixed state handling under certain conditions (bug #13487)
    Audio: several fixes
    BIOS: added LBA64 support for being able to boot from huge hard disks (bug #7415)
    EFI: fix for Windows 10 guests
    ExtPack: before installing an Extension Pack check if there are VMs running to prevent file system locking issues
    rdesktop-vrdp: source code tarball fixes
    Linux hosts: .desktop file compatibility issue (bug #14808)
    Linux hosts / guests: fixes for RHEL 7.2 (bug #14866)
    Linux hosts: The command for recompiling the host kernel modules was changed again, to /sbin/rcvboxdrv setup (bug #14723)
    Linux hosts: some fixes for PCI passthrough (still highly experimental)
    Linux/Mac OS X hosts: fixed a VM hang during startup under certain circumstances (bug #14933)
    Linux Additions: prevent the compiler from doing dead-code elemination on vital code in guest / host communication (bug #14497)
    Linux Additions: when mounting a shared folder, explicitly pass the share name so that /proc/mounts contains this name instead of 'none'
    Linux Additions: workaround for a systemd problem in conjunction with SELinux which prevented to properly enable the 'vboxadd' service during while upgrading the Additions
* Sun Dec 20 2015 mailaender@opensuse.org
- fix permission Error In SUPR3HardenedMain
  Effective UID is not root (euid=1000 egid=100 uid=1000 gid=100) (rc=-10)
  see https://forums.virtualbox.org/viewtopic.php?t=11154
* Sat Nov 21 2015 Larry.Finger@lwfinger.net
- Remove file vbox_build_kms_modules.diff.
* Fri Nov 20 2015 Larry.Finger@lwfinger.net
- Temporarily disable i586 builds.
* Fri Nov 20 2015 Larry.Finger@lwfinger.net
- Increase memory to 8000 MB to try to fix out-of-memory error when building i586 version.
* Mon Nov 16 2015 Larry.Finger@lwfinger.net
- Increase memory to 7000 MB in _constraint to see if that fixes link problem on i586.
* Thu Nov 12 2015 idonmez@suse.com
- Version bump to 5.0.10 (released 2015-11-10 by Oracle)
  This is a maintenance release. The following items were fixed and/or added:
    VMM: improved support for certain Intel Atom CPUs (bug #14773)
    VMM: system register emulation fix (5.0 regression; bug #14515)
    GUI: fixed immediate screenshot issue (bug #14108)
    GUI: fixed another 3D overlay window reparenting issue when the VM is switched to fullscreen mode on X11 hosts
    GUI: fixed help index (bug #14722)
    GUI: fixed state synchronization issue in the VM manager window when VM was paused from its runtime window
    Audio: fixed suspending/resuming audio streams on VM pause/unpause (bug #14784)
    Audio: properly reset AC97 audio streams, otherwise there is silence until a non-48 kHz stream is played
    Audio: fixed a small emulation quirk of the AD1980 codec of the HDA device to make recent linux guests work (bug #14653)
    USB: serveral fixes for the xHCI controller
    USB: fixed a crash under certain conditions on hosts with Linux kernels older than version 3.3
    USB: better identification of certain USB devices
    NAT: support TCP in DNS proxy (bug #14736)
    NAT Network: fixed sporadic crashes on Windows hosts (bug #13899)
    API: when creating differencing images (e.g. as part of a snapshot or cloning a VM) use the same disk image variant as the parent image if possible, which means that e.g. a diff image for a VMDK image split into 2 GB files will also be split (bug #14764)
    API: event queue handling fixes preventing loss of certain events at runtime (e.g. new webcam attached), particularly important on Mac OS X hosts
    Webcam: passthrough fix for certain devices (Windows hosts only)
    VBoxManage: don't crash on snapshot restorecurrent / edit if the VM has no snapshots
    VBoxManage: don't crash on controlvm addencpassword (bug #14729)
    Mac OS X hosts: use the correct kernel on certain hosts
    Windows hosts: fixed VRDP external authentication
    Windows hosts: allow to use a shared folder path with extended-length path prefix (5.0 regression; bug #14651)
    Windows hosts: fix a crash in the netfilter host driver under certain conditions (bug #14799)
    Windows host installer: documented and fixed public properties which can be used to control the installation to some extent
    Windows host installer: fixed not starting the actual installation when showing the version information or help dialogs
    X11 Additions: added basic support for X.Org Server 1.18 (3D requires additional fixes)
* Fri Nov  6 2015 Larry.Finger@lwfinger.net
- Fixed typo in QMessageBox text in new popup window.
* Fri Nov  6 2015 Larry.Finger@lwfinger.net
- Add logic to virtualbox-wrapper.sh to test if /etc/udev/rules.d/60-vboxdrv.rules exists. If not, a screen stating
  that passthru of USB devices is a security hole, and it refers the user to bnc#664520 for an explanation.
  It also explains the process for enabling USB passthru if the user really wants it. When the user closes
  the popup window, a dummy version of /etc/udev/rules.d/60-vboxdrv.rules is created, which prevents this
  window from being displayed every time VirtualBox is started.
- Fixes boo#953018.
* Tue Oct 20 2015 Larry.Finger@lwfinger.net
- Version bump to 5.0.8 (released 2015-10-20 by Oracle)
    boo#951432 CVE-2015-4813 CVE-2015-4896
  This is a maintenance release. The following items were fixed and/or added:
    GUI: Mac OS X: Restore green zoom button for VM windows (it was hidden in the previous release to avoid native full-screen issues). For Yosemite and El Capitan this button should work accordingly to the Apple HIG: Full-screen by default, maximize if the user holds the Option key.
    Serial ports: fixed wrong IRQ number for the first serial port in the ACPI tables (5.0.6 regression; bug #14659)
    API: fixed a 5.0 regression in VBoxManage setproperty defaultfrontend (bug #14696)
    VBoxManage/vbox-img: conversion to RAW images could result in a disk image containing all zeroes
    Linux hosts: several fixes for systemd integration in .deb / .rpm packages (e.g. bug #14665). The command for recompiling the host kernel modules was changed to /sbin/vboxconfig
    Linux hosts: make host-only interfaces report operstate UP only when they have VMs attached (bug #14526)
    Mac OS X hosts: fix bpf capture and accounting of traffic on bridged and host-only interfaces (bug #14553)
    Windows guests: fixed 3D rendering issues on high resolution displays
    Windows Additions: fixed problems with 3D acceleration on Windows hosts with Intel HD graphics (bug #14670)
    Linux Additions: fix service starting on Debian systems with systemd installed but not in use (bug #14683)
* Mon Oct  5 2015 idonmez@suse.com
- Version bump to 5.0.6 (released 2015-10-02 by Oracle)
  This is a maintenance release. The following items were fixed and/or added:
  GUI: the update check now uses the HTTP system proxy settings by default
  GUI: About dialog improvements. Copyable version text, do not close dialog on mouse-clicks and focus losing, explicit close button at the bottom of dialog and disabled close button fix on OS X. (bugs #9912, #12749)
  GUI: fixed bug when re-assigning shortcuts (bug #14565)
  GUI: fixed default focus button in message-box dialogs (bug #14486)
  GUI: fixed settings dialog which is opened if the network settings need to be changed at VM startup (5.0.0 regression; bug #14601)
  GUI: fixed crash during VM start if an early error message needs to be shown, for example Linux kernel modules not present (bug #14646)
  Bridged Networking: fixed handling of guest DHCP requests without UDP checksum when bridging to a wireless interface (bug #14615)
  Audio: latency fixes (Windows hosts only; bug #4088)
  Guest Control: correctly set USERNAME and USERPROFILE environment variables (Windows guests only)
  Guest Control: several fixes
  API: properly restore NAT port forwarding rules when reverting to a snapshot
  Parallel ports: Several fixes allowing to enable two parallel ports for a VM
  VBoxManage: fixed wrong output of debugvm show command
  VBoxManage: fixed hang when specifying logging groups with debugvm log starting with h, for example hex
  Windows hosts: renamed VBoxStartup.log to VBoxHardening.log and provide this log file in the GUI log viewer
  Windows hosts: fixed a small memory leak in the Windows host interface driver (VBoxNetAdp) which caused a BSOD if the driver verifier is enabled (bug #14562)
  Windows hosts: fixed a failure to start VMs on hosts where dsound.dll is not available (bug #14574)
  Windows hosts: another fix for VERR_LDR_MISMATCH_NATIVE errors (bug #14579)
  Windows hosts: fixed host-to-guest communication with bridged networking (bugs #14326, #14457)
  Windows hosts: fixed broken data receiving from the serial device with the named pipe backend if Kaspersky AV is installed
  Linux hosts: Linux 4.3 compile fixes
  Linux hosts: installer fix for certain systems (bug #14627)
  Linux hosts / guests: native systemd support for the host/guest installer scripts. The scripts for re-compiling the kernel modules are now located at /sbin/rcvboxdrv (host) and /sbin/rcvboxadd (Guest Additions)
  Mac OS X hosts: GUI-related fixes for El Capitan
  Mac OS X hosts: fixed a problem with capturing USB devices under El Capitan
  Mac OS X hosts: allow colon character on shared folders (bug #14554)
  Linux Additions: properly set the VBoxService process ID in the PID file (bug #14571)
  Linux Additions: Guest Control fixes (bug #14573)
  Windows Additions: fixed shutting down VBoxTray when running with older VirtualBox host versions
  Windows Additions: fixed video playback with VLC and Windows Media Player when the WDDM driver is used and 3D is not used
  Windows Additions: prevent a possible VLC crash when the WDDM driver is used and 3D is enabled by implementing YV12 surfaces
- Drop vbox-32bit-build-error.diff, fixed upstream
- Updated UserManual.pdf
* Fri Oct  2 2015 dimstar@opensuse.org
- BuildRequire pkgconfig(udev) instead of udev directly: this allows
  us to be earlier in the build phase, as we can make use of udev-mini
  and it solves build failures with systemd224.
* Fri Sep 11 2015 Larry.Finger@lwfinger.net
- The code base released by Oracle failed to build on 32-bit systems. They had already fixed the
  problem. This update applies their solution using patch file vbox-32bit-build-error.diff.
* Tue Sep  8 2015 Larry.Finger@lwfinger.net
  Version bump to 5.0.4 (released 2015-09-08 by Oracle)
  This is a maintenance release. The following items were fixed and/or added:
    VMM: fixed an issue with Windows 10 guest kernel debugging over the network for Hyper-V paravirtualized VMs
    VMM: fixed a bug which prevented reading the saved state of the 'PATM' unit from VirtualBox 4.3.x (bug #14512)
    GUI: changed default OS type for Windows from Windows XP to Windows 7
    GUI: added another pre-defined guest screen resolution (bug #14384)
    GUI: fixed update check which was broken due to changing the location of the root certificates (bug #13096)
    GUI: fixed issues with synchronization of Caps lock / Num lock / Scroll lock on Windows hosts (bug #14302)
    GUI: don't crash during VM shutdown if 2D video acceleration and 3D support are enabled (Mac OS X hosts only)
    GUI: several seamless fixes for certain X11 window managers, also when used in multi-screen setups
    GUI: Log window size, position and cursor-position fixes
    Audio: fixed playing leftover/deprecated audio samples
    Audio: fixed playing audio after suspending the host (5.0 regression; Linux hosts using the ALSA backend)
    Audio: fixed playing short audio samples which were chopped off formerly
    Audio: fixed distortions on OS X when the sample rate of the guest stream and host device don't match
    Storage: fixed raw disk access and flat VMDK image access which would be always opened readonly (5.0.2 regression; bugs #14425, #14461)
    Storage: fixed initial encryption of VDI images after they were compacted (bug #14496)
    VGA: fix for certain graphics modes (bug #14516)
    NAT: don't freeze while the VM is paused if the network attachment mode is changed from/to NAT with activated port forwarding
    OVF: fixed duplicate USB controller entries in exported OVA/OVF (bug #14462)
    Shared Folders: fixed a path separator issue (bug #14434)
    Drag and drop: fixed crashes on OS X hosts when doing host-to-guest transfers
    VBoxManage: another attempt to not deny changing the network adapter type at VM runtime (5.0 regression; bug #14308)
    VBoxManage: fixed broken guestcontrol <VM-Name> list command (5.0 regression)
    VBoxManage: fixed broken Guest Control stdout/stderr output (5.0 regression)
    Mac OS X hosts: fixed remaining problems with activated SMAP (Broadwell and later; bug #14412)
    Mac OS X hosts: fixed broken 3D support (5.0.2 regression; bug #14476)
    Linux hosts: Linux 4.2 fix
    Linux hosts: don't crash on older Linux distributions if the DBus service isn't running (bug #14543)
    Windows hosts: fixed the VERR_LDR_MISMATCH_NATIVE error message (bug #14420)
    Windows hosts: fix for Windows 10 build 10525 and later (bug #14502)
    Windows hosts: fixed network adapter enumeration on Windows 10 (bug #14437)
    Windows hosts: prevent intermittent host network disconnects during VM start/shutdown with bridged networking (bug #14500)
    Windows Additions: fixed the call to the memory allocation function (bug #14415)
    Linux Additions: be more forgiving if the compilation of the vboxvideo module fails (bug #14547)
    X11 Additions: fixed a number of small issues with dynamic resizing and full-screen and seamless modes.
* Tue Sep  1 2015 wbauer@tmo.at
- Install and enable the vboxadd-service init script, to make
  auto-mounting of shared folders and time synchronization work
- Install VBoxService to /usr/sbin/ instead of /usr/bin/ so that
  vboxadd-service can find it, it cannot be run as user anyway
- Create the /media folder with appropriate permissions on
  distributions higher than 13.1, it doesn't exist any more and the
  one that VBoxService creates automatically cannot be accessed by
  normal users
- Fixes boo#908669 and boo#936254
* Fri Aug 14 2015 Larry.Finger@lwfinger.net
  Version bump to 5.0.2 (released 2015-08-13 by Oracle)
  A number of problems were fixed and/or added. In particular, the artifically high load average
  problem reported as bsc#939299 has been fixed. The complete list follows:
    VMM: added support for guest crash report MSRs with Hyper-V paravirtualization
    VMM: fixed an issue causing artifically high load averages on Linux hosts
    VMM: fixed a kernel panic with thread-context hooks caused by incompatible changes made to Linux 4.2 kernels
    VMM: fixed a saved state issue with VT-x/AMD-V disabled (5.0 regression; bug #14304)
    VMM: fixed VERR_SUPDRV_TSC_DELTA_MEASUREMENT_FAILED Guru Meditations on certain AMD CPUs (5.0 regression; bug #14370)
    VMM: fixed a crash while creating a guest core dumps via the VM debug facility (5.0 regression)
    VMM: This release has AVX2 passthrough disabled on every host and AVX passthrough disabled for 64-bit VMs on 32-bit hosts.
  This will be properly fixed in a future 5.0.x maintenance release (see e.g. bug #14262).
    GUI: fixed rare hang and crash on VM shutdown/poweroff
    GUI: X11: fixed few crashes caused by the Qt alien widgets feature
    GUI: X11: fixed various mini-toolbar geometry quirks like positioning, z-order, transiency issues on certain window managers (bug #14257)
    GUI: X11: fixed mini-toolbar minimize button issue under certain window managers (bug #14284)
    GUI: VM menu actions availability should now be properly updated on full-screen/seamless/scaled mode switches
    GUI: disk encryption password validation should be performed when user confirmed the password, not after each entered symbol
    GUI: do not change the VM/group selection in the VM Manager to the newly created VM if it was created by another client (e.g. VBoxManage)
    GUI: improve the quality in scaled mode under some circumstances (5.0 regression; bug #14303)
    VBoxManage: do not deny changing the network adapter type at VM runtime (5.0 regression; bug #14308)
    VRDP: allow Windows 10 RDP clients (bug #14216)
    Audio: fix a possible crash on VM process termination (5.0 regression)
    Storage: improved raw disk access on OS X by unmounting any accessed volume before first use and prevent any mount attempt by the host (bug #14219)
    3D: basic support for saving/restoring display lists
    Shared Folders: fixed a problem with accessing CIFS shares (bug #14252)
    Shared Folders: improved path conversion between hosts and guests with different path separators (bug #14153)
    API: skip resetting of immutable media when the VM in saved state is started (bug #13957)
    API: fixed method for setting medium IDs which used zero (invalid) UUIDs instead random (valid) UUIDs if no UUIDs were passed (bug #14350)
    API: for Windows host fix detection of API client crashes which have a session open
    OVF: properly export all VBox features including the setting for paravirtualization (bug #14390)
    Linux hosts: more fixes for activated SMAP on Linux 3.19 and newer (Broadwell and later; bug #13961)
    Linux hosts: check then name space before attaching to a host network interface (bug #13795)
    Linux Additions: Linux 4.2 fixes (bug #14227)
    Linux Additions: improved the performance of stat() to speed up certain file operations on shared folders
    X11 Additions: various seamless mode fixes, including invisible windows under LXDE. -
* Wed Jul 15 2015 tchvatal@suse.com
- Install more binaries that were in bin generated folder
* Tue Jul 14 2015 tchvatal@suse.com
- Fix buffer overflow on dtrace lib:
  * virtualbox-snpritnf-buffer-overflow.patch
- Note: still does not respect cxxflags
* Sat Jul 11 2015 tchvatal@suse.com
- Fix vbox build by replacing non-existent sed parameter:
  * virtualbox-sed-params.patch
* Sat Jul 11 2015 tchvatal@suse.com
- Version bump to 5.0.0:
  * Major bump from 4 series with tons of changes.
  * Read upstream changelog for in-depth informations
- Obsoleted patches:
  * gcc5-support.patch
  * gcc51-support.patch
- Refreshed patches:
  * gcc5-real-support.patch
  * vbox-disable-updates.diff
  * virtualbox-system-x.patch
* Mon Jul  6 2015 alarrosa@suse.com
- Exclude %%ix86 arch in suse_version == 1315 (openSUSE 42)
* Fri Jun 12 2015 mpluskal@suse.com
- Enable building of for all supported kernel flavours
  * exclude also pv flavour
* Tue Jun  9 2015 tchvatal@suse.com
- Disable multiversion_kernel support, taken from nvidia driver spec,
  should fix bnc#925663.
* Wed May 27 2015 jslaby@suse.com
- initial gcc5 support (it builds at least)
  * added: gcc5-support.patch (upstream)
  * added: gcc51-support.patch (upstream)
  * added: gcc5-real-support.patch
* Tue May 19 2015 mpluskal@suse.com
- Add smap.diff (boo#931461)
* Fri May 15 2015 tchvatal@suse.com
- Version bump to 4.3.28 bnc#935900 CVE-2015-3456:
  * VMM: fixed a Guru Meditation when rebooting certain guests (for example Solaris
    doing fast reboot) by fixing the implementation for INIT IPI
  * VMM: added some information for diagnosing rare VERR_VMX_INVALID_VMXON_PTR Guru
    Meditations (VT-x only)
  * GUI: HID LEDs sync: prevent synchronization if VM window has no focus (Windows
    and Mac OS X hosts only)
  * GUI: fixed drag and drop moving the cursor between guest screens on certain
    hosts
  * 3D: fixed a crash on restoring the VM state on X11 hosts (bug #12737)
  * 3D: fixed a crash on Linux guest shutdown (bug #12772)
  * VRDP: fixed incompatibility with rdesktop 1.8.3
  * VRDP: fixed listening for IPv6 on some systems (bug #14038)
  * Storage: don't crash if creating an asynchronous I/O context fails (e.g. when
    starting many VMs) and show a proper error message
  * Floppy: several fixes
  * Audio: improved the behavior of the volume control for the HD audio device
    emulation
  * USB: increase the number of supported drivers from 3 to 5 (Windows hosts only)
  * PS/2 keyboard: synchronize the LED state on VM restore (Windows and Mac OS X
    hosts only)
  * NAT Network: when running multiple NAT networks with multiple VMs, only stop
    the respective services when stopping VMs (bug #14090)
  * NAT: don't kill UDP bindings on ICMP errors (bug #13475)
  * NAT: bandwidth limit now works properly with NAT (bug #11485)
  * BIOS: fixed the returned size value of the VBE 2.0 PMI function 0Ah (4.2.0
    regression; bug #14096)
  * Guest Control: fixed parameter quoting in Windows guests (bug #13157)
  * Webcam passthrough improvements for Linux (V4L2) hosts to support more webcam
    models
  * API: don't fail starting a VM with VBOX_E_INVALID_OBJECT_STATE under certain
    conditions (bug #13617)
  * API: be more verbose on VBOX_E_INVALID_OBJECT_STATE if a medium is attached to
    a running VM (bug #13560)
  * API: fixed a bug which could result in losing certain screen resize events with
    multi-monitor guests
  * rdesktop-vrdp: fixed path to the keymaps (bug #12066)
  * rdesktop-vrdp: switch to version 1.8.3
  * Windows hosts: more hardening fixes (e.g. bugs #14051, #14052)
  * Linux hosts: another fix for activated SMAP on Linux 3.19 and newer (Broadwell
    and later; bug #13961)
  * Linux hosts: Linux 4.1 compile fix (bug #14081)
  * Solaris hosts: fixed using of VNIC templates with Crossbow based bridged
    networking to be compatible with vanity interface names
  * Mac OS X hosts: fixed crash during VM termination under rare circumstances
  * Windows Additions/WDDM: improved video memory utilization and allow more/bigger
    guest screens with large resolutions (including HiDPI)
  * X11 Additions: prevent flickering when updating mouse cursor
  * Solaris Additions: fixed incorrect usage of 'prtconf' while installing Guest
    Additions (Solaris 10 only)
- Refresh patch:
  * vbox-vboxadd-init-script.diff
* Sun May 10 2015 bwiedemann@suse.com
- Provide host-kmp src for use with custom kernels (bnc#925663)
* Wed May  6 2015 tchvatal@suse.com
- Create groups properly and also create vboxsf and vboxguest on
  guest additions bnc#927708
* Wed May  6 2015 tchvatal@suse.com
- Build with system libs for X instead of localy built ones.
  This should fix bnc#929697
- Adds patch:
  * virtualbox-system-x.patch
* Wed May  6 2015 tchvatal@suse.com
- Split kmk call to multiple lines
* Wed May  6 2015 tchvatal@suse.com
- Reorder alignment of buildroot for various install commands so it
  does not look so fuzzy
* Mon Apr 20 2015 tchvatal@suse.com
- Allow access to vboxdrv to vboxusers group members bnc#927525
* Mon Mar 23 2015 tchvatal@suse.com
- Version bump to 2.3.26:
  * GUI: in the snapshots pane, protect the age of snapshots against wrong host
    time (bug #13955)
  * NAT Network: fixed a bug which prevented to propagate any DNS name server /
    domain / search string information to the NAT network (4.3.24 regression; bugs
    [#13915], #13918)
  * NAT Network: don't delay the shutdown of VBoxSVC on Windows hosts
  * Mouse support: the mouse could not be moved under rare conditions if no Guest
  * Additions are installed (4.3.24 regression; bug #13935)
  * Storage: if the guest ejects a virtual CD/DVD medium, make the change permanent
    (bugs #9858, #12885)
  * VGA: made saving secondary screen sizes possible in X11 guests
  * SDK: fixed the VirtualBox.tlb file (4.3.20 regression; bug #13943)
    rdesktop-vrdp: make it work with USB devices again (4.3.14 regression; bug
    [#13901])
  * USB: fixed a possible BSOD on Windows hosts under rare conditions
  * iPXE: enable the HTTP download protocol on non-Linux hosts (bug #13628)
  * Mac OS X hosts: don't panic on hosts with activated SMAP (Broadwell and later;
    bug #13951)
  * Linux hosts: don't crash Linux 4.0 hosts (bug #13835)
* Wed Mar  4 2015 tchvatal@suse.com
- Version bump to 2.3.24:
  * VMM: emulation fix for the ENTER instruction under certain conditions; fixes
    Solaris 10 guests (VT-x without unrestricted guest execution)
  * VMM: fix for handling NMIs on Linux hosts with X2APIC enabled
  * NAT/NAT Network: fix connection drops when the host's DHCP lease was renewed
    (4.3.22 regression; Windows hosts only; bug #13839)
  * NAT: don't crash on an empty domain list when switching the DNS host
    configuration (4.3.22 regression; Mac OS X hosts only; bug #13874)
  * PXE: re-enable it on Windows hosts (4.3.22 regression; Windows hosts only; bug
    [#13842])
  * Shared Folders: fixed a problem with Windows guests (4.3.22 regression; bug
    [#13786])
  * Audio: improved record quality when using the DirectSound audio backend
  * VBoxManage: when executing the controlvm command take care that the
    corresponding VM runtime changes are saved permanently (bug #13892)
  * Windows Installer: properly install the 32-bit version of VBoxRes.dll on 32-bit
    hosts (bug #13876)
  * Linux hosts / guests: Linux 4.0 fixes (bug #13835)
  * OS/2 Additions: fixed mouse integration (4.3.22 regression; bug #13825)
  * X11 Additions: fixed a sporadic failure to deactivate virtual screens (bug
    [#13845])
- Use smp_mflags when building kernel modules
* Thu Feb 26 2015 wbauer@tmo.at
- Install vboxvideo_drv_117.so on Factory
* Sun Feb 15 2015 zaitor@opensuse.org
- Update to version 4.3.22:
  + VMM: refined measurement of TSC frequency on the host, improves timekeeping for guests
  + VMM: decreased CPU load resulting from guest MMIO writes to the virtual APIC
  + VMM: fixed interception of debug exceptions, observed while using the dbx debugger on Solaris guests (VT-x only)
  + GUI: 3D overlay window positioning code improved, fixed potential misplacement of 3D accelerated guest graphics content
  + GUI: fixed accident SSL authentication failures during update check on Windows hosts (bug #12969)
  + GUI: never send the "ACPI power" keyboard scancode to the guest, we have the ACPI power button for that
  + GUI: was unable to properly restore seamless mode VM from snapshot/saved-state under some circumstances
  + VBoxHeadless: don't crash if 3D is enabled in the VM settings (bug #10250)
  + ATA: fixed several passthrough issues (bugs #12310, #1360)
  + Audio: fixed DirectSound failure when the the host has no audio input device (Windows hosts only; bug #9205)
  + SB16: fixed compatibility issue (bug #13769)
  + Storage: fixed broken CD/DVD passthrough when using the IDE controller (bug #12310)
  + NAT: new ping proxy for Windows hosts (bug #11871)
  + NAT: Properly report outbound connect(2) failures to guest with TCP RST or ICMP (bug #10525)
  + NAT Network: no need for frequent wakeups in VBoxNetDHCP and VBoxNetNAT (bug #11681)
  + Host-only adapter: prevent Windows from creating an "Unidentified network" (bug #9688)
  + Bridged Networking: don't leak host-to-guest traffic to the wireless network when bridging to a wireless interface (bug #13714)
  + Main: fixed a possible race when changing the medium leading to a deadlock under rare conditions (bug #13722)
  + VBoxManage: fixed return code if starting a VM failed (bug #13773)
  + API: fixed 2 deadlock opportunities related to medium handling (bugs #13789, #13801, thank you Alexander Urakov)
  + API: fixed bug in XPCOM which created too few worker threads, sporadically resulting in a deadlock (bug #13802, thank you Alexander Urakov)
  + SDK: fixed a garbage collection leak in the Python VirtualBox webservice API binding (bug #13817)
  + Linux hosts: fixes for activated SMAP (Broadwell and later, bug #13820)
  + X11 guests: prevent unwanted hiding of guest screens on multi-monitor guests (bug #13287)
  + X11 guests: added support for X.Org Server 1.17
  + X11 Additions: fixed a memory leak in VBoxService if libdbus is available but dbus-daemon isn't running (bug #13770)
  + Windows Additions: prevent VBox WDDM driver from loading if host reports weak OpenGL capabilities. 3D content now can be shown over Remote Desktop connection.
  + Windows Additions: some fixes for recent Windows 10 Previews
  + Linux Additions: fixed a compatibility issue with 64-bit Linux 2.4 kernels
  + Linux Additions: fixed a potential use-after-free when unloading the VBoxGuest module
  + Linux Additions: Linux 3.19 fixes (bug #13741)
* Wed Jan 28 2015 tchvatal@suse.com
- Cleanup with spec-cleaner
- Remove really obsolete conditionals due to buildstatus everywhere
* Wed Dec 17 2014 coolo@suse.com
- update to version 4.3.20 (bnc#914447):
  + CVE-2014-0224 CVE-2015-0377 CVE-2014-6595 CVE-2014-6588 CVE-2014-6589
  + CVE-2014-6590 CVE-2015-0427 CVE-2015-0418
  + VMM: fixed reboot hang of 32-bit Windows SMP guests (bug #13319, #13462)
  + VMM: proper Math Fault handling with certain legacy guests (bug #9042, AMD hosts)
  + VMM: fixed a Guru Meditation VINF_EM_TRIPLE_FAULT on older CPUs that don't support MSR-bitmaps (VT-x only; bugs #13034, #13125, #13311, #13425, #13426, #13463, #13585)
  + GUI: fix 3D overlay window re-parenting issue when VM goes to full screen mode on X11 hosts.
  + GUI: fix occasional loss of focus in full-screen mode on X11 host systems (4.3.16 regression)
  + GUI: Mac OS X: wizards should have Cancel button (bug #12541)
  + GUI: added a global option to prevent automatic raising of the new window by mouse move with multi-screen guests (bug #8878)
  + API: accept remote display port 0 as the default RDP port (bug #8534)
  + VBoxManage: fixed crash when executing showvminfo command under certain circumstances (bug #13190)
  + ACPI: fixed occasional Guru Meditations in ACPI timer code (4.3.18 regression; bug #13521)
  + EFI: improved performance of IDE disk access
  + EFI: fixed a bug in the EFI video driver which prevented Windows to boot in UEFI mode (bug #12022)
  + EFI: properly announce the amount of RAM for big VMs (bugs #11103 and #13211)
  + Storage: fixed a crash under certain circumstances when a medium was ejected from a drive attached to the SATA controller without inserting a new medium before pausing or closing the VM (4.3.16 regression)
  + Storage: fixed an interrupt acknowledge issue causing hanging guests or slower I/O (4.3.18 regression)
  + Storage: fixed broken resume after the VM was suspended due to a full disk if host I/O caching is used
  + Storage: fixed a Guru Meditation under certain conditions when using the DevLsiLogic controller with VMs running in raw mode (4.3 regression; bugs #12254, #12655, #12709, #12774, #12886)
  + Guest Control: fixed a bug which might lead to a crash during recursive copy
  + SDK: Java COM bindings fixes
  + iPXE: enable the HTTP download protocol (bug #13628)
  + Runtime: do not use a fixed stack size creating temporary threads during initialization (bug #13038)
  + Windows hosts: fixed more startup problems on certain Windows hosts due to conflicts with anti-virus software; better error reporting (4.3.14 regression; bug #13187)
  + Windows hosts: fixed DirectSound host audio failure under certain conditions (bug #13418)
  + Windows hosts: fixed additional cases of 4.3.14 regression whereby AltGr stopped working for some people (bug #13216)
  + Windows Additions: preserve guest monitor layout when resizing Windows 7 or newer guests
  + Linux Additions: Linux 3.18 compile fixes (bug #13515)
- download the Manual directly without rename
* Tue Oct 14 2014 mseben@gmail.com
- fix /usr/lib/virtualbox *.so files permissions
* Mon Oct 13 2014 renda.krell@gmail.com
- update to version 4.3.18:
  == since 3.4.16 ==
  + VMM: fixed a potential misbehavior after restoring the A20 state from a saved state
  + GUI: fixed full-screen mode mini-toolbar related regressions for different platforms and window managers (bug #13369)
  + GUI: X11: fixed full-screen mode Unity panels quirk caused by mini-toolbar code changes in last release (bug #13365)
  + GUI: X11: added possibility to use legacy full-screen mode as the new one can cause multi-screen issues under Unity, see the manual for more information (bug #13365)
  + GUI: Mac OS X: fixed full-screen mode artifact causing black screen when 3D acceleration was enabled on 10.10 Yosemite hosts (bug #13448)
  + GUI: Mac OS X: fixed regression in user-space swiping from/to VBox in full-screen mode
  + GUI: Mac OS X: fixed issue with switching to VBox in full-screen mode through Alt+Tab and Mission Control
  + Storage: fixed data corruption when resizing huge VHD images under certain circumstances (bug #11960)
  + Storage: fixed a rare hang during startup when the BIOS enumerates the storage devices attached to the SATA controller
  + Storage: follow the spec with AHCI interrupt acknowledge (bug #13474)
  + Storage: fixed broken iSCSI authentication (4.3.14 regression, bugs #13386, #13435)
  + NAT Network: properly parse port forwarding rules to allow UDP rules
  + USB: fixed a crash on Linux hosts with older Linux kernels (bug #13400) and several other fixes
  + ACPI: fixed ACPI timer anomalies (bug #12076)
  + Guest Control: fixed a memory leak (bug #13434)
  + Main: when removing a VM, do also remove the VBoxStartup.log file which might exist on Windows hosts (bug #13478)
  + Windows hosts: fixed more startup problems on certain Windows hosts due to conflicts with anti-virus software; better error reporting (4.3.14 regression; bug #13187)
  + Windows hosts: propagate the process startup information to the child process (4.3.14 regression; bug #13243)
  + Mac OS X hosts: don't force using the discrete GPU (bug #11111)
  + Windows Additions: some Windows 10 tweaks
  + X11 guests: fix a bug handling video driver display properties which prevented GNOME Shell on Fedora 21 from starting
  + Linux hosts / guests: fixed a few remaining warnings in the kernel log if memory allocation fails (bug #11171)
  == since 4.3.14 ==
  + VMM: fixed restoring 32-bit FPU state on 64-bit capable VMs and restoring guest FPU in raw-mode VMs (bug #12646; 4.3 regression)
  + GUI: properly restore normal/scale mode guest-screen size after exiting full-screen/seamless mode
  + GUI: mini-toolbar should provoke less artifacts/conflicts with 3D guest rendering
  + GUI: Mac OS X: Native full-screen multi-screen transition was able to blackout host-screens for nearly minute
  + GUI: X11: Modern window managers should now use native full-screen multi-screen mapping API
  + GUI: added extradata item for configuring the mouse capture behavior, see the manual for more information (bug #3506)
  + Storage: fixed a VBoxSVC crash when querying an iSCSI target with authentication configured (4.3.14 regression)
  + Storage: fixed a rare data corruption during reads if another allocating write is running concurrently and accesses the same range
  + Storage: fixed a rare crash for certain VHD images from other products
  + Storage: fixed a rare release assertion when using the AHCI controller
  + Floppy: fixed read errors and guest memory corruption when running under control of QEMM
  + 3D: added experimental support for rendering on offline GPUs for Mac OS X host
  + 3D: fixed white window appearing on entering FullScreen mode on OSX host
  + 3D: fixed video recording support for 3D data regression (bug #13073)
  + 3D: fixes for MS Office 2013 support
  + 3D: several fixes
  + Bridged Networking: improved IPv6 support when bridging to a wireless interface
  + NAT: prevent internal DNS service from stuck in host-resolver mode when host was switched from one network to another one while host was sleeping (Mac OS X hosts)
  + NAT: preserve DF (if possible) and TOS when proxying outbound UDP datagrams (bugs #9440, #12309)
  + NAT: don't let multicast datagrams out (bug #7338)
  + NAT: fixed handling of large incoming UDP datagrams on Windows hosts (bug #12136)
  + NAT: fixed handling of the RFC 1533 DHCP PAD option
  + NAT Network: fixed inbound half-close on Windows hosts
  + NAT Network: preserve IPv4 DF (if possible), TTL, TOS and IPv6 Hop Limit when proxying outbound UDP datagrams
  + VRDP: fixed a rare crash when using remote audio input
  + USB: fixed several regressions from 4.3.14 (bug #13320)
  + Audio: made the HDA sound emulation work with certain OSX guests (e.g. Mountain Lion)
  + Windows hosts: fixed startup problems on certain Windows hosts due to conflicts with anti-virus software (4.3.14 regression, bug #13187)
  + Windows hosts: fixed 4.3.14 regression whereby AltGr stopped working for some people (bug #13216)
  + X11 hosts: made the extra key on Brazilian Thinkpads work (bug #8745)
  + X11 hosts: fixed a problem of input focus cycles and immediately released key presses in full screen mode (bug #13238)
  + Linux hosts: fixed flooding the kernel log with USB related messages when passing through certain USB devices to a VM (bug #13085)
  + Linux guests: stop applications crashing when drm_wait_vblank is called (bug #13265)
  + Linux guests: fix a crash in gnome-session (bug #13335)
  + X11 guests: do not start VBoxClient over an SSH connection (bug #13107)
  + X11 guests: added support for X.Org Server 1.16 (bug #13207)
  + X11 guests: fixed a wrong parameter in the video driver which caused problems with full-screen X11 clients (bug #2748)
  + VirtualKD: introduced stub/loader device for speeding up Windows kernel debugging, details see  http://virtualkd.sysprogs.org/
- removed virtualbox-xserver-116.patch, already available upstream
* Mon Sep  8 2014 mseben@gmail.com
- modify hint message in virtualbox-60-vboxdrv.rules, so udev rules
  will stay enabled also after package update
* Tue Aug  5 2014 wbauer@tmo.at
- Updated virtualbox-xserver-116.patch to the actual upstream commits.
  The previous version contained outdated X11 includes, so the resulting
  vboxvideo driver didn't actually work with Xorg 1.16 in Factory.
* Mon Jul 21 2014 mseben@gmail.com
- update to version 4.3.14:
  + VMM: more fixes for MSR emulation on certain hardware (bugs #12784, #12949, #13034)
  + VMM: improve MSI handling under rare circumstances (only relevant for the ICH9 chipset)
  + VMM: fixed #UD exception for 64-bit guests with the EFER.SCE bit and the SYSCALL instruction (VT-x only; 4.3 regression; bug #13008)
  + VMM: fixed timekeeping after resuming SMP guests
  + VMM: properly wake up a halted VCPU on NMI/SMI
  + GUI: fixed a potential crash
  + GUI: fixed stuck AltGr key on Windows hosts (bug #2537)
  + GUI: fixed a potential error during the version check
  + GUI: shortcut change should not require Enter/Return (or other trigger) to confirm (bugs #12828, #12847, #12937, #13087)
  + GUI: fixed update check which was broken due to changing the location of the root certificates (bug #13096)
  + VBoxManage: fixed typo in showvminfo --machinereadable (bug #13176)
  + NAT: fixed inbound half-close (bug #13116)
  + NAT: fixed slow upload speed under certain conditions (bug #10034)
  + NAT Network: fixed potential loss of inbound TCP data
  + NAT Network: fixed potential infinite stalls of TCP connections over IPv6
  + NAT Network: fixed resets of TCP connections on Windows hosts
  + NAT Network: fixed inbound half-close on Mac OS X hosts
  + NAT Network: fixed socket leak on Solaris hosts
  + NAT Network: fixed ping of mapped host loopback on Mac OS X and Solaris hosts, fixed proxying of IMCP errors on Mac OS X
  + Host-Only Network: fixed SNMP ifConnectorPresent value on Windows (bug #13143)
  + Storage: fixed a possible crash with CD/DVD passthrough under certain circumstances
  + Storage: fixed a crash when trying to open an inaccessible QED or QCOW image (bug #12613)
  + Storage: fixed data corruption or read errors under rare circumstances
  + AHCI: fixed a crash under rare circumstances
  + USB: performance fixes
  + ICH9: properly reset MSI capability on reset
  + Keyboard: active modifier keys during suspend were stuck after resuming the host
  + 3D: fixed misbehavior with huge guests (i.e. guest more than 4GB guest memory
  + 3D: several fixes
  + API: properly detect the Windows 8.1 guest OS type (bug #13090)
  + ExtPack: cleanup of dangling uninstallation directories
  + Linux hosts / guests: compile fix for EL7 (bug #12638)
  + Linux Additions: made 3D pass-through work with recent versions of Mesa in the guest (bug #12941)
  + Linux Additions: Linux 3.16 fixes (bug #13123)
  + Mac OS X hosts: when scanning for host CD/DVD devices also consider BlueRay devices
  + OS/2 Additions: fixed gengradd.dll library name (bug #12785)
  + Solaris Additions: fixed permissions of files and directories located on shared folders
  + Windows host installer: fixed the need for rebooting Windows after installation or upgrade, extended logging for NetFlt/NetAdp (un)installation
* Tue May 27 2014 mseben@gmail.com
- Update ot version 4.3.12:
  + VMM: fixed an occasional Guru Meditation (Mac OS X hosts only; bugs #12727, #12954)
  + VMM: fixed a rare condition that would fail to invalidate guest TLB entries or would invalidate them when not required (Windows hosts only)
  + VMM: fixed a VERR_NOT_SUPPORTED Guru Meditation seen with certain guests, e.g. OpenServer 5.0.7
  + VMM: more fixes for MSR emulation on certain hardware (tickets #12240, #12875)
  + GUI: fixed mouse positioning with mouse integration disabled and multiple guest screens (Windows hosts only; bug #9059)
  + GUI: fixed crash in VM manager (bug #12878)
  + GUI: fixed crash under rare conditions on entering/exiting fullscreen/seamless mode
  + Shared Clipboard: don't stop working after taking a snapshot (bug #12700)
  + AHCI: fixed a crash under rare circumstances
  + API: fixed a hang during VM shutdown under rare conditions
  + NAT: fixed generation of malformed ICMP error datagrams (4.3.10 regression)
  + NAT: fixed potential crash in DNS proxy
  + NAT Network: don't drop port forwarding rules after some time
  + NAT: fixed ARP cache corruption and network loss in Windows guest caused by iSCSI service activity
  + USB: improved check if a storage device is currently mounted to the host when the device is about to be attached to the VM (Mac OS X hosts only; #11038)
  + 3D support: several fixes, including better support for Ubuntu 14.04
  + VRDP: fixed a potential crash on client disconnect (bug #12858)
  + VBoxSVC: fixed a race when a new client is started a few seconds after the last client terminated (Windows hosts only; bugs #11309, #12509)
  + VBoxSVC: fixed VirtualBox.xml registry corruption after VM renaming
  + VBoxSVC: fixed a potential crash caused by incorrect USB device filter (Mac OS X hosts only; #11038)
  + Windows hosts: partly support 32-bit COM on 64-bit systems
  + Windows host installer: implemented merge module (msm) support
  + Linux hosts: fixed dependency of boot script on older Debian systems (bug #12262)
  + Linux guests: fix symbolic link to shared folder helper (bug #12879)
  + Linux Additions: don't crash VBoxService during guest execute for users without a password (bug #12994)
  + Linux Additions: fixed a bug in guest execution where the guest process terminated with VERR_INTERRUPTED to the host
* Mon May  5 2014 speilicke@suse.com
- Update to version 4.3.10:
  + VMM: more work on improving the emulation of certain MSR registers on certain host CPUs (e.g. bugs #12734, #12736, #12744, #12748, #12686, #12770)
  + VMM: fixed single-stepping for real-mode guests (VT-x without unrestricted guest execution) and some I/O instructions (bug #12636)
  + VMM: fixed a potential problem with COW pages if nested paging is not available
  + GUI: Mac OS X: experimental native full screen support for Mountain Lion and Mavericks (bug #12292)
  + GUI: Mac OS X: removed the mini-toolbar minimize button which doesn't work under Mac OS X full screen mode anyway
  + GUI: experimental HID LEDs synchronization for Windows and Mac OS X hosts: fixed keyboard re-synchronization if the feature is disabled (as done by default; bug #12758)
  + GUI: fixed a potential crash when opening the preferences menu (bug #12862)
  + OVF: fixed a crash of the VirtualBox Manager when re-starting guest export (bug #12586)
  + 3D support: several fixes
  + HGCM: fixed a problem with saved states which could cause several guest misbehavior after a VM was started from a saved state
  + Storage: fixed a bug preventing to compact differential snapshots under certain conditions
  + VBoxSVC: fixed a segmentation fault on Linux hosts if a very long path exists under /dev (bug #12760)
  + API: fixed guest misbehavior under certain conditions if a storage medium was attached or removed at VM runtime
  + Windows installer: make the --silent parameter work again (bug #12764)
  + Linux Additions: install correctly on Ubuntu guest systems with a /usr/lib64 directory (bug #12513)
  + X11 Additions: fix for the VBoxClient process not exiting correctly (bug #12348) and consuming too much processor time
- Refresh virtualbox-xserver-116.patch to xorg-server-1.15.99.902 with
  x.org video driver protocol version 17.0
- Set mode of /usr/lib/virtualbox/VirtualBox to 4750 to match /etc/permissions.easy
  as newly complained by chkstat (due to ro's change)
* Mon Mar 24 2014 speilicke@suse.com
- Add Virtualbox-xserver-1.16.patch: Compatibility with xserver-1.16
* Mon Mar  3 2014 speilicke@suse.com
- Update to version 4.3.8:
  + VMM: more work on improving the emulation of certain MSR registers (e.g. bugs #12224, #12544)
  + VMM: fixed a VERR_INVALID_RPL Guru Meditation when booting certain guests (bug #11350)
  + VMM: experimental support for SSE 4.1 / SSE 4.2 passthrough, see the manual for more information how to enable it (bug #8651)
  + VMM: fix for recent Linux kernels with software virtualization
  + GUI: experimental HID LEDs synchronization for Windows hosts, see the manual for more information
  + GUI: warn the user if the Oracle Extension Pack is not installed and the user tries to activate the remote display feature (bug #9104)
  + GUI: make sure that a minimized guest (using mini toolbar in fullscreen/seamless mode) keeps the minimized state (bug #12199)
  + GUI: popup banner's "do not show this message again" check-box replaced with corresponding button
  + GUI: network adapter cables can now be connected/disconnected directly through the running virtual machine Devices / Network menu a Network status-bar indicator
  + GUI: the new VM wizard now proposes 64-bit guests on 64-bit hosts by default; better distinction between 32-bit OS types 64-bit OS types (bug #12533)
  + GUI: better error message if appliance import fails (bug #12657)
  + GUI: allow to set host-combination to 'None' using the Global settings / Input page (bug #12730)
  + GUI: don't switch the guest to a black screen during online snapshot merge (4.3 regression)
  + VBoxManage: when exporting an appliance, support the suppression of MAC addresses, which means they will be always recreated on import, avoiding duplicate MAC addresses for VMs which are imported several times
  + AHCI: fixed a VM hang during suspend under certain circumstances
  + AHCI: fixed a VM hang during online snapshot merge under certain circumstances
  + AHCI: fixed a bug which resulted in Windows XP guest hangs if a SATA CDROM is attached (bug #12417)
  + AHCI: fixed a Guru Meditation under certain conditions
  + AHCI: ejecting a CD/DVD medium failed under certain conditions
  + AHCI: disk hotplugging fixes
  + NAT: transparent handling of host sleep/resume and network configuration changes if the dnsproxy is enabled or if the hostresolver is used (bug #12441)
  + NAT: fixed crash and misbehaviour under some circumstances with ICMP packets having TTL=1
  + NAT Network: fixed IPv6 reassembly
  + NAT Network: ping proxy implemented
  + OVF: fixed reading of the OVF 0.9 section element (4.3 regression; bug #12345)
  + OVF: several fixes
  + 3D: several fixes, multiscreen fixes (e.g. bug #9124)
  + 3D: include 3D content in captured videos (bug #12666)
  + 3D: include 3D content in captured screenshot (bug #11758)
  + VGA: proper handling of legacy graphics modes if the Guest Additions are active (bug #6649)
  + USB: fixed crash during isochronous transfer under rare circumstances
  + BIOS: better disk geometry handling of SCSI drives
  + API: fix crashes in Java API clients using the XPCOM binding, happened with output parameters only (bug #11232)
  + VBoxSVC: documented the handling of host power management events (see the manual for more information) and added an extradata item for configuring the handling of the battery-low event (bug #9925)
  + VBoxSVC: fixed a bug which could trigger a crash if a VM snapshot was restored the second time and the VM has associated bandwidth groups (bug #12569)
  + VBoxSVC: properly detect ifconfig if located in /bin (bug #12713)
  + Shared Folders: fixed a failure to restore transient shared folders when starting a VM from a saved state (bug #12578)
  + Mac OS X hosts: fixed issue when the application icon was frozen in the dock if the bridging interface was not connected to a network (bug #12241)
  + Linux hosts: also consider the physical package ID when determining the number of physical CPU cores
  + Linux hosts / guests: don't warn in kernel log if memory allocation fails (bug #11171)
  + Solaris hosts: fixed the autostart SMF script (bug #11720)
  + Windows hosts: fixes for non-ANSI code page user names and similar environment contents (bug #12596)
  + Windows hosts / guests: fixed setting and using a guest user's process environment variables (relevant for Guest Control)
  + Windows Additions: fixed handle leaks in VBoxTray (bug #12563)
  + Windows Additions: fixed a crash while detecting active guest users
  + Windows Additions: fixed restoring backed up D3D files on XPDM -> WDDM upgrade
  + Guest Control: fixed setting and using a guest user's process environment variables
  + Linux Additions: support Enterprise Linux 6.5 kernels (bug #12505)
  + Linux Additions: fixed CPU hot-remove on newer Linux kernels
  + Linux / Solaris Additions: don't automount a shared folder which is already mounted
  + X11 Additions: support X.Org Server 1.15 (bug #12623)
- Rebased patches:
  + vbox-default-os-type.diff
  + vbox-no-build-dates.diff
- Dropped patches:
  + virtualbox-xorg-1.15.patch (merged upstream)
* Sun Jan 19 2014 andreas.stieger@gmx.de
- fix build (script handling)
* Sun Jan 19 2014 speilicke@suse.com
- Add missing %%{_vbox_instdir}/VBoxNetNAT.so
* Fri Jan 17 2014 speilicke@suse.com
- Update to version 4.3.6:
  + VMM: fixed a Guru Meditation VINF_EM_TRIPLE_FAULT caused by VMCB caching with nested paging on certain AMD CPUs (bug #12451)
  + VMM: fixed a Guru Meditation VERR_VMX_UNEXPECTED_INTERRUPTION_EXIT_TYPE while intercepting debug exceptions (VT-x only; bug #12410)
  + VMM: fixed a Guru Meditation VERR_SVM_UNEXPECTED_EXIT while intercepting debug register accesses (AMD-V only; bug #12481)
  + VMM: fixed a VERR_SSM_STRUCTURE_MAGIC error when trying to load a saved state made with VBox 4.3.4 when VT-x/AMD-V is disabled. Unfortunately, VBox 4.3.4 produced broken saved states for this configuration so you have to discard these states (bug #12414)
  + VMM: added a few more MSRs to the whitelist required by certain guests (bug #12245)
  + GUI: fixed deleting of inaccessible VMs (4.3 regression, bug #12205)
  + GUI: fixed warnings in VM settings / number of guest processors (bug #12480)
  + Main: don't automatically enable 64-bit guests on 64-bit hosts if VT-x/AMD-V is not available (bug #12424)
  + Main: always expose the DMI memory information to Windows 2012 guests (bug #12017)
  + Main: fixed occasional crashes on guest display resolution change (bug #7063)
  + Main: fixed reporting back temporary name when calling IGuestSession::DirectoryCreateTemp() (bug #12498)
  + API: fix for a hang when launching a GUI VM through the API, which crashes due to GUI unavailability
  + Storage: fix for BLKCACHE_IOERR runtime errors under rare circumstances (bug #11030)
  + Network: allow to start more than 5 PCNet instances (bug #12426)
  + E1000: if the cable was disconnected before the guest initialized the device, the link status was not properly set to 'down' after the initialization completed despite the fact that there was no connection
  + 3D support: fixed offset of guest 3D image elements (Mac OS X Retina hosts only; bug #11021)
  + Solaris hosts: fixed accessing the host driver from non-global zones (4.3 regression, bug #12271)
- For more changes see https://www.virtualbox.org/wiki/Changelog
- Add source services (refresh_patches ATM)
- Rebased patches:
  + vbox-disable-updates.diff (only offset)
  + vbox-fpie.diff (only offset)
  + vbox-deprec-gsoap-service-proxies.diff (manually)
  + vbox-gsoapssl-deps.diff (manually)
  + vbox-no-build-dates.diff (manually)
  + vbox-permissions_warning.diff (manually)
  + vbox-python-detection.diff (manually)
  + vbox-smc-napa.diff (manually)
  + vbox-vboxdrv-init-script.diff (manually)
  + vbox-vboxweb-init-script.diff (manually)
  + virtualbox-xorg-1.15.patch (only offset)
- Dropped patches:
  + vbox-ret-in-nonvoid-fnc.diff (obsolete)
- Fix smp_mflags typo
- Add buildrequires: device-mapper-devel, libvpx-devel
* Wed Jan 15 2014 sndirsch@suse.com
- added virtualbox-xorg-1.15.patch to support xorg-server 1.15
* Thu Jan  9 2014 joerg.lorenzen@ki.tng.de
- added subpackage virtualbox-guest-desktop-icons, contains icons
  to provide os-specific icons for guest desktop files created on desktop.
* Fri Dec 13 2013 coolo@suse.com
- update to 4.2.20, this is a maintenance release. The following items were fixed and/or added:
  * GUI: always report recommended resolutions for all monitors (not always done since 4.2.12)
  * GUI: make sure the assigned license and description are attached to the exported appliance
  * GUI: the OS X hot corners were not accessible while a VirtualBox VM is running (Mac OS X hosts only; bug #4139)
  * NAT: don't run into an infinite loop in case the host cannot access any DNS server (bug #12300)
  * NAT: don't re-connect the cable if the DNS information changes and the cable was disconnected before (bug #12225)
  * Main: properly save the passthrough flag for DVD drives without an attached medium
  * Keyboard: fixed a VM crash if a VM was resumed from a saved state where at least one key was pressed (bug #11289)
  * 2D Video acceleration: fix crashes on presentation mode switches (bug #9194)
  * Storage: fixed errors with snapshots when using QCOW or QED disk images
    (bug #12144)
  * Storage: fix for newer Linux kernels not detecting a hard disk as SSD when
    using the IDE or SATA controller (bug #12025)
  * Storage: fixed detection of CD/DVD media when switching from an empty to a
    host drive with passthrough enabled
  * Snapshots: fixed a bug which could result in lost medium attachments
    (4.2.18 regression, bug #11750)
  * Shared Clipboard: fixed potential SEGFAULT when working with UTF8 and UTF16
    content (Mac OS X hosts only)
  * OVF: fixed import logic for OVF appliances containing multiple VMs
  * Extpack Installer: make it work if the file is located in a folder with
    special characters
  * SDK: extended the functionality coverage for the C bindings
  * API: block the removal of the current snapshot if it has child snapshots
    (only relevant for VMs without snapshottable hard disks, their presence
    always prevented removal), which resulted in VM config corruption
  * API: mark VM configs with snapshots but without current snapshot as
    inaccessible, as this combination is nonsense
  * API: fixed information for some automatically generated events (only with
    XPCOM, Windows host was not affected), which caused errors when getting
    some of the attributes over the webservice (bug #12379)
  * Mac OS X hosts: support for Mac OS X 10.9 (Mavericks)
  * Mac OS X hosts: properly sign the kernel extensions for Mavericks hosts
    (bug #12256)
  * Mac OS X hosts: use a launchd script instead of the deprecated StartupItem
    mechanism (bug #8940)
  * Mac OS X hosts: fixed a bug where the VirtualBox dock icon was not properly
    removed from the dock after a VM terminated preventing Mavericks hosts from
    shutting (bug #12241)
  * Linux Additions: Linux 3.13 compile fix (bug #12358)
  * Linux Additions: Linux 3.12 compile fix (bug #12083)
  * Linux Additions: Linux 3.11 fix for shared folders (bugs #11946, #12128)
  * Linux Additions: compile fix for SLES11 SP3
  * Linux Additions: correctly set umask before installing (bug #12166)
  * Linux Additions: build the vboxvideo kernel module correctly on OL/RHEL 6.1
    guests (bug #11996)
  * Linux Additions: make 3D work on Slackware 14.1 (bug #12320 comments 3 and 4)
  * Windows Additions: fixed memory leak caused by WTSQuerySessionInformation()
    on Windows 2000 guests (bug #12072)
  * Windows Additions: multimonitor resize fixes
  * X11 Additions/3D: fix freezes starting 3D desktop (bug #11503, thank you
    Sam Spilsbury)
  * Guest additions/3D: fix an occasional dead-lock (bug #12319)
- obsolete vbox-shared-folder.diff
* Thu Oct 24 2013 mgorse@suse.com
- added vbox-shared-folder.diff to fix shared folders (bnc#841673).
* Wed Sep 25 2013 wbauer@tmo.at
- install udev rules and VBoxCreateUSBNode.sh to the correct
  directories (bnc#799741)
* Sun Sep 15 2013 mseben@gmail.com
- deprecated vbox-linux-3.11.diff
- updated to virtualbox 4.2.18
  * VMM: properly handle NMIs on Linux hosts with X2APIC enabled
  * VMM: fixed potential crashes with 64-bit guests on 32-bit hosts (bug #11979)
  * GUI / seamless: properly handle mouse wheel scroll events
  * GUI, VBoxManage: when unregistering a VM, also unregister the hard disk images which are used exclusively (bug #10311)
  * GUI: prevent crashes under certain conditions on X11 hosts
  * 3D: multiscreen fixes (incorrect mouse position, flickers)
  * 3D Support: several fixes for the Windows WDDM video driver (multiscreen, seamless)
  * Snapshots: made live snapshots work again (bug #9255)
  * Teleportation: made it work again (bug #9455)
  * VBoxManage: on snapshot take, --pause is default and --live is for doing live snapshots
  * VBoxSVC: don't crash on systems with many VLAN interfaces (Solaris hosts only)
  * Network: after the host resumes from suspend, disconnect and reconnect the virtual network cables to force renewing the DHCP leases for the guests. So far only Mac OS X hosts and Windows hosts (bug #10063).
  * NAT: on name server changes force a reconnect of the virtual network cable to notify the guest (Mac OS X hosts only)
  * Mac OS X installer: keep previously installed Extension Packs on VirtualBox upgrade
  * Linux hosts / guests: Linux 3.11 fixes (bug #12001)
  * Solaris hosts: fixed a potential kernel panic caused due to unexpected preemption due to logging.
  * Windows hosts: fixed an issue with USB2 devices being inaccessible when plugged into USB3 ports.
  * Linux Additions: added PCI device identifier to vboxvideo.ko fixing DRI initialization under certain conditions (bug #11957)
  * Linux Additions: fixed udev detection in the init script with Linux 3.x kernels
* Fri Aug 30 2013 mseben@gmail.com
- added vbox-linux-3.11.diff to fix build (upstream patch : https://www.virtualbox.org/changeset/47588/vbox)
* Wed Jul 24 2013 mseben@gmail.com
- updated to virtualbox 4.2.16
  * OVF/OVA: don't crash on import if no manifest is used (4.2.14 regression; bug #11895)
  * GUI: do not restore the current snapshot if we power-off after a Guru Mediation
  * Storage: fixed a crash when hotplugging an empty DVD drive to the VM
  * Storage: fixed a crash when a guest read from a DVD drive attached to the SATA controller under certain circumstances
  * EFI: don't fail with 64-bit guests on 32-bit hosts (bug #11456)
  * Autostart: fixed VM startup on OS X
  * Windows hosts: native Windows 8 controls
  * Windows hosts: restore native style on Vista 32
  * Windows hosts / guests: Windows 8.1 adaptions (bug #11899)
* Tue Jul  2 2013 sndirsch@suse.com
- install 1.14 vboxvideo driver on openSUSE 13.1 (bnc#826326)
* Sun Jun 30 2013 mseben@gmail.com
- updated to virtualbox 4.2.14
  * VMM: another TLB invalidation fix for non-present pages
  * VMM: fixed a performance regression (4.2.8 regression; bug #11674)
  * GUI: fixed a crash on shutdown
  * GUI: prevent stuck keys under certain conditions on Windows hosts (bugs #2613, #6171)
  * VRDP: fixed a rare crash on the guest screen resize
  * VRDP: allow to change VRDP parameters (including enabling/disabling the server) if the VM is paused
  * USB: fixed passing through devices on Mac OS X host to a VM with 2 or more virtual CPUs (bug #7462)
  * USB: fixed hang during isochronous transfer with certain devices (4.1 regression; Windows hosts only; bug #11839)
  * USB: properly handle orphaned URBs (bug #11207)
  * BIOS: fixed function for returning the PCI interrupt routing table (fixes NetWare 6.x guests)
  * BIOS: don't use the ENTER / LEAVE instructions in the BIOS as these don't work in the real mode as set up by certain guests (e.g. Plan 9 and QNX 4)
  * DMI: allow to configure DmiChassisType (bug #11832)
  * Storage: fixed lost writes if iSCSI is used with snapshots and asynchronous I/O (bug #11479)
  * Storage: fixed accessing certain VHDX images created by Windows 8 (bug #11502)
  * Storage: fixed hang when creating a snapshot using Parallels disk images (bug #9617)
  * 3D: seamless + 3D fixes (bug #11723)
  * 3D: version 4.2.12 was not able to read saved states of older versions under certain conditions (bug #11718)
  * Main/Properties: don't create a guest property for non-running VMs if the property does not exist and is about to be removed (bug #11765)
  * Main/Properties: don't forget to make new guest properties persistent after the VM was terminated (bug #11719)
  * Main/Display: don't lose seamless regions during screen resize
  * Main/OVF: don't crash during import if the client forgot to call Appliance::interpret() (bug #10845)
  * Main/OVF: don't create invalid appliances by stripping the file name if the VM name is very long (bug #11814)
  * Main/OVF: don't fail if the appliance contains multiple file references (bug #10689)
  * Main/Metrics: fixed Solaris file descriptor leak
  * Settings: limit depth of snapshot tree to 250 levels, as more will lead to decreased performance and may trigger crashes
  * VBoxManage: fixed setting the parent UUID on diff images using sethdparentuuid
  * Linux hosts: work around for not crashing as a result of automatic NUMA balancing which was introduced in Linux 3.8 (bug #11610)
  * Windows installer: force the installation of the public certificate in background (i.e. completely prevent user interaction) if the --silent command line option is specified
  * Windows Additions: fixed problems with partial install in the unattended case
  * Windows Additions: fixed display glitch with the Start button in seamless mode for some themes
  * Windows Additions: Seamless mode and auto-resize fixes
  * Windows Additions: fixed trying to to retrieve new auto-logon credentials if current ones were not processed yet
  * Windows Additions installer: added the /with_wddm switch to select the experimental WDDM driver by default
  * Linux Additions: fixed setting own timed out and aborted texts in information label of the lightdm greeter
  * Linux Additions: fixed compilation against Linux 3.2.0 Ubuntu kernels (4.2.12 regression as a side effect of the Debian kernel build fix; bug #11709)
  * X11 Additions: reduced the CPU load of VBoxClient in drag'and'drop mode
  * OS/2 Additions: made the mouse wheel work (bug #6793)
  * Guest Additions: fixed problems copying and pasting between two guests on an X11 host (bug #11792)
* Fri May  3 2013 mseben@gmail.com
- updated to virtualbox 4.2.12
  * VMM: fixed a Guru Meditation on putting Linux guest CPU online if nested paging is disabled
  * VMM: invalidate TLB entries even for non-present pages
  * GUI: Multi-screen support: fixed a crash on visual-mode change
  * GUI: Multi-screen support: disabled guest-screens should now remain disabled on visual-mode change
  * GUI: Multi-screen support: handle host/guest screen plugging/unplugging in different visual-modes
  * GUI: Multi-screen support: seamless mode: fixed a bug when empty seamless screens were represented by fullscreen windows
  * GUI: Multi-screen support: each machine window in multi-screen configuration should have correct menu-bar now (Mac OS X hosts)
  * GUI: Multi-screen support: machine window View menu should have correct content in seamless/fullscreen mode now (Mac OS X hosts)
  * GUI: VM manager: vertical scroll-bars should be now updated on content/window resize
  * GUI: VM settings: fixed crash on machine state-change event
  * GUI: don't show warnings about enabled or disabled mouse integration if the VM was restored from a saved state
  * Virtio-net: properly announce that the guest has to handle partial TCP checksums (bug #9380)
  * Storage: Fixed incorrect alignment of VDI images causing disk size changes when using snapshots (bug #11597)
  * Audio: fixed broken ALSA & PulseAudio on some Linux hosts due to invalid symbol resolution (bug #11615)
  * PS/2 keyboard: re-apply keyboard repeat delay and rate after a VM was restored from a saved state (bug #10933)
  * BIOS: updated DMI processor information table (type 4): corrected L1 & L2 cache table handles
  * Timekeeping: fix several issues which can lead to incorrect time, Solaris guests sporadically showed time going briefly back to Jan 1 1970
  * Main/Metrics: disk metrics are collected properly when software RAID, symbolic links or rootfs are used on Linux hosts
  * VBoxManage: don't stay paused after a snapshot was created and the VM was running before
  * VBoxManage: introduced controlvm nicpromisc (bug #11423)
  * VBoxManage: don't crash on controlvm guestmemoryballoon if the VM isn't running (bug #11639)
  * VBoxHeadless: don't filter guest property events as this would affect all clients (bug #11644)
  * Guest control: prevent double CR in the output generated by guest commands and do NLS conversion
  * Linux hosts / guests: fixed build errors on Linux 3.5 and newer kernels if the CONFIG_UIDGID_STRICT_TYPE_CHECKS config option is enabled (bug #11664)
  * Linux Additions: handle fall-back to VESA driver on RedHat-based guests if vboxvideo cannot be loaded
  * Linux Additions: RHEL/OEL/CentOS 6.4 compile fix (bug #11586)
  * Linux Additions: Debian Linux kernel 3.2.0-4 (3.2.39) compile fix (bug #11634)
  * Linux Additions: added auto-logon support for Linux guests using LightDM as the display manager
  * Windows Additions: Support for multimonitor. Dynamic enable/disable of secondary virtual monitors. Support for XPDM/WDDM based guests
  * X11 Additions: support X.Org Server 1.14 (bug #11609)
* Fri Apr 26 2013 fcrozat@suse.com
- Move udev rules to /usr/lib/udev/rules.d for openSUSE 12.3 (and
  later) and to /lib/udev/rules.d for older distributions.
* Fri Apr 19 2013 coolo@suse.com
- it fails without alsa-devel installed, so buildrequire it (somehow
  no longer dropped in)
* Mon Apr  8 2013 coolo@suse.com
- add a _constraints file to avoid random failures on small workers
* Sun Mar 31 2013 mseben@gmail.com
- added vbox-deprec-gsoap-service-proxies.diff to fix deprecated old-style C++ service proxies (use soapcpp2 -z1 flag)
- added vbox-gsoapssl-deps.diff as workaround to fix build
* Fri Mar 29 2013 mseben@gmail.com
- added VBoxCreateUSBNode.sh from vbox upstream for creating usb device nodes,
  by default this feature is disabled so you have to enable it in vbox udev rules by hand (bnc#799741)
- updated to virtualbox 4.2.10
  * GUI: fixed keyboard with XQuartz X server (bug #10664)
  * Main/Display: fixed a crash with multi-monitors under certain conditions (Mac OS X hosts only)
  * Main/Properties: fixed a crash under certain conditions, for example after wakeup from host hibernate (bug #11444)
  * Settings: don't lose the internal network settings if they are not currently active
  * Storage: another incompatibility fix for VHD differencing images with Hyper-V (bug #5990)
  * VBoxManage: don't read beyond the end of the file specified with export --eulafile (bug #11528)
  * Linux hosts / guests: Linux 3.9-rc0 compile fixes (bug #11529)
  * Linux Additions: fixed two warnings in the shared folders guest kernel module (bug #11390)
  * Linux Additions: don't crash VBoxService if libdbus is not available (bug #8638)
  * Windows Additions: fixed upgrading MultiMedia Redirection (MMR) support
* Wed Mar 20 2013 sndirsch@suse.com
- make HW Supplements for x11 subpackage conditional on
  xorg-x11-server package (bnc#810333)
* Sun Mar  3 2013 mseben@gmail.com
- updated to virtualbox 4.2.8
  * VMM: fixed guest crash with huge amount of guest RAM on VT-x hosts (bug #11306)
  * GUI: fixed a layout bug in the Mac OS X clone VM dialog (bug #10982)
  * GUI: not all the translation tags were taken into account during the language switch (bug #11342)
  * GUI: take guest screenshot dialog sometimes had no keyboard input available on Windows host
  * Main/Machine: fix generation of spurious event for inaccessible VMs which triggered an endless event generation loop in cooperation with the GUI which became unresponsive (4.2.6 regression, bug #11323)
  * Main/Display: fix for an access violation under certain conditions in multi-monitor configurations (bug #10539)
  * Main/Metrics: network metrics are now collected for active (up) interfaces only, the state of an interface being evaluated when the associated metric is enabled via setupMetrics
  * Snapshots: reduce the time for merging snapshots under certain conditions
  * Storage: fixed data corruption after resizing a VDI image under certain circumstances (bug #11344)
  * Storage: fixed non working online merging of snapshots (4.2.6 regression, bug #11359)
  * Storage: fixed crash when connecting to certain QNAP iSCSI targets
  * Storage: fixed incompatibility of VHD differencing images with Hyper-V (bug #5990)
  * Bridged Networking: fixed TCP pseudo header checksum computation for IPv6 (bug #9380)
  * 3D support: fix Battlefield 1942 game crashes (bug #11369)
  * Settings: really sanitize the name of VM folders and settings file, the code was disabled before (bug #10549)
  * Settings: allow to change VRDE settings for saved VMs
  * VBoxManage: don't crash during screenshotpng if there is no display (bug #11363)
  * Linux hosts: work around gcc bug 55940 which might lead to wrong kernel module code if gcc 4.7 is used to compile the 32-bit Linux host kernel (bug #11035)
  * Linux hosts: fixed inconsistent lock state and deadlock warnings on module load and VM startup when CONFIG_PROVE_LOCKING is enabled (bug #11318)
  * Linux hosts: made "]" key work again on Japanese keyboards
  * Mac OS X hosts: don't crash the kernel during dtrace if the VBox kernel extensions are loaded (10.6 hosts only; bug #11273)
  * Solaris / Mac OS X hosts: machine CPU load metrics now report 100%% when all cores are fully utilized (used to be a single core)
  * Solaris 11 host installer: wait for any services left over from a previous installation to be terminated to avoid confusing SMF.
  * Guest Additions: don't block signals for processes executed via guest control
  * Guest Additions: fixed a small memory leak in VBoxService (bug #10970)
  * Windows Additions: fixed shared folder issue with large reads/writes on 64 bit Windows guests (bug #11115)
  * Linux Additions: Linux 3.8 compile fixes (bug #11036)
  * X11 Additions: fixed blocked SIGALRM in 3D desktop sessions (bug #10987)
  * X11 Additions: fixed an unresolved reference in vboxvideo_drv for X.org 6.8 guests and before (e.g. RHEL4; 4.2.0 regression)
  * X11 Additions: fixed screen automatic resizing for guests with X.org 1.3 or older (4.2.0 regression)
* Fri Mar  1 2013 crrodriguez@opensuse.org
- vboxadd init script should not do anything if not running
  in a virtualbox guest.
* Mon Jan 21 2013 sndirsch@suse.com
- install 1.13 vboxvideo driver on openSUSE 12.3 (bnc#799480)
* Sat Dec 29 2012 mseben@gmail.com
- updated to virtualbox 4.2.6
  * VMM: don't inject stale VT-x events to prevent crashes after VM reset (bug #11256)
  * VMM: workaround for buggy BIOSes which enable MONITOR only for certain CPUs (bugs #9460, #10686)
  * GUI: fixed trimming of anti-aliased text in details-view element headers (4.2.0 regression)
  * GUI: fixed create-settings-file-alias functionality on Mac hosts (4.2.0 regression)
  * GUI: fixed take-guest-screenshot functionality on Windows hosts (bug #11095)
  * GUI: several minor fixes, including palette fixes (bug #11191)
  * GUI: fixed Windows 2012 OS type (bug #11206)
  * GUI: allow to terminate the VM even if VBoxSVC crashed
  * API: fixed cancelling of snapshots, previously this could lead to inconsistent VM configs (bug #6877)
  * API: fixed identifying disk images by UUID (bug #11209)
  * 3D Support: several fixes
  * VRDP: fixed occasional crash with external authentication (bug #11156)
  * VGA: fix for double scan text modes
  * USB: fixed invalid pending request count at the time of service of DEVICE POWER requests (Windows hosts only; bugs #10021, #11056)
  * USB keyboard: Korean keyboard workaround (bug #11150)
  * Storage: fixed hang with QCOW images and asynchronous I/O enabled
  * Storage: fixed hang with newer VHD images (bug #11279)
  * Storage: actually write the non-rotational flag to the VM settings (4.2.0 regression)
  * Virtio-net: fixed the problem with network statistics counters in Session Information dialog (GUI)
  * Metrics: introduced network rate and disk usage metrics
  * Metrics: fixed a crash under certain conditions on Solaris hosts
  * BIOS: fix for El Torito
  * Shared Folders: if the host folder of a shared folder mapping does not exist, keep it active but mark it as invalid to prevent inconsitent saved states (bug #11147)
  * VBoxManage: fixed converting disks from raw images
  * VBoxManage: show snapshot description in the VM or snapshot information
  * VBoxManage: make implicit opening of media consistent in all places dealing with media
  * VBoxManage: the iSCSI initiator name was not stored in the settings file when doing storageattach (bug #11212)
  * VBoxManage: metrics collect now properly handles 'CPU/MHz' and 'Net/*/LinkSpeed' metrics
  * VBoxManage: changing the image UUID or parent UUID as part of storageattach works now in all safe cases
  * VBoxManage: introduced storageattach --medium additions as a shortcut to mount the additions image (bug #11165)
  * OVF: fixed importing OVF files cerated by recent VMware products (bug #10905)
  * Linux hosts / Bridged Networking: fixed the problem with leaking connections in conntrack (bug #11178)
  * Linux Additions: added support for ConsoleKit sessions in the vminfo service of VBoxService
  * Linux Additions: don't crash during remount under certain conditions (bug #11291)
  * Linux/Solaris Additions: fixed guest memory metrics collection
  * Solaris hosts: added a dependency to ensure that the user directories are reachable when starting VBox services
  * Windows host installer: integrated user-contributed translations, thanks to all contributors!
  * Windows Additions: fixed auto-logon installation for Windows 8
  * Windows Additions: don't fail if the shared folders host service is not available
  * Windows Additions: fixed Guest Additions startup on Windows 2000 guests (bug #11253)
  * Windows Additions: auto-resize fixes for Windows 8 guests
* Sat Nov  3 2012 mseben@gmail.com
- updated to virtualbox 4.2.4
  * GUI: fixed validation warning on global settings / proxy page (4.2.2 regression, bug #11089)
  * GUI: fixed crash with multiple guest screens on certain conditions (OS X hosts only)
  * VBoxBalloonCtrl: fixed command line argument handling of ballooning module
  * VRDP: fixed occasional crash during a video playback in the guest (bug #11082)
  * BIOS: fixed broken DMI information (4.2 regression)
  * BIOS: workaround for booting from Windows 2000 floppy disks
  * EFI: fixed video mode selection loss on VM reboot (#10983)
  * Parallel: fixed parallel port printing failure/ paper queue empty error (Windows hosts only)
  * NAT: fixed crash on alias-less DNS responses when host-resolver is used
  * Storage: fixed hang under rare circumstances
* Sun Oct 21 2012 mseben@gmail.com
- updated to virtualbox 4.2.2
  * VMM: adapted to changes in Mac OS X 10.8.2 (bug #10965)
  * GUI: restored VM item tool-tip functionality (4.2 regression)
  * GUI: added group item tool-tip functionality
  * GUI: fixed handling of the .ova/.ovf file name association (4.2 regression)
  * GUI: it was not possible to change any setting before the first VM was created (bug #10928)
  * GUI: disable grouping action if all the selected items are full children list of the same group already
  * GUI: added menu for runtime drag-and-drop option change
  * GUI: cleanup shared-clipboard menu on visual-mode change
  * GUI: make sure VM receives keyboard focus on entering fullscreen-mode on Win host (bug #11051)
  * GUI: disable proxy authentication for security reasons
  * 3D Support: DrawIndexedPrimitiveUP implementation fixes for the Windows WDDM video driver (bug #10929)
  * Storage: fixed a release assertion in the AHCI emulation when requests where canceled with asynchronous I/O disabled
  * Storage: fixed a hang during VM reset under certain circumstances (bug #10898)
  * NAT: fixed a crash under rare circumstances (Windows hosts only; bug #10128)
  * NAT: automatically use the host resolver if the host name server is set to some unusual loopback value (bug #10864)
  * E1000: fixed a VirtualBox crash during intensive network transfers (4.2 regression; bugs #10936, #10969, #10980)
  * ICH9: fixed PCI bridge initialization
  * USB mouse: ensure that the last mouse event doesn't get lost if no URBs are available
  * BIOS: certain legacy guests (e.g. Windows 95) didn't find the boot device after a warm reboot
  * BIOS: don't trash the palette in text modes when setting the border color
  * EFI: fixed OS X guest autoboot (4.2 regression)
  * VBoxManage: fixed output of showvminfo --machinereadable (bug #10973)
  * VBoxManage: fixed parsing of storageattach --discard (bug #11023)
  * VBoxManage: fixed wrong output of the HPET setting in showvminfo (bug #11065)
  * VBoxManage: fixed closing the guest session after executing a guest process via guest control
  * VBoxShell: adaptions to interface name changes
  * Guest Additions device: fixed a Guest Additions hang when a machine was reset after a crash
  * Linux hosts / guests: Linux 3.7-rc1 fixes
  * Linux Additions: support X.Org Server 1.13
  * Linux Additions: fixed a hang when the X server was restarted with old guest kernels
  * Linux Additions: fixed a VBoxService crash during CPU hot remove (bug #10964)
  * Windows Additions: fixed automatic screen resize issue for NT4 guests
  * OS/2 Additions: fixed shutdown hang
  * OS/2 Additions: fixed mouse driver panic
  * Solaris hosts: fixed autostart service going into maintenance mode after all VMs started
  * Solaris hosts: fixed linking the host driver with the dtrace module
- added vbox-drop-fa-IR-translation.diff to fix build
* Thu Oct 11 2012 mseben@gmail.com
- fix build, point source command to current directory ( use source ./env.sh )
* Fri Sep 28 2012 seife+obs@b1-systems.com
- update to 4.2.0
  - rebase patches
  - remove kernel-3.6 patch, no longer needed
* Thu Sep 27 2012 idonmez@suse.com
- Add virtualbox-kernel-3.6.patch to fix compilation with 3.6 kernel
* Tue Jun 26 2012 mvyskocil@suse.cz
- let it build with all versions of openjdk
* Thu Jun 21 2012 mseben@gmail.com
- update to virtualbox 4.1.18 (This is a maintenance release)
  * VMM: fixed VERR_REM_VIRTUAL_CPU_ERROR under rare conditions after the guest has been reset (bug #5164 and others)
  * VMM: fixed host freezes with 64-bit guests on 32-bit Linux hosts (bug #10528)
  * VRDP: added a workaround for rdesktop clients not properly updating the screen size when minimized
  * AHCI: fixed a rare bug which can cause a guest memory corruption after the guest storage controler has been reset
  * NAT: another attempt to fix crashes under rare conditions (Windows hosts only; bug #10513)
  * Mac OS X hosts: addressed issues running Leopard / Snow Leopard (bug #10631)
  * Linux hosts / Bridged Networking: fixed the problem with device driver unloading on kernels 3.2.18 and newer due to an invalid reference counter (bug #10624)
  * Linux hosts / guests: Linux 3.5-rc1 fixes
  * Linux Additions: the guest content was sometimes not properly updated (bug #9887)
  * Solaris Additions: installer fix for X.org Server 1.11 and 1.12
* Fri Jun  1 2012 mseben@gmail.com
- use proper version of vboxvideo xorg driver (vboxvideo_drv_112)
  for 12.2 release
- adjust udev rules for vboxuser device on guest machine (file virtualbox-60-vboxguest.rules)
* Thu May 24 2012 mseben@gmail.com
- update to virtualbox 4.1.16 (This is a maintenance release)
  * VMM: fixed a Guru Meditation VERR_ACCESS_DENIED with certain guests (bugs #7589, #8247)
  * VMM: fixed a Guru Meditation VERR_PAGE_TABLE_NOT_PRESENT with Ubuntu 32-bit guests with nested paging enabled on AMD CPUs (bug #10183)
  * VMM: preserve segment limits and attributes when switching to unreal mode required for some legacy guests to work properly (VT-x without unrestricted guest execution only; bug #9941)
  * VMM: fixed a VM hang after a resume from pause / savestate with SMP guests in rare cases
  * 3D Support: several fixes for the Windows WDDM video driver crash
  * NAT: fixed a crash on attempt to process ICMP datagram under some circumstances (bug #10527)
  * Host-only Networking: lifted the maximal number of interfaces to 128 on Linux and Mac OS X hosts (there is no such limitation for Solaris and Windows hosts)
  * EFI: fixed wrong SEC/PEI Core entry point calculation (bug #10531)
  * VRDP: fixed a display update problem (bug #10503)
  * Main: set the proper VM state if savestate failed for some reason (bug #6189)
  * Main: more useful error message if a medium is inaccessible
  * VBoxManage: fixed controlvm savestate if the VM is already paused
  * Mac OS X hosts: addressed issues running on Mountain Lion Preview 3 (bug #10267)
  * Linux hosts: Linux 3.4 compile fixes
  * Linux hosts: fixed wrong help path in some rpm-based packages (bug #10418)
  * Guest Additions: fixed handling of custom environment variables during VBoxManage guestcontrol execute (bug #10581)
  * Windows Additions: fixed guest driver crash of VBoxSF in certain cases (4.1.10 regression, bug #10408)
  * Windows Additions: don't load the WDDM driver if 3D support is not available for Windows 8 guests to keep the guest maintainable in that case (still better to miss some features than providing a blank screen)
  * Solaris Additions: added support for X.org Server 1.11 and 1.12
* Tue May 15 2012 mseben@gmail.com
- modify vboxadd-init-script.diff to fix issues with missing
  config file on guest [bnc#761923]
* Sun Apr 29 2012 mseben@gmail.com
- use workaround for issue with kmk_sed and gcc4.7 http://svn.netlabs.org/kbuild/ticket/112,
  which breaks build, instead of kmk_sed use /usr/bin/sed
* Sat Apr 28 2012 mseben@gmail.com
- update to virtualbox 4.1.14 (This is a maintenance release):
  * Network: fixed the problem with packets larger than MTU-4 when PCnet or PRO/1000 was bridged to certain types of adapters on OS X hosts (bug #3783)
  * NAT: fixed a segfault under rare circumstances
  * 3D Support: fixed Windows WDDM video driver crash for SMP guests (bugs #10200, #10331)
  * Windows Guest Additions, VRDP: fixed occasional text corruption (bug #3001)
* Sat Apr 21 2012 mseben@gmail.com
- drop vbox-config.diff and use LocalConfig.kmk to properly define
  lib,app and doc paths (bnc#737525)
* Wed Apr  4 2012 mseben@gmail.com
- deprecated vbox-visibility.diff and vbox-gsoap_ssl.diff
- update to virtualbox 4.1.12 (This is a maintenance release):
  * VMM: fixed VERR_NOT_SUPPORTED and VERR_RAW_MODE_INVALID_SMP guru meditation due to an invalid reschedule to raw mode (bug #10370)
  * VMM: fixed PDMCritSectLeave guru meditation under rare circumstances with SMP guests
  * VMM: proper Math Fault handling with certain legacy guests (bug #9042)
  * NAT: fixed a socket leak under certain conditions
  * Storage: better sanity check against reading beyond end-of-file
  * Audio: fixed a crash in the NUL audio backend (bug #10374; 4.1.10 regression)
  * HGCM: fixed a crash during savestate under rare circumstances
  * VBoxSVC: several locking fixes
  * VBoxManage: return the correct error code if controlvm savestate failed (bug #10134)
  * Guest Additions: VBoxService should not crash on exit (bug #10326; 4.1.10 regression)
  * Windows Additions: set the correct time stamp when a file is closed (bug #6473)
  * Windows Additions: better help if the DirectX backups are not properly installed
  * Linux Additions: Linux 3.4-rc1 compile fixes
* Sun Apr  1 2012 mseben@gmail.com
- added vbox-gsoap_ssl.diff to fix building websrv with ssl support
- drop deprecated kernel-3.3.patch
- update to virtualbox 4.1.10 (This is a maintenance release):
  * GUI: if 3D support on the host is not available for some reason, do not only disable this VM setting but also uncheck the checkbox
  * VMM: fixed a potential problem causing to schedule interrupts during SYSEXIT right after STI
  * VMM: fixed a potential guest memory corruption issue with page fusion
  * VMM: adjusted the module matching algorithm for page fusion a little, generally resulting in slightly more shared pages
  * Main: host interfaces no longer have "defaults" for IP address and network mask attributes
  * Main: don't depend on a password for certain guest control operations (bug #10030)
  * 3D Support: fixed Windows XP hosts support (4.1.8 regression; bugs #10071 and #10088)
  * 3D Support: rendering fixes for Linux hosts with NVIDIA graphics
  * 3D Support: fixed saved state issues (4.1.8 regression; bug #10126)
  * 3D Support: WDDM driver: fixed powershell_ise crashes (bug #10167), make WPF-based apps work with Aero enabled, fixed additional possible WinSAT crashes
  * VRDP: fixed remote clipboard compatibility issues with some clients
  * Storage: fixed a possible data corruption when compacting VDI or VHD images with snapshots (32-bit hosts only)
  * iSCSI: fixed crash when using incorrect credentials when authenticating with a LIO target (bug #10173)
  * Serial: don't abort in host mode under rare error conditions (non-Windows hosts only)
  * SDK: actually ship current C bindings
  * SDK: fixed the Java glue code for JDK 1.7.0 (bug #9848)
  * SDK: added Python example
  * Metrics: make metrics collection more robust regarding blocked VMs
  * Web service: added SSL/TLS support
  * VBoxShell: fixed Guest Additions information lookup
  * Solaris installer: fixed dependency checking while installing VirtualBox in a zone
  * Linux hosts/guests: Linux 3.3-rc1 compile fixes
  * Solaris hosts: fixed debug kernel panics while opening module CTF data (bug #9651)
  * Mac OS X hosts: fixed Python support on Lion
  * Linux Additions: make 3D passthrough work on OL/RHEL 6.2 (bug #10010)
  * Linux Additions: fixed missing implementation when copying shared folder data through kernel high memory (bug #9878)
  * Linux Additions: make sure all data is written when closing a memory mapped file on a shared folder
  * Linux Additions: added support for X.Org Server 1.12
  * Solaris Additions: fixed guest kernel driver to load properly on guest reboot (4.1.8 regression; bug #10113)
  * Solaris Additions: fixed missing 64-bit OpenGL library VBoxOGL.so (bug #10151)
  * Solaris Additions: fixed VBoxService import and start for Solaris 11 guests.
  * Windows Additions: some Windows 8 adaptions
  * Windows Additions: several fixes for shared folders (bug #9753)
  * Guest control: miscellaneous bugfixes
* Sun Mar 18 2012 mseben@gmail.com
- use pie/fPIE for setuid binaries (vbox-fpie.diff) (bnc#743143)
- clean up virtualbox-60-vboxdrv.rules and use fillup_only for vbox sysconfig file
- added vbox-vboxweb-init-script.diff to use proper pid file and runlevels in vboxweb initscript
* Wed Mar 14 2012 mseben@gmail.com
- enabled websrv feature, this feature is now provided by new subpackage virtualbox-websrv
- added vbox-visibility.diff to fix websrv build (ommit -fvisibility=hidden gcc flag for gsoap related builds)
* Thu Mar  8 2012 idonmez@suse.com
- Drop unnecessary xorg-x11-libs-32bit buildrequires
- Fix build with linux kernel 3.3
* Tue Feb 21 2012 seife+obs@b1-systems.com
- remove build date from VBoxSVC
* Wed Dec 28 2011 mseben@gmail.com
- update to virtualbox 4.1.8
  * VMM: fixed VERR_MAP_FAILED during savestate under certain circumstances (bug #7929)
  * GUI: stop updating the VM status icons when the VM is paused (bug #8368)
  * VBoxManage: fixed wrong return code after startvm (bug #9642)
  * BIOS: fixed hang at launch of DOS applications generated by Clipper 5.3 (note that hardware virtualization may be required)
  * USB: fixed OS/2 boot hang when using recent USB drivers
  * NAT: increase maximum number of parallel connections making connections with port forwarding more robust (#8471)
  * Metrics: fixed potential problem with invalid access in guest metrics collection upon VM destruction
  * Main: don't crash if a medium is ejected twice (bug #9922)
  * VBoxSVC: fixed crash under rare circumstances (e.g. client crash)
  * VRDP: fixed screen freeze (bug #9620)
  * OVF/OVA: fixed broken disk images on import under rare circumstances
  * OVF/OVA: better error message when importing corrupted appliances
  * VMDK/VHD: fixed a possible corruption with host cache disabled when using snapshots under rare circumstances (bug #9749)
  * 3D Support: Fixed fullscreen mode issues for ATI graphics (bug #9775),
  * 3D Support: Windows Media Player rendering for XPDM-based Direct3D support (bug #8341).
  * 3D Support: Multiple fixes to XPDM and WDDM - based 3D support for Windows Guests and for 3D support in general
  * Linux hosts: fixes for Fedoras Linux 2.6.41 (bug #9948)
  * Linux hosts/guests: fixes for Linux 3.2 (bug #9743)
  * Solaris Additions: various shared folder fixes (bugs #9856, #9862, #9917)
  * Windows Additions: various fixes for Direct3D support (un)installation, added detection of missing or wrong Direct3D system files
* Wed Dec  7 2011 coolo@suse.com
- fix license to be in spdx.org format
* Wed Nov 16 2011 mseben@gmail.com
- dropped vbox-VBE_DISPI_INDEX_ENABLE.diff and vbox-disable_vboxpci_build.diff
- update to virtualbox 4.1.6
  * VRDP: fixed screen corruption
  * NAT: the interface stopped working after a lot of failed ICMP requests (bug #9371)
  * E1000: fixed rare Windows 7 guest hangs, either at boot time or when reconfiguring the network card in unusual setups (bug #6223)
  * ATA: fixed a possible crash during ATAPI passthrough with certain guests
  * ATA: improved compatibility with ancient Linux kernels
  * Main: fixed incorrect framebuffer information after leaving the fullscreen mode with X11 guests, this lead to a scrambled preview window in the GUI for example
  * Mac OS X hosts: fixed the problem with duplicate packets when bridged to a wireless interface (bug #9648)
  * Linux hosts: fix for 3D support on Fedora 15 (bug #9799)
  * Linux hosts: don't call del_timer_sync from an interrupt context (Fedora bug report 746331)
  * Windows Vista and 7 guests: more WDDM fixes
  * Linux Additions: fixed kernel module compilation failure on Redhat Enterprise Linux 4 (bug #9709)
  * Linux Additions: install the DRI driver correctly on Ubuntu 11.10 guests
  * Solaris Additions: added read-only mmap support for shared folders
  * Solaris Additions: added directory, file mode and mask options for shared folders
  * Windows Additions: implemented faster detection of logged-in guest users and stale sessions
  * X.Org Additions: fixed graphical corruption when switching to a virtual terminal (bug #9490)
* Wed Oct 19 2011 idonmez@suse.com
- Remove runlevel 4 from vboxdrv init script (bnc#724469)
* Fri Oct 14 2011 mseben@gmail.com
- drop $ALL target from vboxes init script (bnc#705505)
* Mon Oct 10 2011 mseben@gmail.com
- added vbox-VBE_DISPI_INDEX_ENABLE.diff to fix broken linux
  console after starting X (bnc#717713)
* Fri Oct  7 2011 mseben@gmail.com
- dropped xorg conf file virtualbox-60-vboxmouse.conf as there is
  no more vboxmouse_drv.so xorg driver on %%suse_version >= 1130
- modified virtualbox-60-vboxdrv.rules to use setfacl instead of GROUP rule
- update to virtualbox 4.1.4
  * VMM: fixed PAE guests running on 32-bit hosts (4.0 regression; bug #9458)
  * VMM: fixed INVALID_PARAMETER guru meditation caused by insufficient memory conditions (4.1.0 regression; bug #9240)
  * VMM: fixed clobbered CPU registers during stos/lods/ins/outs emulation under rare circumstances
  * VMM: another fix for 64-bit guests on recent AMD CPUs
  * GUI: warn the user if he uses an outdated extension pack and allow to download and upgrade in that case (bug #8025)
  * GUI: fixed spurious LCtrl key events on some Windows hosts (4.0.6 regression; bug #373)
  * VBoxManage: another fix for extpack install --replace (bug #9308)
  * VBoxManage: allow to specify the UUID of the target image in convertfromraw
  * VRDP: fixed a rare crash when two or more clients connect to the server (bug #9503)
  * VRDP: fixed a case when a client was not resized correctly (bug #9242)
  * USB: make device capturing work on Windows hosts with usbhub class filter drivers installed (bug #9298); bugfixes for Windows host USB support
  * VHD: fixed reads crossing block boundaries (bug #8532)
  * VMDK: fixed progress indicator when creating split VMDK images
  * Floppy: fixed medium size detection for physical mediums (Windows hosts only)
  * Main: fixed VM initialization if a shared folder does not exist (bug #7941)
  * Main: fixed possible deadlock between hard disk enumeration and resetting of immutable disks (bug #9549)
  * Main: fixed not detaching of virtual storage after a snapshot restore operation (bug #8296)
  * Main: always reset modified state after restoring a snapshot (bug #9387)
  * Main: fixed writing of changed VM settings to disk when using snapshots (bug #8932)
  * Main: fixed taking screen shots (e.g. the preview window) for headless VMs if the Guest Additions are active
  * Virtio-net: fixed the problem with UDP packets exceeding MTU (bug #9370)
  * 3D Support: fixed incorrect rendering and possible crashes when switching to/from fullscreen with enabled 2D acceleration
  * 3D Support: fixed compiz under ubuntu 9.10
  * Guest control: Miscellaneous small bugfixes
  * Linux / Solaris hosts: don't use hard links in packages (4.1.2 regression; bug #9441)
  * Mac OS X hosts: fix installation issues when installed as root (bug #1578)
  * Mac OS X hosts: fixed packet capture issues with vboxnetX host-only interfaces (bug #8076)
  * Solaris hosts: fixed incoming multicast packets for Crossbow based bridged networking (bug #9532)
  * Solaris hosts: fixed starting EFI guests due to missing EFI ROM files (bug #9535)
  * Windows hosts installer: fixed ADDLOCAL usage on command line (4.1.0 regression; bug #9488)
  * Windows hosts installer: fixed dangling shortcut to the .chm help file (bug #9646)
  * Windows hosts installer: try to fix installation error 2869 which appeared under certain circumstances (bug #9664)
  * Windows hosts: VBoxHeadless should never open a separate console window (bug #3549)
  * Guest Additions: fixed hang while waiting for guest execution output (4.1.2 regression; bug #9446)
  * Linux Additions: add support for X.Org Server 1.11 (bug #9519)
  * Linux Additions: suppress an incorrect error message and allow a shared folder to be mounted in multiple places (bug #9627)
  * Linux Additions: start VBoxService correctly on openSUSE 12.1 (bug #6229)
  * Linux Additions: properly finish the installation even if the compilation of the DRM module fails (which is not fatal)
  * Solaris Additions: fixed memory leaks and panics while mounting (from console) and unmounting shared folders.
  * Windows Additions: fixed swapped mouse cursor hotspot coordinates (4.1.0 regression; bug #9447)
  * Windows Additions: fixed PAGE_FAULT_IN_NONPAGED_AREA BSOD in VBoxDisp.dll when running SnippingTool (bug #9508)
  * Windows Additions: make image viewer work correctly with Aero enabled (Vista and Windows 7)
  * Windows Additions: fixed incorrect window border blurs under Aero with ATI cards (Vista and Windows 7)
  * Windows Additions: fixed incorrect rendering when moving 3D applications outside guest desktop and back under Aero (Vista and Windows 7)
  * Windows Additions: fixed guest hangs when switching back from fullscreen text mode apps (bug #9636)
* Mon Sep 19 2011 crrodriguez@opensuse.org
- Use config noreplace for udev rules, avoid overwrite of USB
  udev rules.
* Thu Sep 15 2011 mseben@gmail.com
- included proper versions of vboxmouse_drv and vboxvideo_drv (xorg drivers) in to
  virtualbox-guest-x11
- fixed typo in virtualbox-60-vboxdrv.rules
* Mon Aug 22 2011 mseben@gmail.com
- update to Virtualbox 4.1.2
  * VMM: fixed 64-bit guests on AMD Fusion CPUs (bug #8824)
  * VMM: fixed handling of the sysenter/sysexit machine instructions in 64-bit guests on Intel hosts
  * GUI: added linked clone support
  * GUI: fixed error check when changing the VM controller settings (4.1.0 regression; bug #9246)
  * GUI: fixed the inclusion of additional information (license, vendor, ...) on OVF export
  * GUI: when taking a snapshot from the VM selector, don't do a live snapshot
  * GUI: fixed immediate crash during start on certain environments due to a library version conflict
  * Guest control execution: implemented copying single files from guest to the host (directories and filters not supported yet)
  * Guest control execution: limited to serve up to 5 guest processes at a time by default
  * Main: return the correct RDP default port fixing settings warnings in the GUI if the remote display was enabled at runtime (bug #9368)
  * VBoxSVC: made the path comparison OS independent when images are registered (bug #9303)
  * VBoxSVC: several fixes/performance improvements for cloning of VMs
  * Snapshots: fixed "Solid-State drive" flag survival on snapshot creation (bug #9379)
  * VBoxManage: implemented copyfrom and stat guest control tools to copy files from guest to host and to check for existence of files on the guest
  * VBoxManage: fixed extpack install --replace (bug #9308)
  * VBoxManage: allow to start multiple VMs with startvm
  * VBoxManage: experimental support for SATA CD/DVD hotplugging
  * Mouse support: fixed an off-by-one pointer position error affecting Windows guests (bugs #7566, #9321)
  * VRDP: fixed a case when the screen was not redrawn correctly (bug #9242)
  * NAT: changed TCP connection establishment according to Winsock API requirements (Windows hosts only; bug #8919)
  * USB: fixed device recognition issues (bugs #9299) and fixed several device capturing issues (Windows hosts; bug #9299)
  * USB: fixed issues with remote filters being applied to local USB devices
  * OVA: fixed import of renamed OVA files (bug #9033)
  * Windows host: fixed icon for .VDI files (bug #9393)
  * Solaris hosts: fixed a bug preventing parallel usage of multiple host NICs with Crossbow based bridged networking
  * Linux hosts: fixed random kernel panics on host suspend / shutdown (4.1.0 regression; bug #9305)
  * Guest Additions: keep logged in user count in out-of-memory situations and warn about it
  * Solaris Additions: fixed shared folders due to missing symbols in the vboxfs module (4.0.12 / 4.1.0 regression; bug #9264)
  * Windows Additions: fixed file truncation on a shared folder with some applications (bugs #9276, #9315)
  * Windows Additions: fixed shared folder issues with antivirus software and 64 bit Windows guests (bug #9318)
  * Windows Vista and 7 guests: WDDM driver fixes and performance enhancements, fixed WinSAT crashes (#9267)
  * Linux Additions: fixed llseek() for Linux kernels 2.6.37 and above
* Tue Aug  9 2011 mseben@gmail.com
- modified usb udev rule in virtualbox-60-vboxdrv.rules (thanks to Dirk O. Kaar)
* Thu Jul 21 2011 mseben@gmail.com
- update to Virtualbox 4.1.0 (major update)
  * Support for cloning of VMs (bug #5853): full clones can be created through the GUI and VBoxManage, linked clones only through VBoxManage
  * GUI: enhanced wizard for creating new virtual disks
  * GUI: new wizard for copying virtual disks
  * GUI: keep the aspect ratio in scale mode (Windows and OSX hosts only; bug #7822)
  * VMM: raised the memory limit for 64-bit hosts to 1TB
  * Experimental support for PCI passthrough for Linux hosts, see the manual for more information
  * Windows guests: Experimental WDDM graphics driver, supporting Windows Aero (bug #4607) and providing Direct3D support using a cleaner approach (no need to install the guest drivers in Safe Mode anymore)
  * Guest Additions: status of modules and features can now be queried separately by the frontends
  * Networking: new network attachment mode "Generic Driver", which offers an open plugin architecture for arbitrary and separately distributable virtual network implementations
  * Host-only Networking: fixed host crash in kernels prior to 2.6.29
  * New Networking Mode UDP Tunnel: allows to interconnect VMs running on different hosts easily and transparently
  * Experimental support for SATA hard disk hotplugging available with VBoxManage
  * Solaris hosts: New Crossbow based bridged networking driver for Solaris 11 build 159 and above
  * VMM: more SMP timer fixes
  * VMM: fixed sporadic recompiler crashes with SMP guests
  * VMM: many small fixes
  * GUI: when reverting to a snapshot, ask for taking a snapshot of the current state
  * GUI: added a View menu
  * GUI: added a setting for the promiscuous mode policy for internal networks, bridged networks and host-only networks
  * GUI: added slider for setting the CPU execution cap allowing to limit the amount of CPU time spent for the execution of the guest
  * GUI: the VM description is editable during the runtime of a VM (bug #1551)
  * GUI: added proxy settings (bug #2870)
  * GUI: made the number of SATA ports configurable
  * GUI: decrease time before showing the VM configuration dialog
  * VBoxManage: more convenient configuration of storage controller attachments by automatically determining the port or device parameter when a storage controller has only one port or device per port
  * VBoxManage: changed syntax of the guestcontrol command group, fixed various bugs, removed obsolete options
  * VBoxBalloonCtrl: new service for automatic dynamic adjustment of the balloon size for running VMs
  * Settings: machine names and snapshot names are not allowed to be a valid UUID
  * Settings: provide better diagnostics if a single medium is used twice in a VM configuration
  * Settings: provide better diagnostics for errors in medium create/merge/clone operations, and fix memory leaks in error cases
  * Storage: ATA/SATA drives can be marked as non-rotational, i.e. the guest OS will detect them as a SSD if supported, which can improve performance
  * Storage: virtual CD/DVD images will be detached if the guest ejects the medium, unless the drive is marked to handle ejects only on a temporary basis
  * Storage: the medium UUID can be changed again when attaching a medium for the first time, which allows using images which are exact duplicates including the UUID
  * Storage: fixed possible data corruption under certain circumstances with VHD and Parallels images (bug #9150)
  * Storage: fixed unnecessary expansion when cloning differential images in VDI format
  * Storage: fixed detection code to handle empty files for VDI and VMDK format
  * Storage: fixed access to CD/DVD images beyond 4GB when using the SATA controller (bug #8592)
  * Floppy: several bugs have been fixed
  * Floppy: make it possible to unmount a host floppy disk (bug #6651)
  * BIOS: disk-related structures are now checksummed correctly (bug #8739)
  * USB: many fixes for the Windows USB host driver
  * NAT: reduced memory footprint
  * Networking: fixed the problem with segmentation offloading when several VMs are transmitting in parallel
  * Networking: workaround for a bug in wireshark when operating directly on a capture file created by VirtualBox
  * Serial: announce the serial devices in the ACPI tables to make Windows guests find the virtual hardware (bug #7411)
  * VRDP: support for TLS connections (see the manual for more information)
  * VRDP: support for multimonitor client configurations with MS RDP clients
  * VRDP: fixed a rare screen corruption
  * 3D support: fixed GL_VERSION string for different locales (bug #8916)
  * Webservice: fixed timeout handling with HTTP 1.1 keepalive, and be more robust when connections fail
  * VBoxSVC: fixed regression when several clients trigger autostart simultaneously
  * Main: fixed incorrect handling of the medium location for media which are not file based, which resulted in confusing location values in many places
  * JAX-WS client bindings: fixed resource leak
  * Sources: fixed USB 2.0 support using extension packs for non-official builds
  * Mac OS X hosts: fixed non-VT-x mode on Lion hosts
  * Windows hosts: fixed copy'n'paste in the GUI and for the VM window (bug #4491)
  * Windows hosts (64-bit only): enabled removing of all mediums when removing a VM
  * Windows hosts (64-bit only): enabled live snapshot deletion
  * Windows hosts: use native controls in the installer (bug #5520)
  * Solaris hosts: fixed preemption issue with Solaris 11 hosts (builds 166 and above)
  * Solaris hosts: better control of USB device access on Solaris 11 hosts
  * Guest Additions: improved driver installation on Windows guests
  * Guest Additions: fixed high CPU usage while executing guest programs from the host
  * Solaris Additions: fixed automounting of shared folders (bug #8014)
- deprecated vbox-netflt_start_xmit_enable.diff
- added vbox-disable_vboxpci_build.diff and vbox-fix-ftbfs-as-needed.patch.diff to fix build
* Thu Jun 30 2011 mseben@gmail.com
- update to Virtualbox 4.0.10
  * GUI: fixed disappearing settings widgets on KDE hosts (bug #6809)
  * Storage: fixed hang under rare circumstances with flat VMDK images
  * Storage: a saved VM could not be restored under certain circumstances after the host kernel was updated (bug #8983)
  * Storage: refuse to create a medium with an invalid variant (for example Split2G with VDI; bug #7227)
  * Snapshots: none of the hard disk attachments must be attached to another VM in normal mode when creating a snapshot
  * USB: fixed occasional VM hangs with SMP guests (bug #4580)
  * USB: proper device detection on RHEL/OEL/CentOS 5 guests (partial fix for bug #8978)
  * ACPI: force the ACPI timer to return monotonic values for improve behavior with SMP Linux guests (bug #8511 and others)
  * RDP: fixed screen corruption under rare circumstances (bug #8977)
  * rdesktop-vrdp: updated to version 1.7.0
  * OVF: under rare circumstances some data at the end of a VMDK file was not written during export
  * Mac OS X hosts: Lion fixes (bug #8903)
  * Mac OS X hosts: GNOME 3 fix
  * Linux hosts: fixed VT-x detection on Linux 3.0 hosts (bug #9071)
  * Linux hosts: fixed Python 2.7 bindings in the universal Linux binaries
  * Windows hosts: fixed leak of thread and process handles
  * Windows Additions: fixed bug when determining the extended version of the Guest Additions (4.0.8 regression; bug #8948)
  * Solaris Additions: fixed installation to 64-bit Solaris 10u9 guests (4.0.8 regression)
  * Linux Additions: RHEL6.1/OL6.1 compile fix
  * Linux Additions: fixed a memory leak during VBoxManage guestcontrol execute (bug #9068)
* Mon Jun 20 2011 aj@suse.de
- Add BuildRequires: glibc-devel-static
* Tue May 31 2011 mseben@gmail.com
- drop hal dependency from BuildRequires (bnc#697034)
* Thu May 26 2011 mseben@gmail.com
- added vbox-netflt_start_xmit_enable.diff (bnc#694311),
  enable alternative packet filter, http://www.virtualbox.org/ticket/8076
* Wed May 18 2011 mseben@gmail.com
- updated to Virtualbox 4.0.8 (maintenance release)
  * Mac OS X hosts: fixed incompatibility with recent Mac OS X versions in 64-bit mode (bug #8474)
  * Mac OS X hosts: fixed incompatibility with hosts with more than 16 cores (bug #8389)
  * Mac OS X hosts: fixed painting corruptions on a second monitor in 64-bit mode (bug #7606)
  * GUI: restored functionality to set an empty host key to disallow any host key combination (4.0.6 regression; bug #8793)
  * VBoxManage: added controlvm screenshotpng subcommand for saving the screenshot of a running VM in PNG format
  * VBoxHeadless: fixed potential crash during shutdown (Windows hosts only)
  * NAT: built-in services use the correct Ethernet addresses in Ethernet header and in ARP requests
  * Host-only networking: fixed adapter reference counting
  * E1000: fixed rare guest crashes with Linux SMP guests (bug #8755)
  * SATA: fixed guest disk corruption under rare circumstances (only relevant for guests with more than 2GB RAM; bug #8826)
  * Storage: fixed data corruption after a snapshot was taken with asynchronous I/O enabled (bug #8498)
  * Floppy: several improvement
  * HPET: another fix for time jumps (bug #8707)
  * USB: removed assumption that string descriptors are null-terminated (Windows hosts only)
  * 3D support: fixed a potential crash when resizing the guest window
  * 3D support: fixed GNOME 3 rendering under Ubuntu 11.04 and Fedora 15
  * Snapshots: fixed another bug which could lose entries in the media registry when restoring a snapshot (bug #8363)
  * Shared Folders: don't stop mounting the other valid folders if one host folder is inaccessible (4.0.6 regression)
  * Linux Additions: check whether gcc and make are installed before building kernel modules (bug #8795)
  * Solaris Additions: added support for X.Org Server 1.10
  * Guest Additions: fixed inappropriate Guest Additions update notification when using vendor-specific version suffixes (bug #8844)
- deprecated vbox-gcc46.patch
* Fri May 13 2011 crrodriguez@opensuse.org
- Allow GCC 4.6 to be used
* Tue Apr 26 2011 crrodriguez@opensuse.org
- Remove bundled libraries to ensure they are never used
- USe system boost headers,only needed for xml parser it seems.
* Fri Apr 22 2011 mseben@gmail.com
- updated to Virtualbox 4.0.6 (maintenance release)
  * VMM: fixed incorrect handling of ballooned pages when restoring a VMM from a saved state
  * VMM: don't crash on hosts with more than 64 cores / hyperthreads; implemented support for up to 256 host cores (except Windows hosts; bug #8489)
  * VMM: fixed guru meditation for PAE guests running on hosts without PAE (bug #8006)
  * VMM: fixed slow Linux guests with raw mode and recent guest kernels (bug #8726)
  * GUI: support host key combinations (bug #979)
  * GUI: fixed progress indicator (bug #7814)
  * GUI: show the mouse pointer while the VM is paused if the USB tablet mouse emulation is used (bug #6799)
  * GUI: adapt the snapshot folder as well when renaming a VM (bug #8469)
  * GUI: persistently remember the last folders of the disk/DVD/floppy selectors
  * GUI: never allow to start a VM with USB-2.0 activated if the proper extension pack is missing (bug #8182)
  * GUI: fixed hang/crash when opening a file dialog in an non-existing folder (bug #8673)
  * Snapshots: fixed a bug which could lose entries in the media registry when restoring a snapshot (bug #8363)
  * Snapshots: allow snapshots to be stored in the VM directory
  * 3D support: fixed a crash if a VM was forced to terminate (Windows hosts only; bug #7133)
  * Storage: fixed memory leak (4.0 regression; bug #7966)
  * Storage: fixed access to iSCSI targets over internal network
  * Storage: fixed reading from disks with more than one snapshot for VHD and VMDK images with disabled host cache (bug #8408)
  * Storage: fixed a possible hang during VM suspend after an I/O error occurred
  * Storage: fixed a possible hang during VM suspend / reset (bug #8276, #8294)
  * Storage: automatically create a diff image when attaching a streamOptimized VMDK image to a VM
  * ATA/SATA: fixed automounting of virtual CD/DVD mediums with recent Linux distributions by correctly reporting the current profile as 'none' if no medium is present
  * Buslogic: fixed emulation for certain guests (e.g. jRockit VE)
  * Host-Only Networking: fixed interface creation failure on Windows hosts (4.0.4 regression; bug #8362)
  * Host-Only & Bridged & Internal Networking: fix for processing promiscuous mode requests by VMs, defaulting to switch behaviour
  * Host-Only Networking: fixed connectivity issue after resuming the host from sleep (bug #3625)
  * Bridged Networking: support for interface bonding on Mac OS X hosts (bug #8731)
  * NAT: fixed processing of ARP announcements for guests with static assigned IPs (bug #8609)
  * VRDP: backward compatibility with VRDPAuth external authentication library (bug #8063)
  * Shared Folders: don't fail to start a VM if a path is not absolute, for example when importing an OVF from a different host (bug #7941)
  * Audio: fixed crash under certain conditions (bug #8527)
  * USB: fixed a crash when plugging certain USB devices (bug #8699)
  * HPET: fixed time jumps when reading the counter (bug #8707)
  * OVF/OVA: automatically adjust disk paths if the VM name is changed on import
  * OVF/OVA: fix export to slow medias
  * OVF/OVA: automatically repair inconsistent appliances with multiple disks (bug #8253)
  * rdesktop-vrdp: fixed an assertion triggered under certain conditions (bug #8593)
  * Windows hosts: fixed occasional hangs during VM shutdown because sometimes COM was not properly uninitialized
  * Mac OS X hosts: prevent the mouse from leaving the VM window while captured
  * Mac OS X hosts: keep aspect ratio while resizing in scale mode (shift for old behaviour) (part of bug #7822)
  * X11 hosts: fixed Yen key support (bug #8438)
  * X11 hosts: fixed a regression which caused Host+F1 to pop up help instead of sending Ctrl+Alt+F1
  * Linux hosts / Linux Additions: mangle IPRT symbols to allow installing VirtualBox inside a VM while the Guest Additions are active (bug #5686)
  * Linux hosts / Linux guests: workaround for a bug in GLIBC older than version 1.11 leading to crashes under certain conditions (signed/unsigned problem with memchr on 64-bit machines)
  * Solaris hosts: fixed a deadlock in event semaphores that could lead to unkillable VM processes
  * Windows Additions: fixed Sysprep parameter handling
  * Windows Additions: fixed spontaneous guest reboots under certain circumstances (4.0.2 regression; bugs #8406, #8429)
  * Windows Additions: added auto logon support for locked workstations on legacy Windows versions
  * Windows Additions: fixed driver bugcheck error when handling PnP messages (4.0 regression; bug #8367)
  * Windows Additions: fixed memory leak in VBoxVideo
  * X11 Additions: added support for X.Org Server 1.10 final
  * Linux Additions: Linux kernel 2.6.39-rc1 fixes
  * Linux Additions: improved auto-run support (bug #5509)
  * Linux Additions: fix mouse support on SUSE 11 SP 1 guests (bug #7946)
  * Solaris Additions: added support for X.Org Server 1.9
  * Guest Additions: various bugfixes for guest control execution
  * Webservice: use own log file, with log rotation to limit size
- deprecated vbox-kernel-2.6.39.patch
* Fri Apr 15 2011 crrodriguez@opensuse.org
- remove the remaining build dates in binaries
* Wed Apr 13 2011 crrodriguez@opensuse.org
- Fix build in kernel 2.6.39
* Wed Apr 13 2011 crrodriguez@opensuse.org
- Fix build with as-needed
- DO not use static libstdc
* Mon Apr 11 2011 crrodriguez@opensuse.org
- Remove more build dates in binaries
- VirtualBox no longer requires GCC 4.3
* Fri Mar 25 2011 mseben@gmail.com
- added Conflicts: virtualbox-ose-*-kmp for kmp packages, because
  host (vboxdrv) and  guest (vboxguest) kmp exports the same
  symbol (RTMemFreeEx) which breaks loading modules using
  modprobe (bnc#661740)
* Thu Mar 17 2011 mseben@gmail.com
- fix missing permissions handling of VBoxNetDHCP (bnc#679785)
- fix permissions handling for virtualbox-qt subpackage
* Wed Mar  9 2011 crrodriguez@opensuse.org
- fix requires sysvinit(syslog)
* Fri Feb 18 2011 mseben@gmail.com
- update to VirtualBox 4.0.4 (maintenance release)
  * VMM: fixed recompiler crashes under certain conditions (bugs #8255, #8319 and further)
  * VMM: fixed running 64-bit guests on 32-bit host with nested paging enabled on AMD CPUs (4.0 regression; bug #7938)
  * VMM: fixed timing issues / hangs for certain guests using the programmable interval timer (bugs #8033 and #8062)
  * VMM: large page and monitoring fixes for live snapshots (bugs #7910, #8059, #8125)
  * GUI: fixed error message when trying to exceed the maximum number of host network interfaces
  * GUI: fixed saving of changes to the metadata of an existing snapshot (bug #8145)
  * GUI: fixed rare crash on X11 hosts (bug #8131)
  * GUI: when selecting a shared folder, start the file dialog in the users home directory (bug #8017)
  * ExtPack: enforce the correct permissions which might be restricted by umask when creating directories (non-Windows hosts only; bug #7878)
  * VBoxSDL: fixed crash when starting by specifying the VM UUID (4.0 regression; bug #8342)
  * VBoxManage: allow savestate even if the VM is already paused
  * VBoxManage: fixed modifyvm --synthcpu (bug #6577)
  * VBoxManage: fixed hang when doing guestcontrol execute –wait-for exit and displaying process status on exit (bug #8235)
  * VBoxManage: decreased CPU load during guestcontrol execute –wait-for exit/stdout while waiting for the guest process to terminate (bug #7872)
  * VBoxManage: fixed list hostdvds/hostﬂoppies
  * VBoxManage: fixed storageattach for host DVD drives and host ﬂoppy drives
  * Metrics: introduced RAM/VMM base metric.
  * Main: improved sanity check when taking a VM screen shot (bug #7966)
  * Main: fixed a crash under rare circumstances if a VM failed to start
  * Main: fixed attaching of immutable disk images (bug #8105)
  * Main: fixed a crash at VM shutdown (bug #6443)
  * Main: fixed incorrect handling of cross-referenced medium attachments (bug #8129)
  * Settings: fixed truncating of big integer values (4.0 regression)
  * Settings: properly store the ICH9 chipset type (bug #8123)
  * Host-Only & Bridged Networking: fixed VBox DHCP server startup issue for Windows hosts (4.0 regression; bug #7905)
  * Host-Only Networking: re-create vboxnetX interfaces after vboxnetadp.ko module reload on Linux and Darwin (bugs #5934, #6341)
  * NAT: fixed an mbuf leak under rare circumstances (bug #7459)
  * ACPI: don’t allow the guest to enter S4 by default and don’t announce S1 and S4 in the ACPI tables if disabled (bug #8008)
  * Graphics card: made re-enabling disabled screens work correctly to prevent problems when X11 guests enter screen saving mode (bug #8122)
  * Storage: fixed write errors with snapshots if the host cache is disabled (4.0 regression; bug #8221)
  * ATA/SATA: fixed reset handling after ACPI suspend/resume
  * BusLogic: fixed hang with SMP VMs
  * Serial: another attempt to prevent lost characters during transmission (bug #1548)
  * Linux hosts/guests: Linux 2.6.38-rc1 compile fixes
  * Mac OS X hosts: fixed VBoxSVC crash when listing host interfaces without default gateway (64-bit hosts only; bug #7955)
  * Solaris/Darwin hosts: fixed VM CPU execution cap
  * X.Org guests: fixed a crash on X server restart (bug #8231)
  * X.Org guests: support X.Org Server 1.10 pre-release and Ubuntu 11.04 Alpha.
  * X.Org guests: Add EDID emulation in the graphics driver to prevent GNOME settings daemon changing the mode on login.
  * X.Org guests: never send graphics modes to the host that older VirtualBox versions can’t handle.
  * Linux Additions: fixed a memory leak in the shared folders code if a host link is not readable (bug #8185)
  * Windows Additions: fixed handling of Security Attention Sequence (SAS) with VBoxGINA
- droppped deprecated vbox-2.6.38.patch
* Tue Feb  8 2011 cshorler@googlemail.com
- The python package isn't installed correctly, and contains an
  unnecessary shared library due to a build / config bug. It is
  also missing pre-compiled python (pyc).
- added vbox-python-detection.diff and vbox-xpcom-kmk.diff
* Mon Jan 31 2011 cshorler@googlemail.com
- Minor packaging fixes
  * ExtPack: add missing host helper util (VBoxExtPackHelper)
  * Config.kmk: patch for VNC (removed from spec), documentation path (fixes GUI), combine with existing rpath diff
  * spec: migrate VNC echo to patch, fix desktop file overwrite issue / bug
* Thu Jan 27 2011 cristian.rodriguez@opensuse.org
- Fix build in 2.6.38 kernels.
* Wed Jan 26 2011 cristian.rodriguez@opensuse.org
- Fix one more build date in binaries that causes unneeded
  republish of binaries.
* Wed Jan 19 2011 mseben@gmail.com
- disable setup parameter for init scripts
* Wed Jan 19 2011 mseben@gmail.com
- updated to VirtualBox 4.0.2
  * GUI: don't crash if a removable host drive referenced from the VM settings vanished
  * GUI: fixed a crash when using the KDE4 Oxygen theme and clicked on the settings button (4.0 regression; bug #7875)
  * GUI: properly warn if the machine folder cannot be created (bug #8031)
  * GUI: several fixes for multimonitor X11 guests
  * ExtPack: don’t make the installer helper application suid root (Linux .deb/.rpm packages only)
  * ExtPack: improved user experience on Vista / Windows 7 when installing an extension pack
  * ExtPack: fixed issue with non-ascii characters in the path name during installing an extension pack (bug #7917)
  * ExtPack: fixed SELinux issues on 32-bit Linux hosts
  * VBoxManage: Host-only interface creation and removal is now supported for all platforms except Solaris (bug #7741)
  * VBoxManage: fixed segmentation fault when removing non-existent host-only interface
  * Storage: fixed possible crashes with VMDK/VHD images with snapshots and async I/O (4.0 regression)
  * Storage: don’t eject the physical medium if a DVD/CDROM/ﬂoppy drive is detached from a VM (bug #5825)
  * Storage: be more robust when a faulty guest sends ATA commands to an ATAPI device (bug #6597)
  * Parallels: fixed deletion of the image during suspend, pause or power off (4.0 regression)
  * Bridged networking: fixed host kernel panic when bridging to devices with no TX queue
  * NAT: port-forwarding rule registration respects protocol parameter (bug #8094)
  * E1000: fixed PXE boot issues with WDS (bug #6330)
  * Virtio-net: fixed the issue with TX performance in some Linux guests
  * ICH9: fixed VM crash (software virtualization only; bug #7885)
  * VGA: fixed VESA screen issue (4.0 regression; bug #7986)
  * Shared Folders: fixed parameter parsing when creating symbolic links, fixes 32-bit/64-bit bitness issue (bug #818)
  * Main: fixed crash under rare circumstances due to an invalid logging string (4.0 regression)
  * Main: improve error information propagation for errors preventing a VM start
  * Main: fixed problems with snapshots and non-ASCII characters in machine paths (bug #8024)
  * Webservice: now listens to localhost by default as documented (bug #6067)
  * Settings: do not fail loading machine settings if removeable drive attachment
  * Settings: fixed issue that changing a snapshot name or description was not saved to machine XML
  * OVF/OVA: fixed import of files created by other OVF tools (bug #7983)
  * rdesktop-vrdp: fix a crash during USB device enumeration (bug #7981)
  * Linux hosts: fixed a crash during USB device enumeration.
  * Linux hosts: try a bit harder to allocate memory (bug #8035; 4.0 regression)
  * Guest Additions: fixed parsing of parameters for guest control in VBoxService (4.0 regression; bug #8010)
  * Windows Guest Additions: automatic logon on Windows Vista/Windows 7 now supports unlocking previously locked workstations
* Fri Jan 14 2011 mseben@gmail.com
- reworked vbox-disable-updates.diff for virtualbox 4.0.0
- modified virtualbox-60-vboxdrv.rules : added comment with udev
  rules inside for assign full usb access to vboxusers - don't
  uncomment these lines if you don't understand possible security
  risk (bnc#664520)
* Wed Jan 12 2011 mseben@gmail.com
- fix typo in spec file, which breaks loading of vboxsf kernel
  module on guest
* Wed Jan  5 2011 mseben@gmail.com
- fix rcvboxdrv setup - we disallow building of kernel modules from sources
- added rcvboxdrv, rcvboxadd files
- fix build fail: "Out of memory: Kill process" : use "-j1" for kmk to disable parallel build
- fix build for older distros
* Fri Dec 31 2010 mseben@gmail.com
- added vbox-smc-napa.diff to fix build
* Thu Dec 30 2010 tejas.guruswamy@opensuse.org
- Use xserver 1.9 additions on Factory
* Thu Dec 23 2010 mseben@gmail.com
- update to VirtualBox 4.0.0
  New Features:
  * Reorganization of VirtualBox into a base package and Extension Packs
  * New settings/disk file layout for VM portability; see chapter 10.1, Where VirtualBox stores its files
  * Major rework of the GUI (now called “VirtualBox Manager”):
  - Redesigned user interface with guest window preview (also for screenshots)
  - New “scale” display mode with scaled guest display
  - Support for creating and starting .vbox desktop shortcuts (bug #1889)
  - The VM list is now sortable
  - Machines can now be deleted easily without a trace including snapshots and saved states,
    and optionally including attached disk images (bug #5511; also, VBoxManage unregistervm --delete can do the same now)
  * Built-in creation of desktop file shortcuts to start VMs on double click (bug #2322)
  * VMM: support more than 1.5/2 GB guest RAM on 32-bit hosts
  * New virtual hardware:
  - Intel ICH9 chipset with three PCI buses, PCI Express and Message Signaled Interrupts (MSI)
  - Intel HD Audio, for better support of modern guest operating systems (e.g. 64-bit Windows; bug #2785)
  * Improvements to OVF support :
  - Open Virtualization Format Archive (OVA) support
  - Significant performance improvements during export and import
  - Creation of the manifest file on export is optional now
  - Imported disks can have formats other than VMDK
  * Resource control: added support for limiting a VM’s CPU time and IO bandwidth
  * Storage: support asynchronous I/O for iSCSI, VMDK, VHD and Parallels images
  * Storage: support for resizing VDI and VHD images.
  * Guest Additions: support for multiple virtual screens in Linux and Solaris guests using X.Org server 1.3 and later
  * Language bindings: uniform Java bindings for both local (COM/XPCOM) and remote (SOAP) invocation APIs
  * In addition, the following items were fixed and/or added:
  Bug Fixes:
  * VMM: Enable large page support by default on 64-bit hosts (applies to nested paging only)
  * VMM: fixed guru meditation when running Minix (VT-x only; bug #6557)
  * VMM: fixed crash under certain circumstances (Linux hosts only, non VT-x/AMD-V mode only; bugs #4529 and #7819)
  * GUI: add configuration dialog for port forwarding in NAT mode (bug #1657)
  * GUI: show the guest window content on save and restore
  * GUI: certain GUI warnings don’t stop the VM output anymore
  * GUI: fixed black fullscreen minitoolbar on KDE4 hosts (Linux hosts only; bug #5449)
  * BIOS: implemented multi-sector reading to speed up booting of certain guests (e.g. Solaris)
  * Bridged networking: improved throughput by filtering out outgoing packets intended for the host before they reach the physical network (Linux hosts only; bug #7792)
  * 3D support: allow use of CR_SYSTEM_GL_PATH again (bug #6864)
  * 3D support: fixed various clipping/visibility issues (bugs #5659, #5794, #5848, #6018, #6187, #6570)
  * 3D support: guest application stack corruption when using glGetVertexAttrib[ifd]v (bug #7395)
  * 3D support: fixed OpenGL support for libMesa 7.9
  * 3D support: fixed Unity/Compiz crashes on natty
  * 2D Video acceleration: multimonitor support
  * VRDP: fixed rare crash in multimonitor configuration
  * VRDP: support for upstream audio
  * Display: fixed occasional guest resize crash
  * NAT: port forwarding rules can be applied at runtime
  * SATA: allow to attach CD/DVD-ROM drives including passthrough (bug #7058)
  * Floppy: support readonly image files, taking this as the criteria for making the medium readonly (bug #5651)
  * Audio: fixed memory corruption during playback under rare circumstances
  * Audio: the DirectSound backend now allows VMs to be audible when another DirectSound application is active, including another VM (bug #5578)
  * EFI: support for SATA disks and CDROMs
  * BIOS: reduce the stack usage of the VESA BIOS function #4F01 (Quake fix)
  * OVF/OVA: fixed export of VMs with iSCSI disks
  * Storage: Apple DMG image support for the virtual CD/DVD (bug #6760)
  * Linux host USB support: introduced a less invasive way of accessing raw USB devices (bugs #1093, #5345, #7759)
  * Linux hosts: support recent Linux kernels with CONFIG_DEBUG_SET_MODULE_RONX set
  * Guest Additions: Shared Folders now can be marked as being auto-mounted on Windows, Linux and Solaris guests
  * Linux Additions: Shared Folders now support symbolic links (bug #818)
  * Linux Additions: combined 32-bit and 64-bit additions into one file
  * Windows Additions: automatic logon on Windows Vista/Windows 7 is now able to handle renamed user accounts; added various bugfixes
* Mon Dec 20 2010 mseben@gmail.com
- rename to virtualbox - drop ose postfix, Oracle team dosn't build
  puel version - we have now extension packs
- rename xorg-x11-driver-virtualbox-ose subpackage to virtualbox-guest-x11
- use Provides: virtualbox-gui for virtualbox-qt subpackage and
  Recommends: virtualbox-gui for virtualbox package, so user could
  install another type of gui easily
* Fri Dec 17 2010 mseben@gmail.com
- update to VirtualBox 4.0.0 BETA4
  * see announcement with changelog http://forums.virtualbox.org/viewtopic.php?f=15&t=37177
- set propper path for link to pdf in .desktop file
* Tue Dec 14 2010 mseben@gmail.com
- update to VirtualBox 4.0.0 BETA2
  * see announcement with changelog http://forums.virtualbox.org/viewtopic.php?f=15&t=36893
* Sat Dec 11 2010 coolo@novell.com
- cleanup 32bit buildrequires
* Tue Dec  7 2010 mseben@gmail.com
- update to VirtualBox 4.0.0 BETA1
  * see announcement with changelog http://forums.virtualbox.org/viewtopic.php?f=15&t=36748
* Thu Dec  2 2010 mseben@gmail.com
- updated to VirtualBox-ose 3.2.12
  * VMM: fixed rare host crash when running 64-bit guests on 32-bit hosts (bug #7577)
  * VMM: fixed host reboots under rare circumstances due to NMIs triggered by active performance counters
  * VMM: fixed out of memory guru meditation for large memory guests (bug #7586)
  * VMM: fixed a guru meditation related to large pages
  * VMM: use new VT-x feature to keep the guest from hogging the CPU
  * Snapshots: implemented deleting the last remaining snapshot while the VM is running
  * GUI: perform the checks for exceeding the size limit of the host file system and for broken asynchronous I/O
  * NAT: fixed memory leak (3.2.0 regression; bugs #6918, #7353)
  * Networking: fixed VM reset handling in e1000
  * VRDP: fixed rare crash in multimonitor configuration
  * Display: fixed occasional guest resize crash
  * Mouse: don't send relative mouse events together with absolute mouse events (3.2.10 regression; bug #7571)
  * Keyboard: fixes for the USB keyboard emulation; fixes for Koran keyboards
  * Serial: don't hang if the host device would block during open (bugs #5756, #5380)
  * Serial: fixed modem status lines (Linux hosts only; bug #812)
  * Graphics: Horizontal resolutions are no longer restricted to a multiple of 8 pixels
  * USB: fixed a crash with older Linux kernels and non-ASCII characters in device strings
  * USB: fixed a crash under rare circumstances (bug #7409; Windows hosts only)
  * iSCSI: respond to NOP-In requests from the target immediately to avoid being disconnected if the guest is idle
  * 3D support: fixed a crash under certain circumstances (bug #7659)
  * 3D support: fixed crashes for GLUT based apps (bug #6848)
  * 3D support: added missing GLX 1.3 functionality (bugs #7652, #7195)
  * 2D Video acceleration: fixed potential deadlock when saving the VM state (bug #4124)
  * Windows hosts: another fix for BSODs under certain circumstances in VBoxNetFlt.sys (bug #7601)
  * Solaris hosts: fixed host USB DVD drive detection
  * Mac OS X hosts: fixed swapped keys for certain ISO keyboard types (bug #2996)
  * Linux hosts: added link state handling for TAP devices needed for proper operation with bridged networking
  * Linux hosts/guests: Linux 2.6.37 fixes
  * Linux Additions: properly compile the vboxvideo module if DKMS is not installed (bug #7572)
  * Linux Additions: fixed a memory leak when accessing non-existing files on a Shared Folders (bug #7705)
  * Windows Additions: skip none-mapped user accounts when enumerating user accounts for VM information
- deprecated vbox-kernel-2637.diff
- added rpath.diff to fix build
- modify vboxdrv init script with proper macros in install section
* Thu Dec  2 2010 dmueller@suse.de
- remove runlevel 4 from start scripts
* Fri Nov 19 2010 coolo@novell.com
- take patch from upstream to fix build with 2.6.37
* Wed Nov 10 2010 javier@opensuse.org
- Added vbox-default-os-type.diff
  * Changes the default Linux guest OS to openSUSE
* Wed Oct 13 2010 crrodriguez@novell.com
- Update to VirtualBox 3.2.10
  * Fix build with newer kernels
  * support X.Org Server 1.9
  * don't crash VBoxClient during reboot
  * Bridged networking: fixed occasional host freeze during VM shutdown
  * fixed memory leak under certain circumstances
  * under rare conditions the NAT engine consumed 100%% CPU load
* Tue Sep 21 2010 puzel@novell.com
- install mount.vboxsf into /sbin, not /usr/sbin (bnc#636347)
* Wed Sep 15 2010 jeffm@novell.com
- added a patch that converts vbox shared folders to use 2.6-style
  embedded inodes but i haven't tested it. I don't use virtualbox and don't
  intend to start.
* Tue Sep 14 2010 coolo@novell.com
- add vbox-kernel-2.6.36.diff to support kernel > 2.6.35
* Tue Sep  7 2010 mseben@gmail.com
- created qt subpackage with qt dependency
* Mon Sep  6 2010 masterpatricko@gmail.com
- Add vbox-python-2.7-configure to build against Python 2.7
* Sun Sep  5 2010 mseben@gmail.com
- added devel subpackage
* Sat Sep  4 2010 mseben@gmail.com
- added subpackage with python bindings
* Sat Aug 28 2010 cristian.rodriguez@opensuse.org
- Do not include build dates in binaries, make build-compare
  happier
* Thu Aug 26 2010 gber@opensuse.org
- made the vboxadd init script depend on $remote_fs since it
  requires /usr to be mounted
* Sun Aug 15 2010 mseben@gmail.com
- update to 3.2.8
  * VMM: properly terminate the VM with an error if the guest is trying to switch to the PAE mode but PAE is disabled in the VM settings
  * GUI: switch to native file dialogs (Windows hosts only; bug #5459)
  * GUI: don't use native file dialogs on KDE hosts (Linux hosts only; bug #6809)
  * 3D support: fixed GL_EXT_texture_sRGB support
  * PXE: fixed ZENworks PXE boot regression
  * OVF: fixed slower export and larger images under certain circumstances (3.2.6 regression; bug #7073)
  * USB: properly signal an interrupt if the port suspend status changes
  * USB: respect the remote-only filter
  * USB: avoid VM hang when changing the configuration of certain devices (Windows hosts only)
  * USB: fix a crash with older Linux kernels and non-ASCII characters in device strings (Linux hosts only; bug #6983)
  * PageFusion: fixed conflict with the guest execution feature
  * PageFusion: fixed stability issues with a large number of VMs
  * PageFusion: fixed host crashes with guest SMP and Win64 guests
  * Memory ballooning: fixed problems restoring VMs with pre-allocation enabled
  * Bridged networking: fixed performance issue with GRO enabled on bridged device (bug #7059)
  * Hostonly networking: fixed performance issue (3.2.6 regression; bug #7081)
  * Hard disks: fix auto-reset of immutable disk at VM startup (bug #6832)
  * BusLogic: several fixes for Windows NT/2000 and SCO OpenServer guests
  * LsiLogic: fixed I/O errors under rare circumstances
  * Sharing disks: support for attaching one disk to several VMs without external tools and tricks (see here for a short explanation)
  * Shared folders: several fixes and performance enhancements for Solaris guests (bugs #4154 and #6512)
  * Solaris Installer: added support for remote installations
  * Guest Properties API: correctly support enumerating the properties of a running VM with an empty "patterns" field (bug #7171)
  * Guest properties: properly delete transient properties on shutdown
  * RDP video redirection performance improvements and stability fixes
  * Settings: silently fix host audio driver when reading machine XML settings files or OVF written by VirtualBox on a different host OS, for example convert DirectSound to PulseAudio (bug #7209)
  * Settings: properly store the NAT network setting in XML settings file version 1.10 and later (bug #6176)
  * VBoxManage: handle differencing images with parent UUID correctly in subcommand openmedium disk (bug #6751)
  * Web service: enabled HTTP keepalive for much better performance
  * Web service: added timestamps to logging output
  * Web service: treat 8-bit strings as UTF-8 not ASCII
  * X11 Additions: fix for Xorg 6.8 guests (e.g. RHEL4)
* Mon Jun 28 2010 mseben@novell.com
- update to 3.2.6:
  * VMM: fixed host crash when running 64-bit guests on 32-bit hosts with certain Intel CPUs (VT-x only; bug #6166)
  * VMM: allow 64-bit SMP guests on 32-bit hosts (VT-x and AMD-V only; does not apply to Mac OS X, which already supports it)
  * VMM: fixed Guru mediation if guests with more than 2GB are booted with VT-x/AMD-V disabled (bug #5740)
  * VMM: fixed TR limit trashing (VT-x and 64-bit host only; bug #7052)
  * Page Fusion: several bug fixes for SMP guests (including bug #6964)
  * Teleportation: several fixes and improvements
  * Mac OS X server guests: compatibility fix
  * EFI: fixed memory detection for guests with 2GB or more RAM assigned
  * GUI: added a workaround for a Linux kernel bug which affecting asynchronous I/O on ext4 / xfs file systems (Linux hosts only)
  * GUI: added setting for multiple VRDP connections; useful if multiple screens are enabled
  * GUI: another fix for the keyboard capturing bug under metacity (bug #6727)
  * GUI: fixed quit dialog when used in seamless or fullscreen mode (Mac OS X hosts only; bug #6938)
  * GUI: handle the extra key on the Brazilian keyboard on X11 hosts again (bug #7022).
  * 2D Video acceleration: fixed crashes when leaving the fullscreen mode (bug #6768)
  * VBoxManage: fixed storageattach error handling (bug #6927)
  * VBoxManage: fixed dhcpserver add (3.2.0 regression; bug #7031)
  * Storage: fixed hang with images located on filesystems which don't support async I/O (bug #6905)
  * Storage: fixed raw disks on Windows hosts (3.2.0 regression; bug #6987)
  * LsiLogic: fixed hang with older Linux guests
  * BusLogic: fixed hang during I/O
  * SATA: set initial number of ports to 1 as some guests can't handle 30 ports (e.g. CentOS 4 and FreeBSD; bug #6984)
  * SATA: performance improvement
  * SCSI: fixed error when using the full format option during Windows installation (bug #5101)
  * iSCSI: fixed authentication (bug #4031)
  * Host-only/bridged networking: fixed excessive host kernel warnings under certain circumstances (Linux hosts only; 3.2.0 regression; bug #6872)
  * NAT: fixed potential memory leaks
  * NAT: increased the size of the memory pool for 16K Jumbo frames (performance tweak)
  * NAT: allow to link/unlink the network cable even if the VM is currently paused
  * E1000: disconnect cable was not properly handled if the NIC was not yet initialized by the guest
  * OVF: export performance optimization
  * OVF: upgraded OS type definitions to CIM 2.25.0 so that Windows 7 and other OSes are now tagged correctly on export
  * Settings: the setting for disabling the host I/O cache was sometimes not properly saved
  * Settings: save machine state into XML correctly even when snapshot folder has been changed to a non-default location (bug #5656)
  * USB: allow the guest to disable an EHCI port
  * USB: find a valid language ID before querying strings (bug #7034)
  * POSIX hosts: fixed several memory leaks (3.2.0 regression)
  * Solaris hosts: fixed VDI access problem under certain circumstances (IDE/SATA; 3.2.0 regression)
  * Solaris hosts: fixed VM fails to start on 32-bit hosts (3.2.0 regression; bug #6899)
  * Windows hosts (32-bit): increase guest RAM limit if the host kernel allows for more virtual address space
  * Linux Additions: re-read a directory after a file was removed (bug #5251)
  * Linux Additions: install the DRI driver in the right location on ArchLinux guests (bug #6937)
  * X11 Additions: fixed spurious mouse movement events (bug #4260)
  * Solaris Additions: fixed guest control execution
* Tue Jun 15 2010 dmueller@suse.de
- update to 3.2.4:
  * GUI: fixed a superfluous resize-event on powering-on VM for X11 (improvement for the 3.2.2 fix)
  * Host-only/bridged networking: fixed guest-to-guest communication over wireless (3.2.0 regression; bug #6855)
  * Storage: fixed a potential guest disk corruption with growing images (3.2.0 regression)
  * Page Fusion: fixed shared module detection for Win64 guests
  * 3D support: allow use of CR_SYSTEM_GL_PATH again (bug #6864)
  * 3D support: fixed a host assertion for some multi-threaded guest applications (bug #5236)
  * 3D support: fixed host crashes with nVIDIA drivers on WDDM startup
  * OVF: fixed import of OVFs with a VM description (annotation) (3.2.2 regression; bug #6914)
  * VRDP: fixed issues with secondary monitors (bug #6759)
* Thu Jun  3 2010 mseben@novell.com
- updated to 3.2.2
  * VMM: fixed rare invalid guest state guru meditation (VT-x only)
  * VMM: fixed poor performance with nested paging and unrestricted guest execution (VT-x only; bug #6716)
  * VMM: fixed occasional guru meditation during Windows 7 bootup (bug #6728)
  * GUI: keep the status for remote control in sync with the actual state
  * GUI: don't exit after a successful refresh of an invalid VM configuration
  * GUI: fixed keyboard capturing bug under metacity (bug #6727)
  * GUI: fixed crash during VM termination if a modal dialog is open
  * GUI: default controllers names of New VM Wizard are synchronized with VM settings
  * GUI: fixed superfluous resize-event on powering-on VM for X11
  * GUI: fixed regression - missed USB item's tool-tip of USB devices menu
  * GUI: Activate VM window on mouse-hovering for multi-monitor VMs
  * VBoxSDL/Linux hosts: automated keyboard type detection (bug #5764)
  * SATA: fixed crash during VM suspend under rare circumstances
  * SATA: fixed crash during VM reset after a snapshot was taken
  * Storage: fixed sporadic hang of SMP guests using SATA or LSI Logic SCSI and asynchronous I/O
  * Virtio-net: fix for guests with more than about 4GB RAM (bug #6784)
  * Page Fusion: fixed VBoxService crash with enabled Page Fusion on Win64 guests
  * Page Fusion: added kernel module sharing
  * HGCM: fixed memory leak which showed up if the Guest Additions were accessing a non-existing HGCM service
  * Teleportation: several fixes
  * Floppy: don't disable the host I/O cache by default
  * USB: fixed 3.1 regression with certain devices (e.g. iPhone); Windows host only
  * Serial: updated the guest device emulation to 16550A and reduced the probability for loosing bytes during transmission (bug #1548)
  * NAT: re-fetch the name server parameters from the host on guest DHCP requests to handle host network switches more gracefully (bug #3847)
  * NAT: fixed parsing of IPv4 addresses in CIDR notation (bug #6797)
  * NAT: limit the number of name servers passed to the guest to four (non-Windows hosts only; bug #4098)
  * NAT: fixed DNS transaction id mismatch (bug #6833)
  * VDE: fixed changing the attachment during runtime
  * Bridged Networking: fixed memory leak in the Bridged Networking driver for Windows hosts (bug #6824)
  * Windows Additions: fix for NT4 guests (bug #6748)
  * Windows Additions: re-introduced system preparation feature
  * Linux guests: enable PAE for RedHat guests by default
  * Linux guests: fix support for disabling mouse integration (bug #6714)
  * Webservice: fixed a rare crash when calling IGuest methods from the webservice.
  * OVF: fixed wrong hard disk UUIDs on export (bug #6802)
  * OVF: fixed 3.2.0 regression importing legacy OVF 0.9 files
  * 3D support: fixed OpenGL support for 64bit apps on windows guests
  * 3D support: fixed various host crashes (#2954, #5713, #6443)
* Thu Jun  3 2010 mseben@novell.com
- updated to 3.2.0
  * Following the acquisition of Sun Microsystems by Oracle Corporation, the product is now called Oracle VM VirtualBox
  * Experimental support for Mac OS X guests (see the manual for more information)
  * Memory ballooning to dynamically in- or decrease the amount of RAM used by a VM (64-bit hosts only)
  * Page Fusion automatically de-duplicates RAM when running similar VMs thereby increasing capacity
  * CPU hot-plugging for Linux (hot-add and hot-remove) and certain Windows guests (hot-add only)
  * New Hypervisor features: with both VT-x/AMD-V on 64-bit hosts, using large pages can improve performance; also,
    on VT-x, unrestricted guest execution is now supported (if nested paging is enabled with VT-x, real mode and
    protected mode without paging code runs faster, which mainly speeds up guest OS booting)
  * Support for deleting snapshots while the VM is running
  * Support for multi-monitor guest setups in the GUI for Windows guests
  * USB tablet/keyboard emulation for improved user experience if no Guest Additions are available
  * LsiLogic SAS controller emulation
  * RDP video acceleration
  * NAT engine configuration via API and VBoxManage
  * Use of host I/O cache is now configurable
  * Guest Additions: added support for executing guest applications from the host system
  * OVF: enhanced OVF support with custom namespace to preserve settings that are not part of the base OVF standard
  * VMM: fixed Windows 2000 guest crash when configured with a large amount of RAM (bug #5800)
  * Linux/Solaris guests: PAM module for automatic logons added
  * GUI: guess the OS type from the OS name when creating a new VM
  * GUI: added VM setting for passing the time in UTC instead of passing the local host time to the guest (bug #1310)
  * GUI: fixed seamless mode on secondary monitors (bugs #1322 and #1669)
  * GUI: offer to download the user manual in the OSE version (bug #6442)
  * Main: allow to start a VM even if a virtual DVD or floppy medium is not accessible
  * Settings: be more robust when saving the XML settings files
  * Mac OS X: rewrite of the CoreAudio driver and added support for audio input (bug #5869)
  * Mac OS X: external VRDP authentication module support (bug #3106)
  * Mac OS X: Moved the realtime dock preview settings to the VM settings (no global option anymore). Use the dock menu to configure it.
  * Mac OS X: added the VM menu to the dock menu
  * 3D support: fixed corrupted surface rendering (bug #5695)
  * 3D support: fixed VM crashes when using ARB_IMAGING (bug #6014)
  * 3D support: fixed assertion when guest applications uses several windows with single OpenGL context (bug #4598)
  * 3D support: added GL_ARB_pixel_buffer_object support
  * 3D support: added OpenGL 2.1 support
  * 3D support: fixed Final frame of Compiz animation not updated to the screen (Mac OS X only) (bug #4653)
  * 3D support: fixed blank screen after loading snapshot of VM with enabled Compiz
  * Added support for virtual high precision event timer (HPET)
  * OVF: fixed mapping between two IDE channels in OVF and the one IDE controller in VirtualBox
  * OVF: fix VMDK format string identifiers and sort XML elements from rasd: namespace alphabetically as prescribed by standard
  * VBoxShell: interactive Python shell extended to be fully functional TUI for VirtualBox
  * Linux Additions: support Fedora 13 (bug #6370)
  * VBoxManage: fixed overly strict checks when creating a raw partition VMDK (bugs #688, #4438)
- dropped vbox-system-xorg.patch and vbox-drm-includepath.diff we
  use now xorg includes and libs from tarball
- turn on VNC server feature, which allows users to connect
  to a virtual machine remotely using any VNC client.
* Mon May 31 2010 mseben@novell.com
- create links to vbox tools in %%_bindir - they could be usefull
  for controlling vbox from command line
* Mon May 24 2010 mseben@novell.com
- fix vboxguest.rules udev rule for guest : use TAG+="udev-acl"
  to grant permissions
* Mon May 10 2010 mseben@novell.com
- updated to 3.1.8
  * VMM: fixed crash with the OpenSUSE 11.3 milestone kernel during early boot (software virtualization only; bug #5457)
  * VMM: fixed invalid state during teleportation
  * VMM: fixed OS/2 guest crash with nested paging enabled
  * VMM: fixed massive display performance loss (AMD-V with nested paging only)
  * GUI: fixed off-by-one bug when passing absolute mouse coordinates to the guest (3.1.6 regression)
  * GUI: show the real version of the Guest Additions, not the interface version
  * GUI: when adding a DVD or floppy slot in the VM mass storage settings dialog, don't attach a random medium but just leave the slot empty
  * GUI: added --seamless and --fullscreen command line switches (bug #4220)
  * GUI: fixed a SEGFAULT under rare circumstances
  * 2D Video acceleration: fixed display issues when working with non 32-bit modes (bugs 6094 & #6208)
  * LsiLogic: Fixed detection of hard disks attached to port 0 when using the drivers from LSI
  * ATA: Fixed sporadic crash with Linux guests when having a hard disk and DVD drive on the same channel (bug 6079)
  * Network: allow to start a VM even if not all network adapters are attached
  * Network: promiscuous mode support for e1000 and simparavirtualized adapters (bug 6519)
  * NAT: fixed ICMP latency (non-Windows hosts only; bug 6427)
  * SCSI: fixed guest crashes under certain circumstances when booting from SCSI devices
  * VBoxManage: fixed modifyvm --natnet default
  * Solaris Hosts: fixed a kernel panic when bridged networking might fail to initialize
  * Solaris Hosts: fixed priority tagged VLAN packets in bridged networking
  * Shared folders: fixed issue with copying read-only files (Linux guests only; bug 4890)
  * Shared folders: renamed the guest kernel module from vboxvfs to vboxsf to make it load on demand by the Linux kernel. Fixes mounting from /etc/fstab in Ubuntu 10.04
  * Shared folders: fixed setuid file permissions (Solaris guests only).
  * Shared folders: fixed deleting directories recursively (Solaris guests only; bug 6513)
  * Guest Additions: support seamless and dynamic resizing on certain older X11 guests (bug 5840)
  * Solaris Additions: fixed OpenGL library dependencies (bug 6435)
  * Keyboard/Mouse emulation: fixed handling of simultaneous mouse/keyboard events under certain circumstances (bug 5375)
  * Mouse emulation: never switch straight back from Explorer to IntelliMouse mode as it confuses the FreeBSD mouse driver (bug 6488)
  * SDK: fixed memory leak in IDisplay::takeScreenShotSlow() (bug 6549)
  * 3D support: fixed Final frame of Compiz animation not updated to the screen (Mac OS X only) (bug 4653)
  * VRDP: allow to bind to localhost only on Mac OS X (bug 5227)
  * Linux hosts: add host USB support for Ubuntu 10.04 and other hosts without the hal daemon or usbfs (bug 6343)
  * webservice: more structs and array fixes in PHP bindings (bug 5657)
  * Windows hosts: make the bridged networking driver notify dll be correctly unregistred on uninstall (bug 5780)
- dropped VBoxRandR.sh (from xorg-x11-driver-virtualbox-ose) by
  upstream : VBoxClient now handles dynamic resizing using library
  calls, not a shell script see  http://www.virtualbox.org/changeset/27601
- deprecated vbox-fix_PF_storm.diff
- use older version of disable-updates patch
- fix typo in %%verify_permissions in spec file
- virtualbox-ose-vboxes init script changes from rbos@opensuse.org
* Sun Apr 18 2010 ro@suse.de
- buildfix with changed include location for recent libdrm
  keep old path as well as to not break when building against older distros
  (vbox-drm-includepath.diff)
- fix KMP subpackage naming in specfile
* Sun Apr 18 2010 ro@suse.de
- add -I/usr/include/libdrm to compiler flags
* Wed Apr 14 2010 mseben@novell.com
- added vbox-system-xorg.patch to build the X.Org server
  additions against our system
* Fri Apr  9 2010 mseben@novell.com
- added fix_PF_storm.diff to fix crashing during liveCD boot at early
  "Loading basic drivers" state  (bnc#576681)
* Mon Apr  5 2010 rbos@opensuse.org
- add script to start virtual boxes during boot, to be configured
  via /etc/sysconfig/vbox
* Mon Apr  5 2010 mseben@novell.com
- fix build : install also dir /etc/X11/xorg.conf.d/ for
  60-vboxmouse.conf config
* Fri Apr  2 2010 mseben@novell.com
- modified 60-vboxguest.rules and added 60-vboxmouse.conf to fix
  lost mouse integration, caused by xorg-server which no longer
  use HAL (bnc#592642)
* Wed Mar 31 2010 mseben@novell.com
- added Obsoletes: virtualbox-ose-kmp to splitted kmp host and
  guest packages
* Fri Mar 26 2010 mseben@novell.com
- updated to 3.1.6
  * Linux hosts: fixed timing issue on hosts with Linux kernels 2.6.31 or later with certain CPUs (asynchronous timer mode; bug #6250)
  * Linux hosts: properly handle host suspend/resume events on Linux kernels 2.6.30 or later (bug #5562)
  * Mac OS X hosts: fixed VBoxSVC crash while enumerating the host network interfaces under certain circumstances
  * Snapshots: fixed image corruption after snapshot merge under certain circumstances (bug #6023)
  * Snapshots: fixed crash with VBoxHeadless / OSE
  * VMM: fixed reference counting guru meditation (bug #4940)
  * VMM: improved guest SMP stability
  * VMM: fixed VT-x hardware debug issues (bugs #477 & #5792)
  * VMM: fixed PGMDynMapHCPage guru meditation (Mac OS X; VT-x only; bug #6095)
  * VMM: fixed pgmPoolTrackFlushGCPhysPTInt guru meditations (Mac OS X; VT-x only; bugs #6095 & #6125)
  * VMM: Fixed host crash when running PAE guests in VT-X mode (Mac OS X only; bug #5771).
  * GUI: fix displaying of error message (bug #4345)
  * GUI: fix inability to enter seamless mode (bugs #6185, #6188)
  * 3D support: fixed assertion and flickering when guest application uses several windows with a single OpenGL context (bug #4598)
  * 3D support: fixed host crashes when using GL_EXT_compiled_vertex_array and array element calls (bug #6165)
  * 3D support: fixed runtime linker errors with OpenGL guest libs (bug #5297)
  * 3D support: fixed OpenGL extension viewer crash on startup (bug #4962)
  * NAT: fixed a 3.1.4 regression on Windows hosts where graceful connection termination was broken (bug #6237)
  * NAT: alternative network setting was not stored persistent (bug #6176)
  * NAT: fixed memory corruption during ICMP traffic under certain circumstances
  * Network: allow to switch the host interface or the internal network while a VM is running (bug #5781)
  * VHD: fix for images with a block size different than 2MB
  * USB: fixed filtered device attach regression (bug #6251)
  * USB: fixed crash in OHCI under rare circumstances (bug #3571)
  * VRDP: fixed hang under rare circumstances when attaching USB devices
  * ACPI: prevent guest freezes when accessing /proc/acpi for determining the state of the host battery and the AC adapter (Linux hosts only; bug #2836)
  * PulseAudio: fixed guest freezes under certain conditions (3.1.4 regression; bug #6224)
  * BIOS: increased space for DMI strings
  * BIOS: fixed interrupt routing problem for certain configurations (I/O-APIC enabled, ACPI not used; bug #6098)
  * iSCSI: be more robust when handling the INQUIRY response
  * iSCSI: be more robust when handling sense data
  * BusLogic: fixed FreeBSD guests
  * webservice: vboxwebsrv is now multithreaded
  * Solaris Installer: fixed netmask to stay persistent across reboots for Host-only interface (bug #4590)
  * Linux installer: removed external dependency to libpng12.so (bug #6243)
  * Solaris Additions: fixed superfluous kernel logging (bug #6181)
  * Linux Additions: fixed hang when starting the X server in Fedora12 guests and in guests with Linux 2.6.33 or later (bug #6198)
  * Linux Additions: support Mandriva speedboot runlevel (bug #5484)
  * Linux Additions: fixed SELinux security context of mount.vboxsf (bug #6362)
  * Linux Additions: support Ubuntu 10.04 (bug #5737)
  * Web service: update PHP bindings to fix problems with enums and collections
- deprecated vbox-x_crash.diff
* Thu Feb 18 2010 mseben@novell.com
- rewritten spec file
- split kmp packages to guest and host parts
- added vbox-x_crash.diff to fix X crash caused by guest additions
  see:http://www.virtualbox.org/ticket/6198
* Mon Feb 15 2010 mseben@novell.com
- updated to 3.1.4
  * VMM: SMP stability fixes
  * VMM: fixed guru meditation in certain rare cases (bug #5968)
  * VMM: activate NXE for PAE enabled guests (VT-x and AMD-V on 32 bits hosts only; bug #3578)
  * VMM: added workaround for broken BIOSes that make VirtualBox think AMD-V is in use (for details see bug #5639)
  * VMM: fixed rare host reboot when restoring a saved state (bug #3945)
  * VMM: fixed incompatibility with 2.6.32 Linux kernels (software virtualization only; bug #6100)
  * VMM: turn on nested paging by default for new VMs (if available; VT-x and AMD-V only)
  * VMM: turn on VPID by default for new VMs (if available; VT-x only)
  * VMM: perform strict CPUID compatibility checks when teleporting; to get the old behavior set "VBoxInternal/CPUM/StrictCpuIdChecks" to 0
  * VMM: fixed VM crash with certain 16 bits Windows applications (software virtualization only; bug #5399)
  * Snapshots: fixed a 3.1 regression that broke deletion of snapshots when a machine had immutable or writethrough storage attached (bug #5727)
  * Saved state: fixed VERR_SSM_LOADED_TOO_MUCH error when loading DisplayScreenshot(bug #6162)
  * VBoxManage: add restorecurrent operation to snapshots command
  * VBoxManage: fixed broken snapshot lookup by name (bug #6070
  * GUI: fixed the broken "Reload" button that reloads the machine XML when a machine is inaccessible
  * GUI: fixed guest fullscreen mode after reboot (bug #5372)
  * GUI: handle Ctrl+Break properly on X11 hosts (bug #6122)
  * GUI: fixed status LEDs for storage devices
  * GUI: workaround for disabling the seamless mode on KDE hosts (KWin bug)
  * 3D support: fixed SELinux warning saying VBoxOGL.so requires text relocation (bug #5690)
  * 3D support: fixed Corrupted surface rendering (bug #5695)
  * 3D support: free textures on guest application termination (bug #5206)
  * 3D support: fixed ubigraph_server crashes (#4674)
  * 3D support: fixes for 64-bit Solaris guests
  * Seamless: disable seamless mode when guest changes screen resolution (bug #5655)
  * NAT: fixed high CPU load under certain circumstances (Windows hosts only; bug #5787)
  * NAT: fixed handling of the broadcast flag in DHCP requests
  * NAT: fixed rare crash due to an assertion in the ICMP code (bug #3217)
  * Virtio-net: don't crash when ports accessed beyond the valid range (bug #5923)
  * LsiLogic: fix for Windows 7 guests
  * ATA: fix for guru meditation when installing Solaris 8 guests (bug #5972)
  * VHD: fixed an incompatibility with Virtual PC (bug #5990)
  * VHD: update the footer backup after setting a new UUID (bug #5004)
  * Host DVD: really fixed loading "passthrough" setting from config file (bug #5681)
  * Shared folders: fixed resolving of symlink target on Linux (3.1.2 regression)
  * VRDP: fixed VERR_NET_ADDRESS_IN_USE error when restarting a VM (3.1 regression; bug #5902)
  * VRDP: fixed crash on Mac OS X when 3D is enabled (3.1 regression)
  * PulseAudio: fixed recording (bug #4302)
  * USB: fixed a shutdown blue screen (Windows hosts only; bug #5885)
  * BIOS: fixed attribute during text scroll (bug #3407)
  * OVF: fix strange error messages on disk import errors
  * OVF: do not require write access the the .ovf file during import (3.1 regression; bug #5762)
  * iSCSI: fix taking snapshots of a running VM (#5849)
  * Solaris hosts: several USB fixes (including support for Apple iPod; bug #5873)
  * Solaris installer: fixed USB module removal and Solaris 10 "id" binary incompatibility
  * Guest Additions: fixed wrong guest time adjustment if the guest clock is ahead (3.1 regression; non-Windows guests only)
  * Linux Additions: fixed shared folders for Linux 2.6.32 guests (bug #5891)
  * Linux Additions: make the mouse driver work on Debian 5.0.3 guests again (3.1.2 regression, bug #5832)
  * Windows Additions: fixed malfunctioning !VBoxService that broke time-sync (bug #5872)
  * Windows Additions: fixed uninstallation issues on 64-bit guests
  * Windows Additions: fixed some sysprep execution issues
  * X.Org Additions: never reject the saved video mode as invalid (bug #5731)
  * XFree86 Additions: accept video mode hints for the initial mode again *
- vbox-typecast.diff : deprecated
* Mon Dec 21 2009 poeml@cmdline.net
- refresh virtualbox-ose-permissions_warning.diff, so it applies on the very
  picky Factory (without any fuzz)
* Mon Dec 21 2009 poeml@cmdline.net
- updated to 3.1.2 (maintenance release)
  * VMM: fixed SMP stability regression
  * USB: fixed USB related host crashes on 64 bits Windows hosts (#5237)
  * Main: wrong default HWVirtExExclusive value for new VMs (bug #5664)
  * Main: DVD passthrough setting was lost (bug #5681)
  * VBoxManage: iSCSI disks do not support adding a comment (bug #4460)
  * VBoxManage: added missing --cpus and --memory options to OVF --import
  * GUI: fixed VBox URL in update dialog for German and Dutch languages
  * GUI: NLS updates
  * OVF: fixed export of non standard storage controller names (bug #5643)
  * Solaris hosts: several USB fixes (including support for Apple iPhone)
  * Mac OS X hosts: several fixes for the 3D support
  * Mac OS X hosts: re-enabled CMD+Key combinations, even if the Host-Key isn't CMD (bug #5684)
  * Mac OS X hosts: fixed to fast scrolling if the mouse wheel is used inside the guest (bug #5672)
  * Mac OS X hosts: dock & menubar don't disappear in fullscreen when the VM is not running on the primary display (bug #1762)
  * Mac OS X hosts: added an option for enabling "Auto show Dock & Menubar in fullscreen" (bug #5636)
  * Windows host installer: fixed starting VBox with wrong privileges right after installation (bug #4162)
  * Host interface and host-only networking: prevent driver from unloading while a VM is still active (Windows host only)
  * Host-only networking: fixed host-only interface creation (Windows host only) (bug #5708)
  * Virtio-net: don't crash without an attached network
  * Virtio-net: fixed the issue with intermittent network in VM with several virtual CPU cores.
  * NAT: fixed port-forwarding regressions (bug #5666)
  * NAT: fixed crash under certain conditions (bug #5427)
  * NAT: fixed resolving of names containing a slash or underscore when using the host resolver DNS proxy (bug #5698)
  * ATA: fixed sporadic crash when resuming after a VM was forcefully paused (e.g. due to iSCSI target being unavailable)
  * SATA: fixed raw vmdk disks (bug #5724)
  * Linux guests: increased the default memory for Redhat and Fedora guests
  * Linux Guest Additions: fixed installation on RHEL 3.9 guests and on some 64bit guests
  * Linux Guest Additions: prevent SELinux warnings concerning text relocations in VBoxOGL.so (bug #5690)
  * X11 guests: fixed mouse support for some Xorg 1.4 guests (openSUSE 11.0)
  * X11 guests: fixed xorg.conf modification for some older Xorg releases (openSUSE 11.1)
  * Windows guests: fixed some VBoxService shutdown issues
  * Windows guests: fixed VBoxVideo spinlock issues on NT4
  * Windows Guest Additions: fixed uninstallation issues of NT4
  * Shared folders: fixed resolving of symlink target (bug #5631)
  * 2D Video acceleration: delay loading of OpenGL dlls for Windows hosts to avoid GUI crashes on misconfigured systems
  * 2D Video acceleration: fixed issues with video picture not displayed on playback
- some files have been moved to other places in the source tree, and
  virtualbox-ose-disable-updates.diff was adjusted for those changes
- virtualbox-ose-init-scripts.diff was forward ported
* Fri Dec  4 2009 mseben@novell.com
- small corrections in guest and host init scripts (bnc#560166)
* Tue Dec  1 2009 mseben@novell.com
- updated to 3.1.0
  - major new futures :
  * Teleportation (aka live migration); migrate a live VM session
    from one host to another (see the manual for more information)
  * VM states can now be restored from arbitrary snapshots instead
    of only the last one, and new snapshots can be taken from other
    snapshots as well ("branched snapshots"; see the manual for more information)
  * 2D video acceleration for Windows guests; use the host video
    hardware for overlay stretching and color conversion (see the
    manual for more information)
  * More flexible storage attachments: CD/DVD drives can be attached
    to an arbitrary IDE controller, and there can be more than one
    such drive (the manual for more information)
  * The network attachment type can be changed while a VM is running
  * Complete rewrite of experimental USB support for OpenSolaris
    hosts making use of the latest USB enhancements in Solaris Nevada 124 and higher
  * Significant performance improvements for PAE and AMD64 guests
    (VT-x and AMD-V only; normal (non-nested) paging)
  * Experimental support for EFI (Extensible Firmware Interface)
  * Support for paravirtualized network adapters (virtio-net)
  - the following items were fixed and/or added:
  * VMM: guest SMP fixes for certain rare cases
  * GUI: snapshots include a screenshot
  * GUI: locked storage media can be unmounted by force
  * GUI: the a log window grabbed all key events from other GUI windows (bug #5291)
  * GUI: allow to disable USB filters (bug #5426)
  * GUI: improved memory slider in the VM settings
  * GUI: the VirtualBox website couldn't be opened from the help menu (bug #4559)
  * 3D support: major performance improvement in VBO processing
  * 3D support: added GL_EXT_framebuffer_object, GL_EXT_compiled_vertex_array support
  * 3D support: fixed crashes in FarCry, SecondLife, Call of Duty, Unreal Tournament,
    Eve Online (bugs #2801, #2791)
  * 3D support: fixed graphics corruption in World of Warcraft (#2816)
  * 3D support: fixed Final frame of Compiz animation not updated to the screen (#4653)
  * 3D support: fixed incorrect rendering of non ARGB textures under compiz
  * iSCSI: support iSCSI targets with more than 2TiB capacity
  * VRDP: fixed occasional VRDP server crash (bug #5424)
  * Network: fixed the E1000 emulation for QNX (and probably other) guests (bug #3206)
  * NAT: added host resolver DNS proxy (see the manual for more information)
  * VMDK: fixed incorrectly rejected big images split into 2G pieces (bug #5523, #2787)
  * VMDK: fixed compatibility issue with fixed or raw disk VMDK files (bug #2723)
  * VHD: fixed incompatibility with Hyper-V
  * Support for Parallels version 2 disk image (HDD) files; see the manual for more information
  * OVF: create manifest files on export and verify the content of an optional manifest file on import
  * OVF: fixed memory setting during import (bug #4188)
  * Mouse device: now five buttons are passed to the guest (bug #3773)
  * VBoxHeadless: fixed loss of saved state when VM fails to start
  * VBoxSDL: fixed crash during shutdown (Windows hosts only)
  * X11 based hosts: allow the user to specify their own scan code layout (bug #2302)
  * Mac OS X hosts: don't auto show the menu and dock in fullscreen (bug #4866)
  * Mac OS X hosts (64 bit): don't interpret mouse wheel events as left click (bug #5049)
  * Mac OS X hosts: fixed a VM abort during shutdown under certain conditions
  * Solaris hosts: combined the kernel interface package into the VirtualBox main package
  * Solaris hosts: support for OpenSolaris Boomer architecture (with OSS audio backend).
  * Shared folders: VBOXSVR is visible in Network folder (Windows guests, bug #4842)
  * Shared folders: performance improvements (Windows guests, bug #1728)
  * Windows, Linux and Solaris Additions: added balloon tip notifier if VirtualBox host
    version was updated and Additions are out of date
  * Solaris guests: fixed keyboard emulation (bug #1589)
  * Solaris Additions: fixed as_pagelock() failed errors affecting guest properties (bug #5337)
  * Windows Additions: added automatic logon support for Windows Vista and Windows 7
  * Windows Additions: improved file version lookup for guest OS information
  * Windows Additions: fixed runtime OS detection on Windows 7 for session information
  * Windows Additions: fixed crash in seamless mode (contributed by Huihong Luo)
  * Linux Additions: added support for uninstalling the Linux Guest Additions (bug #4039)
  * Linux guest shared folders: allow mounting a shared folder if a file of the same name as
    the folder exists in the current directory (bug #928)
  * SDK: added object-oriented web service bindings for PHP5
- dropped deprecated vbox-fix_return.diff
- refresh patches to apply with fuzz=0 (new rpm)
- added fix_return.diff : fix no-return-in-nonvoid-function build issue
- added typecast.diff : typecast of pointer using uintptr_t to fix build error
- removed deprecated : kmp-vboxvfs.diff and gcc43-fixes.diff
* Thu Nov  5 2009 mseben@novell.com
- added debug_hash.diff to fix build issue
* Thu Nov  5 2009 mseben@novell.com
- updated to 3.0.10
  * VMM: guest SMP stability fixes
  * VMM: fixed guru meditation with nested paging and SMP guests (bug #5222)
  * VMM: changed VT-x/AMD-V usage to detect other active hypervisors; necessary for e.g. Windows 7 XP compatibility mode (Windows & Mac OS X hosts only; bug #4239)
  * VMM: guru meditation during SCO OpenServer installation and reboot (VT-x only; bug #5164)
  * VMM: fixed accessed bit handling in certain cases (bug #5248)
  * VMM: fixed VPID flushing (VT-x only)
  * VMM: fixed broken nested paging for 64 bits guests on 32 bits hosts (AMD-V only; bug #5285)
  * VMM: fixed loading of old saved states/snapshots (bug #3984)
  * Linux hosts: fixed module compilation against Linux 2.6.32rc4 and later
  * Guest Additions: fixed possible guest OS kernel memory exhaustion
  * Guest Additions: fixed stability issues with SMP guests
  * Linux Additions: sendfile() returned -EOVERFLOW when executed on a shared folder (bug #2921)
  * Linux Additions: fixed incorrect disk usage value (non-Windows hosts only)
  * Linux installer: register the module sources at DKMS even if the package provides proper modules for the current running kernel
  * 3D support: removed invalid OpenGL assertion (bug #5158)
  * Network: fixed the Am79C973 PCNet emulation for QNX (and probably other) guests (bug #3206)
  * VMDK: fix handling of split image variants
  * VHD: do not delay updating the footer when expanding the image to prevent image inconsistency
  * USB: stability fix for some USB 2.0 devices
  * GUI: added a search index to the .chm help file
  * GUI/Windows hosts: fixed CapsLock handling on French keyboards (bug #2025)
  * Shared clipboard/X11 hosts: fixed a crash when clipboard initialisation failed (bug #4987)
* Thu Oct 22 2009 dmueller@suse.de
- update to 3.0.8:
  * VMM: fixed 64 bits guest on 32 bits host regression in 3.0.6 (VT-x only; bug #4947)
  * VMM: fixed a recompiler triple fault guru meditation (VT-x & AMD-V only; bug #5058)
  * VMM: fixed hang after guest state restore (AMD-V, 32 bits Windows guest and IO-APIC enabled only; bug #5059)
  * VMM: fixed paging issue with OS/2 guests
  * VMM: fixed guru meditation in rare cases (2.0 regression; software virtualization only)
  * VMM: fixed release assertion during state restore when using the Sound Blaster 16 emulation (bug #5042)
  * Security: fixed vulnerability that allowed to execute commands with root privileges
  * Linux hosts: fixed runtime assertion in semaphore implementation which was triggered under certain conditions (bug #616)
  * Linux hosts: change the default USB access mode on certain distributions (bugs #3394 and #4291)
  * Linux hosts: on hardened Gentoo, the VBoxSVC daemon crashed by opening the VM network settings (bug #3732)
  * Linux hosts, Solaris hosts: pass the XAUTHORITY variable along the DISPLAY variable when starting a VM from VBoxManage or from the VM selector (bug #5063)
  * Linux hosts: use sysfs to enumerate host drives if hal is not available
  * Solaris hosts: fixed a bug which would hang the host sporadically as interrupts were not re-enabled everytime
  * Solaris hosts: fixed a kernel panic with bridged and host-only networking (bug #4775)
  * Solaris hosts: fixed incorrectly persistent CD/DVD-ROMs when changing them (bug #5077)
  * X11-based hosts: support additional function keys on Sun keyboards (bug #4907)
  * Mac OS X hosts (Snow Leopard): fixed problem starting headless VMs without a graphical session (bug #5002)
  * Mac OS X hosts: fixed problem listing host-only adapter names with trailing garbage (attached VMs won't start)
  * Windows Additions: now work with Vista 64-bit Home editions (bug #3865)
  * Windows Additions: fixed screen corruption with ZoomText Magnifier
  * Windows Additions: fixed NPGetUniversalName failure (bug #4853)
  * Windows Additions: fixed Windows NT regression (bug #4946)
  * Windows Additions: fixed VBoxService not running if no Shared Folders are installed
  * Linux Additions: implemented ftrunctate (bug #4771)
  * VRDP: start VM even if configured VRDP port is in use
  * Networking: the PCnet network device stopped receiving under rare conditions (bug #4870)
  * VBoxManage: implemented controlvm vrdpport command
  * iSCSI: fixed issue with NetApp targets (#5072)
  * SCSI: add support for virtual disks larger than 2TB
  * USB: fixed potential crash when unplugging USB2 devices (bug #5089)
  * NAT: IPSEC did not properly work with Linux guests (bug #4801)
* Thu Oct 15 2009 mseben@novell.com
- fixed security issue with empty LD_LIBRARY_PATH in wrappers (bnc#448246)
* Fri Oct  9 2009 mseben@novell.com
- fix build (corrected 60-vboxadd.rules)
* Thu Oct  8 2009 mseben@novell.com
- added udev rules file 60-vboxadd.rules for guest system (bnc#541196)
* Thu Oct  8 2009 mseben@novell.com
- added checks for setuid on VBoxNetAdpCtl (bnc#533550)
* Mon Oct  5 2009 mseben@novell.com
- added VBoxNetAdpCtl.diff : use VBoxNetAdpCtl.cpp from upstream svn
  which fix security problems with popen and strncpy (see bnc#533550)
* Thu Oct  1 2009 mseben@novell.com
- fix permissions for VBoxRandR and vboxadd-xclient
* Tue Sep 29 2009 mseben@novell.com
- moved hal policy file 90-vboxguest.fdi to hal/fdi/policy instead
  of hal/fdi/information
* Thu Sep 24 2009 mseben@novell.com
- added 90-vboxguest.fdi for hal policy, to autodetect the virtualbox
  mouse (thanks to Tejas Guruswamy)
- added permissions_warning.diff - implements messagebox, which is
  displayed, when user try to start VirtualBox and is not a member
  of vboxusers group
* Tue Sep 22 2009 mseben@novell.com
- added VBoxRandR to guest-tools - support for dynamic display changes (autoresize)
- added vboxadd-xclient.sh to guest-tools - allow automatically start
  VBoxClient with support for shared clipboard, autoresize and seamless window
* Mon Sep 14 2009 mseben@novell.com
- rewritten init-scripts.diff (bnc#537793) and added
  /etc/default/virtualbox config, which allow configure type of
  session shutdown (thanks to Dennis Olsson)
* Thu Sep 10 2009 mseben@novell.com
- updated to 3.0.6
  * VMM: fixed IO-APIC overhead for 32 bits Windows NT, 2000, XP and 2003 guests (AMD-V only; bug #4392)
  * VMM: fixed a Guru meditation under certain circumstances when enabling a disabled device (bug #4510)
  * VMM: fixed a Guru meditation when booting certain Arch Linux guests (software virtualization only; bug #2149)
  * VMM: fixed hangs with 64 bits Solaris & OpenSolaris guests (bug #2258)
  * VMM: fixed decreasing rdtsc values (AMD-V & VT-x only; bug #2869)
  * VMM: small Solaris/OpenSolaris performance improvements (VT-x only)
  * VMM: cpuid change to correct reported virtual CPU id in Linux
  * VMM: NetBSD 5.0.1 CD hangs during boot (VT-x only; bug #3947)
  * Solaris hosts: worked around an issue that caused the host to hang (bug #4486)
  * Solaris hosts: fixed a rare host system deadlock when using bridged networking
  * Solaris hosts: fixed a potential host system deadlock when CPUs were onlined or offlined
  * Solaris hosts installer: added missing dependency for UTF-8 package (bug #4899)
  * Linux hosts: don't crash on Linux PAE kernels < 2.6.11 (in particular RHEL/CentOS 4); disable VT-x on Linux kernels < 2.6.13 (bug #1842)
  * Linux/Solaris hosts: correctly detect keyboards with fewer keys than usual (bug #4799)
  * Mac OS X hosts: prevent password dialogs in 32 bits Snow Leopard
  * Python WS: fixed issue with certain enumerations constants having wrong values in Python webservices bindings
  * Python API: several threading and platform issues fixed
  * Python shell: added exportVM command
  * Python shell: various improvements and bugfixes
  * Python shell: corrected detection of home directory in remote case
  * OVF: fixed XML comment handling that could lead to parser errors
  * Main: fixed a rare parsing problem with port numbers of USB device filters in machine settings XML
  * Main: restrict guest RAM size to 1.5 GB (32 bits Windows hosts only)
  * Main: fixed possible hang during guest reboot (bug #3792)
  * GUI: fixed rare crash when removing the last disk from the media manager (bug #4795)
  * VBoxManage: fixed setting guest properties with --flags or -flags
  * Webservice: fixed a severe memory leak, at least on platforms using XPCOM
  * Serial: fixed host mode (Solaris, Linux and Mac OS X hosts; bug #4672)
  * VRDP: Remote USB Protocol version 3
  * SATA: fixed hangs and BSODs introduced with 3.0.4 (bugs #4695, #4739, #4710)
  * SATA: fixed a bug which prevented Windows 7 from detecting more than one hard disk
  * SATA/SCSI: fixed rare random guest crashes and hangs
  * SCSI: fixed problem with Fedora 11 refusing to boot after kernel update
  * iSCSI: fix logging out when the target has dropped the connection, fix negotiation of simparameters, fix command resend when the connection was dropped, fix processing SCSI status for targets which do not use phase collapse
  * BIOS: fixed a bug that caused the OS/2 boot manager to fail (2.1.0 regression, bug #3911)
  * PulseAudio: don't hang during VM termination if the connection to the server was unexpectedly terminated (bug #3100)
  * Mouse: fixed weird mouse behaviour with SMP (Solaris) guests (bug #4538)
  * HostOnly Network: fixed failure in CreateHostOnlyNetworkInterface() on Linux (no GUID)
  * HostOnly Network: fixed wrong DHCP server startup while hostonly interface bringup on Linux
  * HostOnly Network: fixed incorrect factory and default MAC address on Solaris
  * HostOnly Network: fixed the problem with listing host-only interfaces on Mac OS X when all physical interfaces are down (bugs #4698, #4790)
  * DHCP: fixed a bug in the DHCP server where it allocated one IP address less than the configured range
  * E1000: fixed receiving of multicast packets
  * E1000: fixed up/down link notification after resuming a VM
  * NAT: fixed ethernet address corruptions (bug #4839)
  * NAT: fixed hangs, dropped packets and retransmission problems (bug #4343)
  * Bridged Network: fixed packet queue issue which might cause DRIVER_POWER_STATE_FAILURE BSOD for Windows hosts (bug #4821)
  * Windows Additions: fixed a bug in VBoxGINA which prevented selecting the right domain when logging in the first time
  * Shared clipboard: do not send zero-terminated text to X11 guests and hosts (bug #4712)
  * Shared clipboard: use a less CPU intensive way of checking for new data on X11 guests and hosts (bug #4092)
  * Guest Additions: do not hide the host mouse cursor when restoring a saved state (bug #4700)
  * Windows guests: fixed issues with the display of the mouse cursor image (bugs #2603, #2660 and #4817)
  * SUSE 11 guests: fixed Guest Additions installation (bug #4506)
  * Guest Additions: support Fedora 12 Alpha guests (bugs #4731, #4733 and #4734)
- drop deprecated pa-interface_change.diff
* Mon Sep  7 2009 mseben@novell.com
- added pa-interface_change.diff to fix interface change in PulseAudio
* Sun Aug 23 2009 mseben@novell.com
- added vboxvideo.ko kernel module to virtualbox-ose-kmp-*
- added VBoxOGL libraries to xorg-x11-driver-virtualbox-ose
* Mon Aug 17 2009 suse-tux@gmx.de
- fixed typo in the vboxadd init script and updated virtualbox-ose-init-scripts.diff
  (bnc#530271)
* Fri Aug 14 2009 mseben@suse.cz
- fix quote symbol (") in vboxdrv.rules (bnc#528310)
* Thu Aug  6 2009 mseben@suse.cz
- updated to 3.0.4
  * VMM: 64 bits guest stability fixes (AMD-V only; bugs #3923 & #3666)
  * VMM: SMP stability fixes (AMD-V only)
  * VMM: SMP performance improvement (esp. for Solaris guests)
  * VMM: eliminated several bugs which could lead to a host reboot
  * VMM: fixed OS/2 ACP2 boot floppy hang (VT-x only)
  * VMM: small performance improvement for OpenSolaris guests (AMD-V only)
  * VMM: fixed CentOS/Xen reboot (software virtualization only; bug #4509)
  * SATA: fixed hangs / BSOD during Windows XP installation (bug #4342)
  * SATA: mark the ports as non hotpluggable (bug #3920)
  * 3D support: fix deadlocks and context/window tracking for multithreaded applications (bug #3922)
  * 3D support: fix memory leaks when terminating OpenGL guest applications
  * 3D support: fix crash in Call of Duty
  * NAT: using two or more NAT adapters in one VM was broken (3.0.0 regression)
  * NAT: fixed network communication corruptions (bugs #4499, #4540, #4591, #4604)
  * NAT: fixed passive ftp access to host server (bug #4427)
  * iSCSI: fixed cloning to/from iSCSI disks
  * GUI: fixed path separator handling for the OVF export on Windows (bug #4354)
  * GUI: the mini toolbar was only shown on the first host display (bug #4654)
  * GUI: added a VM option to display the mini toolbar on top
  * GUI: don’t crash when adding plus configuring host-only network interfaces
  * Shared Folders: fixed selection of a drive root directory as a shared folder host path in VirtualBox (Windows host only)
  * USB: fixed a bug that may have rendered USB devicefilter settings inactive (3.0.2 regression, bug #4668)
  * Guest Additions: report the Guest Additions version to the guest properties (bug #3415)
  * Linux hosts: fixed problems leading to wrong colors or transparency in host windows with some graphics drivers (bug #3095)
  * Linux hosts: hardware detection fallbacks if the hal service fails to find any DVD drives.
  * Linux and Solaris hosts: Work around color handling problems in Qt (bug #4353)
  * Solaris Installer: fixed incorrect netmask for Host-only interface (bug #4590)
  * Solaris Installer: added package dependency for Python and Python-devel (bug #4570)
  * X11 guests: prevent windows from being skipped in seamless mode KDE guests (bugs #1681 and #3574)
  * X11 guests: fixed screen corruption in X11 guests when large amounts of video RAM were allocated (bug #4430)
  * X11 guests: some fixes when switching between host and guest-drawn mouse pointers.
  * X11 guests: fixed an issue which caused seamless mode to stop working as it should (the main issue listed in bug #2238).
* Mon Aug  3 2009 mseben@suse.cz
- drop qt3-devel-tools,libmudflap-32bit from BuildRequires
* Thu Jul 30 2009 mseben@suse.cz
- enable generated data for SaX
- added mountvboxsf, VBoxControl, VBoxService to guest-tools
- disable chown of device in vboxadd init script in guest-tools subpackage (bnc#507835)
* Mon Jul 13 2009 mseben@suse.cz
- updated to 3.0.2
  * VMM: fixed network regressions (guest hangs during network IO) (bug #4343)
  * VMM: guest SMP performance improvements
  * VMM: fixed hangs and poor performance with Kaspersky Internet Security (VT-x/AMD-V only; bug #1778)
  * VMM: fixed crashes when executing certain Linux guests (software virtualization only; bugs #2696 & #3868)
  * ACPI: fixed Windows 2000 kernel hangs with IO-APIC enabled (bug #4348)
  * APIC: fixed high idle load for certain Linux guests (3.0 regression)
  * BIOS: properly handle Ctrl-Alt-Del in real mode
  * iSCSI: fixed configuration parsing (bug #4236)
  * OVF: fix potential confusion when exporting networks
  * OVF: compatibility fix (bug #4452)
  * NAT: fixed crashes under certain circumstances (bug #4330)
  * 3D support: fixed dynamic linking on Solaris/OpenSolaris guests (bug #4399)
  * 3D support: fixed incorrect context/window tracking for multithreaded apps
  * Shared Folders: fixed loading from saved state (bug #1595)
  * Shared Folders: host file permissions set to 0400 with Windows guest (bug #4381)
  * X11 host and guest clipboard: fixed a number of issues, including bug #4380 and #4344
  * X11 Additions: fixed some issues with seamless windows in X11 guests (bug #3727)
  * Linux hosts: workaround for buggy graphics drivers showing a black VM window on recent distributions (bug #4335)
  * Linux hosts: fixed typo in kernel module startup script (bug #4388)
  * OVF: accept ovf:/disk/ specifiers with a single slash in addition to ovf://disk/ (bug #4452)
  * Fixed a settings file conversion bug which sometimes caused hardware acceleration to be enabled
- drop vbox-ose-rpmlintrc
* Wed Jul  1 2009 mseben@suse.cz
- updated to 3.0.0, major new features were added:
  * Guest SMP with up to 32 virtual CPUs (VT-x and AMD-V only)
  * Windows guests: ability to use Direct3D 8/9 applications / games (experimental)
  * Support for OpenGL 2.0 for Windows, Linux and Solaris guests
- deprecated : 64issue.diff , validate-op-gcc43.diff and increment.diff
- disabled Makefile-vboxadd,Makefile-vboxnetflt and Makefile-vboxvfs
* Fri Jun 19 2009 coolo@novell.com
- disable as-needed for this package as it fails to build with it
* Wed Jun 17 2009 mseben@suse.cz
- updated to 3.0.0_BETA_2, major new features were added:
  * Guest SMP with up to 32 virtual CPUs (VT-x and AMD-V only)
  * Windows guests: ability to use Direct3D 8/9 applications / games (experimental)
  * Support for OpenGL 2.0 for Windows, Linux and Solaris guests
- deprecated : 64issue.diff , validate-op-gcc43.diff and increment.diff
- disabled Makefile-vboxadd,Makefile-vboxnetflt and Makefile-vboxvfs
* Tue Jun  9 2009 coolo@novell.com
- Replace pmtools with acpica package required for building.
  pmtools package gets split into acpica and dmidecode,
  pmtools will be dropped.
* Thu Jun  4 2009 mseben@suse.cz
- added patch increment.diff : same variable used twiceand post
  incremented in the same expression in dnsproxy.c
* Mon Jun  1 2009 mseben@suse.cz
- updated to 2.2.4
  * Solaris hosts: make it work with Solaris build 114 or later (bug #3981)
  * Solaris hosts: ﬁxed a bug serial port character handling found during loopback (bug #3120)
  * Linux hosts: adapted vboxdrv.sh to the latest changes in VBoxManage list runningvms (bug #4034)
  * Windows hosts: ﬁxed a crash caused by host-only/bridged networking
  * Mac OS X hosts: ﬁxed access to host DVD with passthrough disabled (bug #4077)
  * Guest Additions: ﬁxed problems with KDE 4 not recognizing mouse clicks
  * Windows Additions: ﬁxed incorrect 8-bit guest color depth in Windows 7 guests
  * GUI: warn if VT-x/AMD-V could not be enabled for guests that require this setting (bug #4055)
  * VMM: ﬁxed occassional crash due to insufﬁent memory
  * VMM: ﬁxed hanging 64 bits Solaris guests
  * VMM: restore from a saved state occassionally failed (bugs #3984 and #2742)
  * Clipboard: ﬁxed a deadlock while shutting down the shared clipboard on X11 hosts (bug #4020)
  * OVF: ﬁxed potential hang during import
  * OVF: ﬁxed potential crashes during import/export on Win64 hosts
  * VBoxManage modifyhd --compact: ﬁxed bug which could lead to crashes and image corruption (bug #3864)
  * VBoxManage metrics collect: now ﬂushes the output stream.
  * VHD: made VBoxManage internalcommands sethduuid work for .vhd ﬁles (bug #3443)
  * VHD: some .vhd ﬁles could not be cloned (bug #4080)
  * VMDK: ﬁxed creating snapshots
  * NAT: improvement of TCP connection establisment (bug #2987)
  * NAT: ﬁxed order of DNS servers in DHCP lease (bug #4091)
  * NAT: ﬁxed DHCP lease for multiple name servers (bug #3692)
  * NAT: ﬁxed a potential segfault if the host lost its connectivity (bug #3964)
  * Shared Folders: deny access to parent directories on Windows hosts (bug #4090)
  * Shared Folders: make rm/rmdir work with Solaris guests on Windows hosts
  * Networking: ﬁxed the problem with blocked receiving thread when a broadcast packet arrives too early
  to be handled by uninitialized e1000 adapter.
  * Networking: ﬁxed the problem that caused host freezes/crashes when using bridged mode with host’s
    interface having RX checksum ofﬂoading on (bug #3926 and related). Fixes problems with TX ofﬂoading as well (bug #3870)
  * PXE boot: Added support for PRO/1000 MT Server adapter.
  * Python bindings: ﬁxed keyword conﬂict
  * SCSI: ﬁxed occasional crashes on Win64
  * Serial: allow to redirect the serial port to a raw ﬁle (bug #1023)
  * VRDP: ﬁxed a rare incorrect screen update
* Fri May 29 2009 mseben@suse.cz
- included proper version of vboxmouse_drv and vboxvideo_drv in
  xorg-x11-driver (bnc#507839)
* Mon May 25 2009 coolo@suse.de
- fix %%endif
* Sat May 23 2009 coolo@suse.de
- switch to gcc44
* Thu May  7 2009 mseben@suse.cz
- fixed ose-init-scripts.diff : don't use vboxusers group for
  /dev/vboxdrv (bnc#429725)
* Thu May  7 2009 dmueller@suse.de
- make sure that the kmp is also updated at the same time
  like the main module, otherwise bad things will happen
* Tue May  5 2009 dmueller@suse.de
- fix build for older distros
* Wed Apr 29 2009 mseben@suse.cz
- updated to 2.2.2
  * Host and guest clipboard: ﬁxed a number of issues affecting hosts and guests running the X window system.
  * Guest Additions: make sure the virtual mouse autodetection works on ﬁrst reboot after installing the Additions on X.Org server 1.5 and later.
  * Guest Additions: properly report process identity number of running services
  * Guest Additions: clean up properly if the X Window server terminates
  * Linux Additions: ﬁxed installation path for OpenGL libraries in some 64-bit guests (bug #3693)
  * Solaris Additions: ﬁxed installation to work when X.Org is not installed on the guest
  * Solaris Additions: ﬁxed a bug that could panic the guest when unmounting a busy shared folder
  * Windows Additions: ﬁxed mouse pointer integration of some Windows guests (2.2.0 regression, bug #3734)
  * Windows Additions: ﬁxed installation on Windows Server 2008 Core (bug #2628)
  * Main: do not try to use older versions of D-Bus (Linux hosts only, bug #3732)
  * VMM: ﬁxed out-of-memory conditions on Windows hosts (bug #3657)
  * VMM: ﬁxed occasional hangs when attaching USB devices during VM startup (2.2.0 regression; bugs #3787)
  * VMM: ﬁxed guru meditation related to memory management (software virtualization only)
  * Virtual disks: ﬁx possible data corruption when writing to diff images, incorrect detection of redundant writes
  * GUI: reworked network settings dialog
  * GUI: properly show the detailed settings dialog of NAT networks (bug #3702)
  * GUI: HostKey could not be changed (2.2.0 regression, bug #3689)
  * GUI: ﬁxed memory textﬁeld size (Windows hosts only; bug #3679)
  * GUI: ﬁxed crash when selecting a shared folder path (Windows hosts only; bugs #3694, #3751, #3756)
  * VBoxManage modifyhd --compact: implemented again for VDI ﬁles, and now supports relative paths (bug #2180, #2833)
  * VBoxManage snapshot discard: made it work again (2.1.0 regression; bug #3714)
  * NAT: ﬁxed release assertion during poll() (bug #3667)
  * Clipboard: ﬁxed random crahes (X11 hosts only, bug #3723)
  * Shared Folders: ﬁxed incorrect permissions for Solaris guests
  * Shared Folders: ﬁxed wrong ﬁle sizes with Solaris guests
  * CBindings: ﬁxed possible memory leak while releasing the IVirtualBox and ISession Objects
  * Solaris hosts: ﬁxed host-only network interface incompatibility with nwam/dhcpagent (bug #3754)
* Mon Apr 20 2009 mseben@suse.cz
- updated to 2.2.0
  * VMM: FreeBSD guest related ﬁx for V86 ﬂags (bug #2342)
  * VMM: ﬁxed guru meditation when booting an AsteriskNow Linux VM (bug #2342)
  * VMM: ﬁxed PGMPOOLKIND_FREE guru meditation (bugs #3356, #3431)
  * VMM: ﬁxed Windows XP boot hang (guest PAE + nested paging only)
  * VMM: allow mixing of VT-x/AMD-V and software virtualization
  * VMM: ﬁxed extremely slow safe mode booting in e.g. Windows 2008 (VT-x/AMD-V only)
  * VMM: signiﬁcant speedup of certain GRUB boot loaders (e.g. Solaris) (VT-x/AMD-V only)
  * VMM: real-mode IOPL ﬁx for DOS guests (VT-x only)
  * VMM: ﬁxed VT-x detection with certain BIOSes that enable VT-x, but don’t set the lock bit in MSR_IA32_FEATURE_CONTROL
  * VMM: ﬁxed hibernation issues on Windows XP hosts (VT-x only; bug #1794)
  * VMM: properly emulate RDMSR from the TSC MSR, should ﬁx some NetBSD guests
  * VMM: emulate RDPMC; ﬁxes Windows guests crashes when using the Kaspersky virus scanner (bug #1778)
  * NAT: ﬁxed truncated downloads (FTP) (bug #3257)
  * NAT: blocked UDP packets caused a crash (bug #3426)
  * NAT: allow to conﬁgure the next server and the boot ﬁle via VBoxManage (bug #2759)
  * IDE: ﬁxed hard disk upgrade from XML-1.2 settings (bug #1518)
  * Hard disk: support more VMDK ﬁle variants (including ﬁxed-size ESX server images)
  * Hard disks: refuse to start the VM if a disk image is not writable
  * USB: further reduced host CPU utilization for OHCI and EHCI
  * USB: ﬁxed BSOD on the host with certain USB devices (Windows hosts only; bug #1654)
  * E1000: properly handle cable disconnects (bug #3421)
  * VRDP: ﬁxed hangs when VRDP server is enabled or disabled in runtime
  * Shared folders: respect umask settings on Linux, OSX and Solaris hosts when creating ﬁles
  * X11 guests: prevented setting the locale in vboxmouse, as this caused problems with Turkish locales (bug #3563)
  * X11 guests: show the guest mouse pointer at the right position if the virtual desktop is larger than the guest resolution (bug #2306)
  * Linux additions: ﬁxed typo when detecting Xorg 1.6 (bug #3555)
  * Solaris guests: added xpg4/xcu4 dependency to the guest additions installer (bug #3524)
  * Windows guests: bind the VBoxMouse.sys ﬁlter driver to the correct guest pointing device (bug #1324)
  * Windows hosts: ﬁxed BSOD when starting a VM with enabled host interface (bug #3414)
  * Linux hosts: do proper reference counting to prevent unloading the vboxnetﬂt module as long as this code is in use (bug #3104)
  * Linux hosts: do not leave zombies of VBoxSysInfo.sh (bug #3586)
  * Linux installers: ﬁxes for Slackware, Arch Linux and Linux from Scratch systems
  * Windows installers: combined installer executable which contains both (32- and 64-bit) architectures.
  * VBoxManage: less cryptic command-line error messages
  * VBoxManage list vms commands now default to compact format
  * VBoxManage controlvm dvdattach did not work if the image was attached before
  * VBoxManage: allow creation of all supported disk image variants
  * VBoxManage showvminfo: don’t spam the release log if the additions don’t support statistics information (bug #3457)
  * VBoxManage: big command line processing cleanup
  * Hard disks: improved immutable disk support to auto-reset diff ﬁle at VM startup (related to bug #2772)
  * GUI: enable the audio adapter by default for new VMs
  * GUI: warn if VT-x/AMD-V is not operational when starting a 64-bit guest
  * GUI: deactivate 64-bit guest support when the host CPU does not support VT-x/AMD-V
  * GUI: removed ﬂoppy icon from the status bar
  * GUI: show build revision in about dialog
  * GUI: ﬁxed sticky status bar text
  * GUI: improved error dialogs
  * GUI: fail with an appropriate error message when trying to boot a read-only disk image (bug #1745)
  * GUI/Mac OS X: ﬁxed disabled close button
  * GUI/Windows: re-enabled support for copy and paste (Windows hosts 2.0 regression; bug #2065)
  * 3D support: added OpenGL select/feedback support (bug #2920)
  * 3D support: close OpenGL subsystem for terminated guest applications (bug #3243)
  * 3D support: ﬁxed VM hangs when starting guests with 3D acceleration enabled (bug #3437)
  * PXE: ﬁxed boot hangs when hardware virtualization is used (bug #2536)
  * LsiLogic: ﬁxed problems with Solaris guests
  * Main API: close machine settings XML ﬁle when unregistering machine (bug #3548)
* Wed Apr 15 2009 ro@suse.de
- drop xalan/xerces from buildrequires, not used
* Fri Feb 27 2009 dmueller@suse.de
- merge into Factory
* Fri Feb 27 2009 suse-tux@gmx.de
- added Patch18 (vbox-swab_2.6.29_header.diff) which disables vbox's swab.h file
  and uses the one which is shipped with the recent linux-kernel-headers package
  (former versions of this file weren't c++ compatible). Fixed factory build.
* Wed Feb 25 2009 suse-tux@gmx.de
- removed the networking part from the README.SUSE file. There's no need
  to create a bridge anymore.
* Tue Feb 24 2009 dmueller@suse.de
- merge with factory
* Tue Feb 24 2009 suse-tux@gmx.de
- new upstream version 2.1.4
- updated Patch16 (virtualbox-ose-disable-updates.diff)
* Wed Feb 11 2009 dmueller@suse.de
- use the external yasm again instead of an intree
  binary blob
- remove intree binary blob (licensing issues)
* Wed Feb  4 2009 dmueller@suse.de
- gcc41 is no longer required for building
* Mon Feb  2 2009 mkudlvasr@suse.cz
- merge with openSUSE factory
- create tmp dir primary based on uid, then env (bnc#427266)
* Thu Jan 29 2009 suse-tux@gmx.de
- added BuildRequires: udev in order to make rpmlint happy
* Thu Jan 29 2009 suse-tux@gmx.de
- new upstream version 2.1.2
- updated virtualbox-ose-init-scripts.diff
- build everything with gcc43
* Thu Jan 22 2009 dmueller@suse.de
- merge with openSUSE factory
* Wed Jan  7 2009 suse-tux@gmx.de
- fixed #463822 (wrapper scripts ignored arguments)
* Sat Jan  3 2009 suse-tux@gmx.de
- finally fixed build of vboxvfs (it seems that this was never working) so that modprobe
  doesn't complain about unknown symbols
- fixed vboxadd-timesync init script ("status")
* Sat Jan  3 2009 suse-tux@gmx.de
- yet another x86_64 fix (no VBoxREM2.rel anymore due to the new recompiler)
* Sat Jan  3 2009 suse-tux@gmx.de
- fixed vboxvfs on x86_64 (updated and enabled Patch3 (vbox-kmp-vboxvfs.diff))
- renamed %%%%{_sbindir}/mountvboxsf to /sbin/mount.vboxsf
* Mon Dec 29 2008 suse-tux@gmx.de
- new upstream version 2.1.0
- build the complete source with gcc43 (except the recompiler stuff) in order
  to avoid weird linking errors
- the vboxvfs init script was removed because vboxvfs depends on vboxadd so
  it is merged in one script (rcvboxadd)
- the vboxnet init script and the VBoxAddIF/VBoxDeleteIF scripts were removed
  because the TUN/TAP stuff is replaced with the new networking implementation
- don't ship the vditools binary anymore because it is declared as obsolete
- disabled Patch3 (vbox-kmp-vboxvfs.diff)
- disabled Patch15 (vbox-configure_python26.diff)
- added Source11 (Makefile-vboxnetflt)
- updated %%%%preun and %%%%postun scripts for the guest-tools package
- enabled vboxadd-timesync by default
- fixed init scripts
* Tue Dec  2 2008 mkudlvasr@suse.cz
- disable dialog for upstream update [bnc#449099]
* Sat Nov 29 2008 dmueller@suse.de
- add missing requires to make seamless mouse integration work
* Tue Nov 25 2008 lnussel@suse.de
- fix permissions handling (bnc#429725)
- fix permissions of /dev/vboxdrv (bnc#429725)
- don't use %%_libdir for binaries
* Mon Nov 24 2008 dmueller@suse.de
- 2.0.6 update (bnc#448240):
  * VMM: ﬁxed Guru meditation when running 64 bits Windows guests (bug #2220)
  * VMM: ﬁxed Solaris 10U6 boot hangs (VT-x and AMD-V) bug #2565)
  * VMM: ﬁxed Solaris 10U6 reboot hangs (AMD-V only; bug #2565)
  * GUI: the host key was sometimes not properly displayed (Windows hosts only, bug #1996)
  * GUI: the keyboard focus was lost after minimizing and restoring the VM window via the Windows taskbar (bugs #784)
  * VBoxManage: properly show SATA disks when showing the VM information (bug #2624)
  * SATA: ﬁxed access if the buffer size is not sector-aligned (bug #2024)
  * SATA: improved performance
  * SATA: ﬁxed snapshot function with ports>1 (bug #2510)
  * E1000: ﬁxed crash under rare circumstances
  * USB: ﬁxed support for iPhone and Nokia devices (Linux host: bugs #470 & #491)
  * Linux/Solaris/Darwin hosts: verify permissions in /tmp/vbox-$USER-ipc
  * Linux hosts: ﬁxed assertion on high network load (AMD64 hosts, ﬁx for Linux distributions with glibc 2.6 and newer (bug #616)
  * Linux hosts: don’t crash during shutdown with serial ports connected to a host device
  * Solaris hosts: ﬁxed incompatibility between IPSEC and host interface networking
  * Solaris hosts: ﬁxed a rare race condition while powering off VMs with host interface networking
  * Solaris hosts: ﬁxed VBoxSDL on Solaris 10 by shipping the required SDL library (bug #2475)
  * Linux additions: ﬁxed compilation of vboxvfs.ko for 64-bit guests (bug #2550)
  * SDK: added JAX-WS port caching to speedup connections
* Wed Nov 12 2008 dmueller@suse.de
- create vboxusers group in %%pre
- tighten restrictions and make factory build again
* Fri Nov  7 2008 dmueller@suse.de
- install usable permission files for the buildservice
- fix preamble again
* Wed Nov  5 2008 sndirsch@suse.de
- use the appropriate driver version of vboxvideo/vboxmouse for
  openSUSE 11.1, 11.0, 10.3 and lower (bnc #374710, bnc #438590)
* Mon Oct 27 2008 mkudlvasr@suse.cz
- add Should-Start: ypbind to rcvboxnet
- add rc symlinks for init scripts
* Mon Oct 27 2008 ro@suse.de
- do not play with permissions files on factory
* Sat Oct 25 2008 dmueller@suse.de
- update to 2.0.4:
  * VMM: better error reporting for VT-x failures
  * VMM: don’t overﬂow the release log with PATM messages (bug #1775)
  * VMM: ﬁxed save state restore in real mode (software virtualization only)
  * GUI: work around a Qt bug on Mac OS X (bug #2321)
  * GUI: properly install the Qt4 accessible plugin (bug #629)
  * SATA: error message when starting a VM with a VMDK connected to a SATA port (bug #2182)
  * SATA: ﬁxed Guru mediation when booting OpenSolaris/64; most likely applies to other guests as well (bug #2292)
  * Network: don’t crash when changing the adapter link state if no host driver is attached (bug #2333)
  * VHD: ﬁxed bug which prevents booting from VHD images bigger than 4GB (bug #2085)
  * VRDP: ﬁxed a repaint problem when the guest resolution was not equal to the client resolution
  * Clipboard: don’t crash when host service initialization takes longer than expected (Linux hosts only; bug #2001)
  * Linux hosts: handle jifﬁes counter overﬂow (VM stuck after 300 seconds of host uptime; bug #2247)
  * Solaris hosts: ﬁxed host or guest side networking going stale while using host interface networking (bug #2474)
  * Solaris hosts: added support for using unplumbed network interfaces and Crossbow Virtual Network Interfaces (VNICs) with host interface networking
  * Solaris hosts: reworked threading model improves performance for host interface networking
  * Windows additions: ﬁxed crash when accessing deep directory structures in a shared folder
  * Windows additions: improved shared folder name resolving (bug #1728)
  * Windows additions: ﬁxed Windows 2000 shutdown crash (bug #2254)
  * Windows additions: ﬁxed error code for MoveFile() if the target exists (bug #2350)
  * Linux additions: ﬁxed seek() for ﬁles bigger than 2GB (bug #2379)
  * Linux additions: support Ubuntu 8.10
  * Linux additions: clipboard ﬁxes (bug #2015)
  * Web services: improved documentation and ﬁxed example (bug #1642)
  - ------------------------------------------------------------------
* Sat Oct 25 2008 suse-tux@gmx.de
- new upstream version 2.0.4
* Fri Oct 17 2008 olh@suse.de
- add ExclusiveArch x86 x86_64
* Thu Sep 25 2008 mkudlvasr@suse.cz
- merge into openSUSE Factory
* Tue Sep 23 2008 suse-tux@gmx.de
- splitted virtualbox-permissions into virtualbox-ose.easy and virtualbox-ose.secure to
  be suse compliant
* Tue Sep 23 2008 suse-tux@gmx.de
- only apply Patch12 (vbox-buildfix) on factory
- added dir /var/run/VirtualBox (this is needed by the VBoxAddIF/VBoxDeleteIF scripts)
* Mon Sep 22 2008 mkudlvasr@suse.cz
- modified Config.kmk fix to use realpath for splited kernels
- fixed Required-Stop in init scripts
* Thu Sep 18 2008 suse-tux@gmx.de
- added Patch15 (vbox-configure_python26.diff) to detect the python installation on
  factory
* Thu Sep 18 2008 suse-tux@gmx.de
- fixed #427266 - now virtualbox uses RUNPATH instead of ORIGIN to locate the
  libs because ORIGIN seems to be broken if the hardening feature is enabled
- updated Patch3 (vbox-kmp-vboxvfs.diff) and fixed Makefile-vboxvfs (finally!)
  in order to remove undefined symbols
- create wrapper script for VBoxHeadless
* Sun Sep 14 2008 suse-tux@gmx.de
- new upstream version 2.0.2
* Sun Sep 14 2008 suse-tux@gmx.de
- disabled Patch2 (vbox-kmp-vboxadd.diff)
- updated Patch3 (vbox-kmp-vboxvfs.diff)
- fixed Makefile, Makefile-vboxadd and Makefile-vboxvfs to compile on x86_64
* Sun Sep 14 2008 suse-tux@gmx.de
- new upstream version 2.0.0
- replaced Patch14 (old: virtualbox-missing-Makefiles.diff) with vbox-kbuild_unit_paths.diff,
  this is needed because our kbuild package doesn't ship these units
- fixed Makefile, Makefile-vboxadd and Makefile-vboxvfs + some cleanups
- modified virtualbox-patch-source so that it doesn't remove the kBuild/units dir
- added Source9 (virtualbox-permissions) because we can't ship suid binaries
* Thu Sep 11 2008 mkudlvasr@suse.cz
- new upstream version 1.6.6
- removed Patch14 - not needed any more
- added rc-symlinks to init scripts
- fixed Config.kmk
* Mon Sep  8 2008 dmueller@suse.de
- merge into openSUSE Factory
* Sat Aug  9 2008 suse-tux@gmx.de
- new upstream version 1.6.4
- added Patch14 (virtualbox-missing-Makefiles.diff) because some Makefiles are missing
  (Makefiles are taken from http://article.gmane.org/gmane.comp.emulators.virtualbox.devel/706)
* Wed Jun 25 2008 dmueller@suse.de
- merged factory and OBS package
* Fri Jun 13 2008 suse-tux@gmx.de
- new upstream version 1.6.2
- updated Patch12 (vbox-buildfix) and Patch13 (virtualbox-use-intree-yasm.diff)
* Tue Jun 10 2008 mkudlvasr@suse.cz
- add -y option to %%fillup_and_insserv macro (bnc#391878)
* Thu May 15 2008 dmueller@suse.de
- readd Enhances (bnc#390333)
* Thu May  8 2008 ro@suse.de
- subpackage needs to be virtualbox-ose-KMP (not -kmp)
* Mon May  5 2008 suse-tux@gmx.de
- enabled Patch2 (vbox-kmp-vboxadd.diff) and Patch3 (vbox-kmp-vboxvfs.diff) again. They're
  needed for x86_64 builds. Updated both patches and the parts for the Makefile.module are
  removed now because we don't need them.
* Mon May  5 2008 suse-tux@gmx.de
- fixed Makefile, Makefile-vboxadd and Makefile-vboxvfs
- added "BuildRequires: xorg-x11-libXext-devel-32bit xorg-x11-libXmu-devel-32bit"
  to build on x86_64
* Mon May  5 2008 suse-tux@gmx.de
- new upstream version 1.6.0
- added libxml2-devel libxslt-devel to the BuildRequires
- added configuration file %%%%{_sysconfdir}/vbox/vbox.cfg
- added x11restore.pl to the guest-tools package
- the former vboxadd-xclient is now called VBoxClient
- disabled Patch2 (vbox-kmp-vboxadd.diff) and Patch3 (vbox-kmp-vboxvfs.diff); they seem to be superfluous
- disabled Patch11 (vbox-vboxfs-2.6.25); everything is fixed in this release
- updated other patches:
  * Patch10 (vbox-2.6.25): the vfsmod.c stuff is fixed
  * Patch4 (virtualbox-ose-init-scripts.diff): removed patches for vboxadd.sh and vboxvfs.sh + minor fix
  * some of the other patches were updated to apply flawlessly
- other minor spec file fixes
- adapted virtualbox-patch-source script so that it still works if the dir in the tarball differs from "basename tarball"
  (VirtualBox-1.6.0-OSE != VirtualBox-1.6.0_OSE)
* Fri May  2 2008 dmueller@suse.de
- fix supplements generation (bnc#384084)
* Wed Apr 30 2008 mkudlvasr@suse.cz
- add enhances statements for kmp. fixes [bnc #384084]
* Sun Apr 27 2008 mkudlvasr@suse.cz
- remove sax configuration according to [bnc#374710]
- activate init scripts by default
- solve vboxadd-xclient and vboxadd-timesync file conflict
  (they were packaged also in virtualbox-ose by mistake)
- added networking configuration into README.SUSE
* Mon Apr 14 2008 dmueller@suse.de
- remove the full tarball (bnc#270552)
* Mon Apr  7 2008 dmueller@suse.de
- revert revert of of kbuild package instead of precompiled binaries
- add patch to always use in-tree yasm
* Sun Apr  6 2008 bwalle@suse.de
- revert of of kbuild package instead of precompiled binaries
  since it didn't work in Factory
- revert removal of precompiled binaries from the tarball since
  it didn't work in Factory
- fix build on 2.6.25
* Wed Apr  2 2008 dmueller@suse.de
- use kbuild package instead of precompiled binaries in tarball
- remove precompiled binaries from the tarball
* Mon Mar 10 2008 mkudlvasr@suse.cz
- add init scripts for guest tools and x11 configuration script
- update README.suse
* Thu Feb 28 2008 dmueller@suse.de
- merge factory and buildservice packages
* Wed Feb 27 2008 mkudlvasr@suse.cz
- created symlink to VBoxTunctl in /usr/bin. VBoxAddIf should work ok now
* Tue Feb 26 2008 mkudlvasr@suse.cz
- re-added script which strips unneded parts of code [bug 270552]
* Tue Feb 26 2008 suse-tux@gmx.de
- new upstream version 1.5.6
- fixed Makefile for building the vboxdrv module
* Thu Feb 21 2008 suse-tux@gmx.de
- fixed Requires for the guest-tools (typo which was due to the rename)
- minor spec fixes (replaced some hardcoded paths with the corresponding rpm macros)
* Wed Feb 20 2008 dmueller@suse.de
- fix factory/x86_64 buildrequires
* Fri Feb 15 2008 dmueller@suse.de
- rename xorg-x11-driver-virtualbox to xorg-x11-driver-virtualbox-ose
* Wed Feb 13 2008 dmueller@suse.de
- go back to gcc 4.1 for Factory, otherwise it does not work
* Tue Feb 12 2008 dmueller@suse.de
- rename to virtualbox-ose
- add patch for gcc 4.3 compile failure
* Fri Feb  8 2008 suse-tux@gmx.de
- updated virtualbox-init-script: removed check for the existence of the kernel-module (again)
* Mon Feb  4 2008 sndirsch@suse.de
- xorg-x11-driver-virtualbox: install package by default in
  virtualbox (Supplements tag); added SaX2/hwinfo data files
  (Bug #358460)
* Thu Jan 31 2008 suse-tux@gmx.de
- added language support
* Mon Jan 28 2008 suse-tux@gmx.de
- enabled Patch2 and Patch3 again - otherwise we cannot build on
  x86_64
- updated Makefile-vboxadd and Makefile-vboxvfs to build on x86_64
* Sun Jan 27 2008 suse-tux@gmx.de
- updated Makefile-vboxadd and Makefile-vboxvfs (minor fixes)
- updated virtualbox-init-script.diff: enabled check if the kernel module exists
- updated virtualbox-gcc43-fixes.diff: most of it is fixed upstream
- disabled Patch2, Patch3 and Patch5 in the spec file:
  Patch2: vbox-kmp-vboxadd.diff: this patch shouldn't be needed anymore
  Patch3: vbox-kmp-vboxvfs.diff: this patch shouldn't be needed anymore
  Patch5: virtualbox-kernel-2.6.24.diff: this is fixed upstream
- some spec file cleanups
- updated to version 1.5.4
  * USB 2.0 support
  * PulseAudio backend
  * GUI: fixed accelerators in German translation
  * GUI: fixed registration dialog crashes
  * GUI: allow to enter unicode characters to the name of the registration dialog
  * GUI: pre-select attached media in the disk manager when opened from the VM settings dialog
  * GUI: remember the last active VM
  * GUI: don't accept empty paths for serial/parallel ports in XML
  * GUI: fixed NumLock / CapsLock synchronizazion on Windows hosts
  * GUI: don't start the kernel timer if no VM is active (Linux host)
  * VMM: improved compatibility with FreeBSD guests
  * VMM: properly restore CR4 after leaving VT-x mode
  * VMM: patch code and disassembler updates
  * VMM: with VT-x a pending interrupt could be cleared behind our back
  * VMM: workaround for missed cpuid patch (some Linux guests refuse to boot on multi-core CPUs)
  * VMM: fixed code for overriding CPUID values
  * API: don't crash when trying to create a VM with a duplicate name
  * API: don't crash when trying to access the settings of a VM when some other VMs are not accessible
  * API: fixed several memory leaks
  * ATA/IDE: fixed SuSE 9.1 CD read installer regression
  * Floppy: fixed inverted write protect flag
  * USB: virtualize an EHCI controller
  * USB: several minor fixes
  * Network: fixed MAC address check
  * Network: host interface fixes for Solaris guests
  * Network: guest networking stopped completely after taking a snapshot
  * Network: don't crash if a network card is enabled but not attached
  * PXE: fix for PXE-EC8 error on soft reboot
  * NAT: update the DNS server IP address on every DNS packet sent by the guest
  * VGA: reset VRAM access handers after a fullscreen update
  * VGA: don't overwrite guest's VRAM when displaying a blank screen
  * ACPI: implemented the sleep button event
  * VRDP: fixed crash when querying VRDP properties
  * VRDP: netAddress fixes
  * VRDP: fixed the Pause/Break keys over VRDP
  * VRDP: sync NumLock / CapsLock sync over VRDP
  * VRDP: workaround for scrambled icons with a guest video mode of 16bpp
  * VRDP: reset modifer keys on RDP_INPUT_SYNCHRONIZE
  * VRDP: reset RDP updates after resize to prevent obsolete updates
  * Clipboard: Windows host/guest fixes
  * Clipboard: fixed a SEGFAULT on VM exit (Linux host)
  * Clipboard: fixed a buffer overflow (Linux host)
  * Shared Folders: fixed memory leaks
  * Linux installer: remove the old kernel module before compiling a new one
  * Linux host: compatibility fixes with Linux 2.6.24
  * Linux host: script fixes for ArchLinux
  * Linux host: load correct HAL library to determine DVD/Floppy (libhal.so.1 not libhal.so)
  * Linux host: make sure the tun kernel module is loaded before initializing static TAP interfaces
  * Windows additions: fixed hang during HGCM communication
  * Windows additions: fixed delay when shutting down the guest
  * Linux additions: added sendfile support to allow HTTP servers to send files on shared folders
  * Linux additions: make additions work with Fedora 8 (SELinux policy added)
  * Linux additions: sometimes ARGB pointers were display incorrectly
  * Linux additions: several small script fixes
* Tue Dec 11 2007 anschneider@suse.de
- Add VBoxAddIF and VBoxDeleteIF scripts
* Fri Nov 30 2007 anschneider@suse.de
- Fix kmp requriement
* Thu Nov 29 2007 anschneider@suse.de
- Fixes that virtualbox compiles with gcc 4.3
  * virtualbox-gcc43-fixes.diff
  * virtualbox-validate-op-gcc43.diff
* Wed Nov 28 2007 anschneider@suse.de
- Require the same version for the kmp module as the package self.
- Fix conflicts with Kernel 2.6.24
  * virtualbox-kernel-2.6.24.diff
* Wed Nov 21 2007 ro@suse.de
- buildreq: gcc-42 -> gcc-43
* Fri Nov  2 2007 suse-tux@gmx.de
- Added own Makefiles for the kernel modules (vboxvfs seems
  to be broken though)
* Thu Nov  1 2007 mkudlvasr@suse.cz
- added init scripts for starting kernel module. fixes [bug 328887]
- disabled stripping of VBoxREM2.rel . fixes [bug 307722]
- updating to 1.5.2 fixes [bug 335734]
* Sun Oct 28 2007 anschneider@suse.de
- Added xorg-x11 drivers for mouse and video
- Added kernel moduels for guest systems
- Added guest tools for mounting shares, syncing the time and sharing
  the clipboard
* Sun Oct 28 2007 anschneider@suse.de
- updated to version 1.5.2
  * Windows Installer: fixed installation on Windows 2000 hosts
  * Windows Installer: proper warning when installing a 32-bit VirtualBox
    version on 64-bit Windows and vice versa
  * Linux Installer: no longer require license acceptance during install,
    instead at first GUI startup (addresses issues with hanging installer
    on Debian based distributions)
  * GUI: added user registration dialog
  * GUI: fixed crashes on 64-bit Linux hosts
  * GUI: several fixes and improvements to seamless mode
  * GUI: fixed DirectDraw mode with certain video cards (e.g. Intel i915)
  * GUI: fixed incorrect guest resolution after leaving fullscreen mode
  * GUI: improved keyboard handling on Linux host
  * GUI: show fatal VM aborts (aka "Guru Meditation")
  * GUI: fixed crashes due to a display update race condition on some systems
  * GUI: added ACPI shutdown option to the VM close dialog
  * GUI: NLS improvements
  * BIOS: fixed floppy boot menu
  * BIOS: expose the VM UUID in the DMI/SMBIOS area
  * VGA: fixed CGA video modes
  * VGA: fixed 8-bit DAC handling (Solaris setup)
  * VMM: fixed issue with VT-x on Windows 64-bit hosts
  * VMM: improved compatibility with Linux KVM
  * VMM: fixed issues with Fedora 8 guests
  * VMM: fixed fatal errors while installing Windows guests when using AMD-V
  * VMM: fixed sporadic hangs when minimizing VM window and using VT-x/AMD-V
  * VMM: fixed high load of ksoftirq on tickless Linux hosts
  * VMM: fixed Windows 2000 guests hangs related to IRQ sharing
  * VMM: fixed sporadic errors during openSUSE 10.3 installation
  * VMM: fixed issue with Linux 2.6.23 guests
  * VMM: fixed issues with Solaris guests
  * VMM: fixed stability issue related to incorrect relocations
  * Serial: significantly reduced CPU utilization
  * Network: fixed issues with FreeBSD guests
  * Network: added MII support (100MBit detection fix)
  * Network: improved MAC address handling
  * Network: added PXE release logging
  * IDE: large reads from CD could exceed the I/O buffer size
  * Audio: load ALSA dynamically on Linux (i.e. do not fail when ALSA is not
    present)
  * VRDP: support additional RDP clients (SunRay, WinConnect, Mac OS X)
  * VRDP: fixed issues when client color depth is higher than server color depth
  * VRDP: make PAM authentication service name configurable
  * VRDP: increased stack size to deal with stack consuming PAM library calls
  * Additions: various fixes and enhancements to clipboard handling
  * Windows Additions: fixed issues with Additions on NT 4 guests
  * Windows Additions: added support for 8-bit video modes
  * Windows Additions: allow specifying custom resolutions for secondary screens
  * Windows Additions: several fixes and improvements for DirectDraw
  * Windows Additions: improved the mouse filter driver compatibility with other
    mouse drivers
  * Linux Additions: several fixes and enhancements to Shared Folders
  * Linux Additions: added support for X.org Server 1.4
  * Shared folders: fixed MS Powerpoint access issues (Linux host)
  * API: fixed RPC_E_CHANGED_MODE startup error on Windows hosts
  * API: fixed SMP race condition on Linux hosts
  * API: fixed stability issues on Windows hosts in low memory conditions
* Thu Sep  6 2007 mvyskocil@suse.de
- updated to version 1.5.0
  * Major: Seamless windows
  * Major: Virtual serial ports
  * Major: Intel PXE 2.1 network boot
  * GUI: sometimes two mouse cursors were visible when Windows guest additions became active
  * GUI: added VT-x/AMD-V settings
  * GUI: disable 'Show log...' menu entry to prevent crash if VM list is empty
  * GUI: the log window grabbed the keyboard
  * GUI: fixed error handling if Linux host clipboard initialization fails
  * GUI: pass the Pause key and the PrtScrn key to the guest (Linux hosts)
  * GUI: increased maximum guest RAM to 2 GB (Windows host)
  * GUI: improved rendering performance (Windows host)
  * GUI: status lights for USB and shared folders
  * GUI: properly respect the DISPLAY environment variable
  * GUI: download Guest Additions from virtualbox.org in case they are not present locally
  * VRDP: support for multimonitor configurations in Windows guests
  * VRDP: support for MS RDP6 and MS RDP Mac clients
  * VRDP: added support for WinConnect RDP client
  * VRDP: performance improvements
  * VRDP: fixed sporadic client disconnects
  * VBoxManage: never delete existing target during clonevdi
  * VBoxManage: properly print the size of currently used hard disks
  * VMM: fixed Xandros Desktop 4.1 hang
  * VMM: fixed VT-x/AMD-V hang with newer versions of gcc (Linux hosts)
  * VMM: improved stability of VT-x
  * VMM: check for disabled AMD-V when detecting support
  * VMM: fixed AMD-V issue when running OS/2 guests
  * VMM: fixed application startup regressions (e.g. VideoReDo)
  * VMM: fixed regression that broke disk access in OS/2 and OpenBSD guests (possibly much more)
  * VMM: fixed crashes if memory allocation failed (Linux)
  * VMM: fixed enabling of Local APIC on AMD hosts (fixed Ubuntu Feisty installation kernel hang during boot)
  * VMM: fixed XFree86 4.3 (Debian/Sarge) segfaults when switching to text mode
  * VMM: refuse to start when KVM is active (Linux Host)
  * VMM: fixed bootup hangs with ReactOS
  * VMM: fixed out-of-memory errors under certain environments with enough appropriate memory available
  * API: fixed occassional crashes of the VBoxSVC server during VM shutdown (Linux host)
  * API: some components were not notified when mounting a CD/DVD
  * VMDK: improve geometry compatibility with existing VDMK images
  * IDE/Floppy: optionally make non-available host device non-fatal
  * IDE: improve emulation accuracy of the IRQ line between master and slave drive
  * IDE: guest could freeze when unmounting the CD/DVD drive
  * VGA: several text mode fixes in particular with Windows DOS boxes
  * USB: fixed some issues with Windows hosts
  * USB: fixed race condition between udev and USB filters (Linux host)
  * Shared Folders: reversed network provider order to increase mapping performance (Windows guest)
  * Shared Folders: browsable from Windows Explorer (Windows guests)
  * Shared Folders: stability fixes (Windows guest)
  * Shared Folders: case sensitivity fixes (Windows guest and Linux host)
  * Audio: fall back to the NULL audio driver if no voice could be opened
  * NAT: fixed crash
  * Guest Additions: reworked the shared clipboard for Linux hosts and guests based on user feedback about problems with individual applications
  * Guest Additions: don't allow to disable mouse pointer integration for Linux guests as an Xorg hardware mouse cursor cannot be turned into a software mouse cursor
  * Guest Additions: Linux guests shipping Xorg 1.3 (e.g. Fedora 7, Ubuntu Gutsy) are now supported
  * Guest Additions: added DirectDraw support to the Windows display driver
* Tue Aug 28 2007 mkudlvasr@suse.cz
- update to svn version (Aug 22 2007)
- new licence - FLOSS exceptions
* Mon Jun 25 2007 seife@suse.de
- fix x86_64 build
* Thu Jun 14 2007 mkudlvasr@suse.cz
- took new update from autobuild (update to version 1.4.0)
- highlights from changelog:
  * OS X supported
  * amd64 supported
  * easier networking of virtual machines
- stripping unneded parts of code [bug 270552]
* Fri May 11 2007 ro@suse.de
- use same ksrc-magic in specfile as in configure
* Mon Apr 23 2007 mkudlvasr@suse.cz
- took package from buildservice and added into autobuild
* Mon Apr 16 2007 Marcus Hüwe <suse-tux@gmx.de>
- fixed XEN problems when building x86_64 packages in the BS
- fixed BuildRequires for factory
* Sun Apr  8 2007 Marcus Hüwe <suse-tux@gmx.de>
- udate to 1.3.8
- fixed x86_64 problems; added a futex patch from mandriva
  (see  http://cvs.mandriva.com/cgi-bin/viewvc.cgi/contrib-SPECS/virtualbox/VirtualBox-OSE-1.3.4-futex.patch?view=log
  for details)
  there is still a problem because on x86_64 you cannot load the
  kernel module because of nmi_watchdog
- added Requires: virtualbox-kmp
- added a wrapper for VBoxSDL
- added an icon to the desktop file
* Sat Mar 10 2007 Marcus Hüwe <suse-tux@gmx.de>
- made it work again (i forgot to install the *.r0 and *.gc files)
* Mon Feb 26 2007 Marcus Hüwe <suse-tux@gmx.de>
- slightly modified Patch2 (patch for building on XEN hosts)
  and also modified the Patch1 a bit
- removed Patch0 (Patch0 was a USB-patch)
* Mon Feb 19 2007 Marcus Hüwe <suse-tux@gmx.de>
- new upstream version 1.3.6
* Sat Feb 17 2007 Marcus Hüwe <suse-tux@gmx.de>
- added/removed patches
- fixed some 10.2 XEN-issues - now it builds on 10.2 again
- cleaned up spec file (removed some dirty stuff)
* Mon Feb 12 2007 Marcus Hüwe <suse-tux@gmx.de>
- new upstream version 1.3.4
* Fri Feb  2 2007 Marcus Hüwe <suse-tux@gmx.de>
- initial build
